<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'much’a: runa, runa, chuya qara niraq, tunpa chuya qara niraq',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'much’a: runa, runa, chuya qara niraq, tunpa qara niraq',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'much’a: runa, runa, chuya qara niraq, tunpa yana qara niraq',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'much’a: runa, runa, chuya qara niraq, yana qara niraq',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'much’a: runa, runa, tunpa chuya qara niraq, chuya qara niraq',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'much’a: runa, runa, tunpa chuya qara niraq, tunpa qara niraq',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'much’a: runa, runa, tunpa chuya qara niraq, tunpa yana qara niraq',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'much’a: runa, runa, tunpa chuya qara niraq, yana qara niraq',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'much’a: runa, runa, tunpa qara niraq, chuya qara niraq',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'much’a: runa, runa, tunpa qara niraq, tunpa chuya qara niraq',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'much’a: runa, runa, tunpa qara niraq, tunpa yana qara niraq',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'much’a: runa, runa, tunpa qara niraq, yana qara niraq',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'much’a: runa, runa, tunpa yana qara niraq, chuya qara niraq',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'much’a: runa, runa, tunpa yana qara niraq, tunpa chuya qara niraq',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'much’a: runa, runa, tunpa yana qara niraq, tunpa qara niraq',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'much’a: runa, runa, tunpa yana qara niraq, yana qara niraq',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'much’a: runa, runa, yana qara niraq, chuya qara niraq',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'much’a: runa, runa, yana qara niraq, tunpa chuya qara niraq',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'much’a: runa, runa, yana qara niraq, tunpa qara niraq',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'much’a: runa, runa, yana qara niraq, tunpa yana qara niraq',
    '👨🏻‍❤‍💋‍👨🏻' => 'much’a: qari, qari, chuya qara niraq',
    '👨🏻‍❤‍💋‍👨🏼' => 'much’a: qari, qari, chuya qara niraq, tunpa chuya qara niraq',
    '👨🏻‍❤‍💋‍👨🏽' => 'much’a: qari, qari, chuya qara niraq, tunpa qara niraq',
    '👨🏻‍❤‍💋‍👨🏾' => 'much’a: qari, qari, chuya qara niraq, tunpa yana qara niraq',
    '👨🏻‍❤‍💋‍👨🏿' => 'much’a: qari, qari, chuya qara niraq, yana qara niraq',
    '👨🏼‍❤‍💋‍👨🏻' => 'much’a: qari, qari, tunpa chuya qara niraq, chuya qara niraq',
    '👨🏼‍❤‍💋‍👨🏼' => 'much’a: qari, qari, tunpa chuya qara niraq',
    '👨🏼‍❤‍💋‍👨🏽' => 'much’a: qari, qari, tunpa chuya qara niraq, tunpa qara niraq',
    '👨🏼‍❤‍💋‍👨🏾' => 'much’a: qari, qari, tunpa chuya qara niraq, tunpa yana qara niraq',
    '👨🏼‍❤‍💋‍👨🏿' => 'much’a: qari, qari, tunpa chuya qara niraq, yana qara niraq',
    '👨🏽‍❤‍💋‍👨🏻' => 'much’a: qari, qari, tunpa qara niraq, chuya qara niraq',
    '👨🏽‍❤‍💋‍👨🏼' => 'much’a: qari, qari, tunpa qara niraq, tunpa chuya qara niraq',
    '👨🏽‍❤‍💋‍👨🏽' => 'much’a: qari, qari, tunpa qara niraq',
    '👨🏽‍❤‍💋‍👨🏾' => 'much’a: qari, qari, tunpa qara niraq, tunpa yana qara niraq',
    '👨🏽‍❤‍💋‍👨🏿' => 'much’a: qari, qari, tunpa qara niraq, yana qara niraq',
    '👨🏾‍❤‍💋‍👨🏻' => 'much’a: qari, qari, tunpa yana qara niraq, chuya qara niraq',
    '👨🏾‍❤‍💋‍👨🏼' => 'much’a: qari, qari, tunpa yana qara niraq, tunpa chuya qara niraq',
    '👨🏾‍❤‍💋‍👨🏽' => 'much’a: qari, qari, tunpa yana qara niraq, tunpa qara niraq',
    '👨🏾‍❤‍💋‍👨🏾' => 'much’a: qari, qari, tunpa yana qara niraq',
    '👨🏾‍❤‍💋‍👨🏿' => 'much’a: qari, qari, tunpa yana qara niraq, yana qara niraq',
    '👨🏿‍❤‍💋‍👨🏻' => 'much’a: qari, qari, yana qara niraq, chuya qara niraq',
    '👨🏿‍❤‍💋‍👨🏼' => 'much’a: qari, qari, yana qara niraq, tunpa chuya qara niraq',
    '👨🏿‍❤‍💋‍👨🏽' => 'much’a: qari, qari, yana qara niraq, tunpa qara niraq',
    '👨🏿‍❤‍💋‍👨🏾' => 'much’a: qari, qari, yana qara niraq, tunpa yana qara niraq',
    '👨🏿‍❤‍💋‍👨🏿' => 'much’a: qari, qari, yana qara niraq',
    '👩🏻‍❤‍💋‍👨🏻' => 'much’a: warmi, qari, chuya qara niraq',
    '👩🏻‍❤‍💋‍👨🏼' => 'much’a: warmi, qari, chuya qara niraq, tunpa chuya qara niraq',
    '👩🏻‍❤‍💋‍👨🏽' => 'much’a: warmi, qari, chuya qara niraq, tunpa qara niraq',
    '👩🏻‍❤‍💋‍👨🏾' => 'much’a: warmi, qari, chuya qara niraq, tunpa yana qara niraq',
    '👩🏻‍❤‍💋‍👨🏿' => 'much’a: warmi, qari, chuya qara niraq, yana qara niraq',
    '👩🏼‍❤‍💋‍👨🏻' => 'much’a: warmi, qari, tunpa chuya qara niraq, chuya qara niraq',
    '👩🏼‍❤‍💋‍👨🏼' => 'much’a: warmi, qari, tunpa chuya qara niraq',
    '👩🏼‍❤‍💋‍👨🏽' => 'much’a: warmi, qari, tunpa chuya qara niraq, tunpa qara niraq',
    '👩🏼‍❤‍💋‍👨🏾' => 'much’a: warmi, qari, tunpa chuya qara niraq, tunpa yana qara niraq',
    '👩🏼‍❤‍💋‍👨🏿' => 'much’a: warmi, qari, tunpa chuya qara niraq, yana qara niraq',
    '👩🏽‍❤‍💋‍👨🏻' => 'much’a: warmi, qari, tunpa qara niraq, chuya qara niraq',
    '👩🏽‍❤‍💋‍👨🏼' => 'much’a: warmi, qari, tunpa qara niraq, tunpa chuya qara niraq',
    '👩🏽‍❤‍💋‍👨🏽' => 'much’a: warmi, qari, tunpa qara niraq',
    '👩🏽‍❤‍💋‍👨🏾' => 'much’a: warmi, qari, tunpa qara niraq, tunpa yana qara niraq',
    '👩🏽‍❤‍💋‍👨🏿' => 'much’a: warmi, qari, tunpa qara niraq, yana qara niraq',
    '👩🏾‍❤‍💋‍👨🏻' => 'much’a: warmi, qari, tunpa yana qara niraq, chuya qara niraq',
    '👩🏾‍❤‍💋‍👨🏼' => 'much’a: warmi, qari, tunpa yana qara niraq, tunpa chuya qara niraq',
    '👩🏾‍❤‍💋‍👨🏽' => 'much’a: warmi, qari, tunpa yana qara niraq, tunpa qara niraq',
    '👩🏾‍❤‍💋‍👨🏾' => 'much’a: warmi, qari, tunpa yana qara niraq',
    '👩🏾‍❤‍💋‍👨🏿' => 'much’a: warmi, qari, tunpa yana qara niraq, yana qara niraq',
    '👩🏿‍❤‍💋‍👨🏻' => 'much’a: warmi, qari, yana qara niraq, chuya qara niraq',
    '👩🏿‍❤‍💋‍👨🏼' => 'much’a: warmi, qari, yana qara niraq, tunpa chuya qara niraq',
    '👩🏿‍❤‍💋‍👨🏽' => 'much’a: warmi, qari, yana qara niraq, tunpa qara niraq',
    '👩🏿‍❤‍💋‍👨🏾' => 'much’a: warmi, qari, yana qara niraq, tunpa yana qara niraq',
    '👩🏿‍❤‍💋‍👨🏿' => 'much’a: warmi, qari, yana qara niraq',
    '👩🏻‍❤‍💋‍👩🏻' => 'much’a: warmi, warmi, chuya qara niraq',
    '👩🏻‍❤‍💋‍👩🏼' => 'much’a: warmi, warmi, chuya qara niraq, tunpa chuya qara niraq',
    '👩🏻‍❤‍💋‍👩🏽' => 'much’a: warmi, warmi, chuya qara niraq, tunpa qara niraq',
    '👩🏻‍❤‍💋‍👩🏾' => 'much’a: warmi, warmi, chuya qara niraq, tunpa yana qara niraq',
    '👩🏻‍❤‍💋‍👩🏿' => 'much’a: warmi, warmi, chuya qara niraq, yana qara niraq',
    '👩🏼‍❤‍💋‍👩🏻' => 'much’a: warmi, warmi, tunpa chuya qara niraq, chuya qara niraq',
    '👩🏼‍❤‍💋‍👩🏼' => 'much’a: warmi, warmi, tunpa chuya qara niraq',
    '👩🏼‍❤‍💋‍👩🏽' => 'much’a: warmi, warmi, tunpa chuya qara niraq, tunpa qara niraq',
    '👩🏼‍❤‍💋‍👩🏾' => 'much’a: warmi, warmi, tunpa chuya qara niraq, tunpa yana qara niraq',
    '👩🏼‍❤‍💋‍👩🏿' => 'much’a: warmi, warmi, tunpa chuya qara niraq, yana qara niraq',
    '👩🏽‍❤‍💋‍👩🏻' => 'much’a: warmi, warmi, tunpa qara niraq, chuya qara niraq',
    '👩🏽‍❤‍💋‍👩🏼' => 'much’a: warmi, warmi, tunpa qara niraq, tunpa chuya qara niraq',
    '👩🏽‍❤‍💋‍👩🏽' => 'much’a: warmi, warmi, tunpa qara niraq',
    '👩🏽‍❤‍💋‍👩🏾' => 'much’a: warmi, warmi, tunpa qara niraq, tunpa yana qara niraq',
    '👩🏽‍❤‍💋‍👩🏿' => 'much’a: warmi, warmi, tunpa qara niraq, yana qara niraq',
    '👩🏾‍❤‍💋‍👩🏻' => 'much’a: warmi, warmi, tunpa yana qara niraq, chuya qara niraq',
    '👩🏾‍❤‍💋‍👩🏼' => 'much’a: warmi, warmi, tunpa yana qara niraq, tunpa chuya qara niraq',
    '👩🏾‍❤‍💋‍👩🏽' => 'much’a: warmi, warmi, tunpa yana qara niraq, tunpa qara niraq',
    '👩🏾‍❤‍💋‍👩🏾' => 'much’a: warmi, warmi, tunpa yana qara niraq',
    '👩🏾‍❤‍💋‍👩🏿' => 'much’a: warmi, warmi, tunpa yana qara niraq, yana qara niraq',
    '👩🏿‍❤‍💋‍👩🏻' => 'much’a: warmi, warmi, yana qara niraq, chuya qara niraq',
    '👩🏿‍❤‍💋‍👩🏼' => 'much’a: warmi, warmi, yana qara niraq, tunpa chuya qara niraq',
    '👩🏿‍❤‍💋‍👩🏽' => 'much’a: warmi, warmi, yana qara niraq, tunpa qara niraq',
    '👩🏿‍❤‍💋‍👩🏾' => 'much’a: warmi, warmi, yana qara niraq, tunpa yana qara niraq',
    '👩🏿‍❤‍💋‍👩🏿' => 'much’a: warmi, warmi, yana qara niraq',
    '🧑🏻‍🫯‍🧑🏼' => 'maqanakuq runa: chuya qara niraq, tunpa chuya qara niraq',
    '🧑🏻‍🫯‍🧑🏽' => 'maqanakuq runa: chuya qara niraq, tunpa qara niraq',
    '🧑🏻‍🫯‍🧑🏾' => 'maqanakuq runa: chuya qara niraq, tunpa yana qara niraq',
    '🧑🏻‍🫯‍🧑🏿' => 'maqanakuq runa: chuya qara niraq, yana qara niraq',
    '🧑🏼‍🫯‍🧑🏻' => 'maqanakuq runa: tunpa chuya qara niraq, chuya qara niraq',
    '🧑🏼‍🫯‍🧑🏽' => 'maqanakuq runa: tunpa chuya qara niraq, tunpa qara niraq',
    '🧑🏼‍🫯‍🧑🏾' => 'maqanakuq runa: tunpa chuya qara niraq, tunpa yana qara niraq',
    '🧑🏼‍🫯‍🧑🏿' => 'maqanakuq runa: tunpa chuya qara niraq, yana qara niraq',
    '🧑🏽‍🫯‍🧑🏻' => 'maqanakuq runa: tunpa qara niraq, chuya qara niraq',
    '🧑🏽‍🫯‍🧑🏼' => 'maqanakuq runa: tunpa qara niraq, tunpa chuya qara niraq',
    '🧑🏽‍🫯‍🧑🏾' => 'maqanakuq runa: tunpa qara niraq, tunpa yana qara niraq',
    '🧑🏽‍🫯‍🧑🏿' => 'maqanakuq runa: tunpa qara niraq, yana qara niraq',
    '🧑🏾‍🫯‍🧑🏻' => 'maqanakuq runa: tunpa yana qara niraq, chuya qara niraq',
    '🧑🏾‍🫯‍🧑🏼' => 'maqanakuq runa: tunpa yana qara niraq, tunpa chuya qara niraq',
    '🧑🏾‍🫯‍🧑🏽' => 'maqanakuq runa: tunpa yana qara niraq, tunpa qara niraq',
    '🧑🏾‍🫯‍🧑🏿' => 'maqanakuq runa: tunpa yana qara niraq, yana qara niraq',
    '🧑🏿‍🫯‍🧑🏻' => 'maqanakuq runa: yana qara niraq, chuya qara niraq',
    '🧑🏿‍🫯‍🧑🏼' => 'maqanakuq runa: yana qara niraq, tunpa chuya qara niraq',
    '🧑🏿‍🫯‍🧑🏽' => 'maqanakuq runa: yana qara niraq, tunpa qara niraq',
    '🧑🏿‍🫯‍🧑🏾' => 'maqanakuq runa: yana qara niraq, tunpa yana qara niraq',
    '🧑🏻‍❤‍🧑🏼' => 'pitu runakuna sunquwan: runa, runa, chuya qara niraq, tunpa chuya qara niraq',
    '🧑🏻‍❤‍🧑🏽' => 'pitu runakuna sunquwan: runa, runa, chuya qara niraq, tunpa qara niraq',
    '🧑🏻‍❤‍🧑🏾' => 'pitu runakuna sunquwan: runa, runa, chuya qara niraq, tunpa yana qara niraq',
    '🧑🏻‍❤‍🧑🏿' => 'pitu runakuna sunquwan: runa, runa, chuya qara niraq, yana qara niraq',
    '🧑🏼‍❤‍🧑🏻' => 'pitu runakuna sunquwan: runa, runa, tunpa chuya qara niraq, chuya qara niraq',
    '🧑🏼‍❤‍🧑🏽' => 'pitu runakuna sunquwan: runa, runa, tunpa chuya qara niraq, tunpa qara niraq',
    '🧑🏼‍❤‍🧑🏾' => 'pitu runakuna sunquwan: runa, runa, tunpa chuya qara niraq, tunpa yana qara niraq',
    '🧑🏼‍❤‍🧑🏿' => 'pitu runakuna sunquwan: runa, runa, tunpa chuya qara niraq, yana qara niraq',
    '🧑🏽‍❤‍🧑🏻' => 'pitu runakuna sunquwan: runa, runa, tunpa qara niraq, chuya qara niraq',
    '🧑🏽‍❤‍🧑🏼' => 'pitu runakuna sunquwan: runa, runa, tunpa qara niraq, tunpa chuya qara niraq',
    '🧑🏽‍❤‍🧑🏾' => 'pitu runakuna sunquwan: runa, runa, tunpa qara niraq, tunpa yana qara niraq',
    '🧑🏽‍❤‍🧑🏿' => 'pitu runakuna sunquwan: runa, runa, tunpa qara niraq, yana qara niraq',
    '🧑🏾‍❤‍🧑🏻' => 'pitu runakuna sunquwan: runa, runa, tunpa yana qara niraq, chuya qara niraq',
    '🧑🏾‍❤‍🧑🏼' => 'pitu runakuna sunquwan: runa, runa, tunpa yana qara niraq, tunpa chuya qara niraq',
    '🧑🏾‍❤‍🧑🏽' => 'pitu runakuna sunquwan: runa, runa, tunpa yana qara niraq, tunpa qara niraq',
    '🧑🏾‍❤‍🧑🏿' => 'pitu runakuna sunquwan: runa, runa, tunpa yana qara niraq, yana qara niraq',
    '🧑🏿‍❤‍🧑🏻' => 'pitu runakuna sunquwan: runa, runa, yana qara niraq, chuya qara niraq',
    '🧑🏿‍❤‍🧑🏼' => 'pitu runakuna sunquwan: runa, runa, yana qara niraq, tunpa chuya qara niraq',
    '🧑🏿‍❤‍🧑🏽' => 'pitu runakuna sunquwan: runa, runa, yana qara niraq, tunpa qara niraq',
    '🧑🏿‍❤‍🧑🏾' => 'pitu runakuna sunquwan: runa, runa, yana qara niraq, tunpa yana qara niraq',
    '🧑🏻‍🐰‍🧑🏼' => 'runakuna quwi ninrikunawan: chuya qara niraq, tunpa chuya qara niraq',
    '🧑🏻‍🐰‍🧑🏽' => 'runakuna quwi ninrikunawan: chuya qara niraq, tunpa qara niraq',
    '🧑🏻‍🐰‍🧑🏾' => 'runakuna quwi ninrikunawan: chuya qara niraq, tunpa yana qara niraq',
    '🧑🏻‍🐰‍🧑🏿' => 'runakuna quwi ninrikunawan: chuya qara niraq, yana qara niraq',
    '🧑🏼‍🐰‍🧑🏻' => 'runakuna quwi ninrikunawan: tunpa chuya qara niraq, chuya qara niraq',
    '🧑🏼‍🐰‍🧑🏽' => 'runakuna quwi ninrikunawan: tunpa chuya qara niraq, tunpa qara niraq',
    '🧑🏼‍🐰‍🧑🏾' => 'runakuna quwi ninrikunawan: tunpa chuya qara niraq, tunpa yana qara niraq',
    '🧑🏼‍🐰‍🧑🏿' => 'runakuna quwi ninrikunawan: tunpa chuya qara niraq, yana qara niraq',
    '🧑🏽‍🐰‍🧑🏻' => 'runakuna quwi ninrikunawan: tunpa qara niraq, chuya qara niraq',
    '🧑🏽‍🐰‍🧑🏼' => 'runakuna quwi ninrikunawan: tunpa qara niraq, tunpa chuya qara niraq',
    '🧑🏽‍🐰‍🧑🏾' => 'runakuna quwi ninrikunawan: tunpa qara niraq, tunpa yana qara niraq',
    '🧑🏽‍🐰‍🧑🏿' => 'runakuna quwi ninrikunawan: tunpa qara niraq, yana qara niraq',
    '🧑🏾‍🐰‍🧑🏻' => 'runakuna quwi ninrikunawan: tunpa yana qara niraq, chuya qara niraq',
    '🧑🏾‍🐰‍🧑🏼' => 'runakuna quwi ninrikunawan: tunpa yana qara niraq, tunpa chuya qara niraq',
    '🧑🏾‍🐰‍🧑🏽' => 'runakuna quwi ninrikunawan: tunpa yana qara niraq, tunpa qara niraq',
    '🧑🏾‍🐰‍🧑🏿' => 'runakuna quwi ninrikunawan: tunpa yana qara niraq, yana qara niraq',
    '🧑🏿‍🐰‍🧑🏻' => 'runakuna quwi ninrikunawan: yana qara niraq, chuya qara niraq',
    '🧑🏿‍🐰‍🧑🏼' => 'runakuna quwi ninrikunawan: yana qara niraq, tunpa chuya qara niraq',
    '🧑🏿‍🐰‍🧑🏽' => 'runakuna quwi ninrikunawan: yana qara niraq, tunpa qara niraq',
    '🧑🏿‍🐰‍🧑🏾' => 'runakuna quwi ninrikunawan: yana qara niraq, tunpa yana qara niraq',
    '👨🏻‍🫯‍👨🏼' => 'maqanakuq tata: chuya qara niraq, tunpa chuya qara niraq',
    '👨🏻‍🫯‍👨🏽' => 'maqanakuq tata: chuya qara niraq, tunpa qara niraq',
    '👨🏻‍🫯‍👨🏾' => 'maqanakuq tata: chuya qara niraq, tunpa yana qara niraq',
    '👨🏻‍🫯‍👨🏿' => 'maqanakuq tata: chuya qara niraq, yana qara niraq',
    '👨🏼‍🫯‍👨🏻' => 'maqanakuq tata: tunpa chuya qara niraq, chuya qara niraq',
    '👨🏼‍🫯‍👨🏽' => 'maqanakuq tata: tunpa chuya qara niraq, tunpa qara niraq',
    '👨🏼‍🫯‍👨🏾' => 'maqanakuq tata: tunpa chuya qara niraq, tunpa yana qara niraq',
    '👨🏼‍🫯‍👨🏿' => 'maqanakuq tata: tunpa chuya qara niraq, yana qara niraq',
    '👨🏽‍🫯‍👨🏻' => 'maqanakuq tata: tunpa qara niraq, chuya qara niraq',
    '👨🏽‍🫯‍👨🏼' => 'maqanakuq tata: tunpa qara niraq, tunpa chuya qara niraq',
    '👨🏽‍🫯‍👨🏾' => 'maqanakuq tata: tunpa qara niraq, tunpa yana qara niraq',
    '👨🏽‍🫯‍👨🏿' => 'maqanakuq tata: tunpa qara niraq, yana qara niraq',
    '👨🏾‍🫯‍👨🏻' => 'maqanakuq tata: tunpa yana qara niraq, chuya qara niraq',
    '👨🏾‍🫯‍👨🏼' => 'maqanakuq tata: tunpa yana qara niraq, tunpa chuya qara niraq',
    '👨🏾‍🫯‍👨🏽' => 'maqanakuq tata: tunpa yana qara niraq, tunpa qara niraq',
    '👨🏾‍🫯‍👨🏿' => 'maqanakuq tata: tunpa yana qara niraq, yana qara niraq',
    '👨🏿‍🫯‍👨🏻' => 'maqanakuq tata: yana qara niraq, chuya qara niraq',
    '👨🏿‍🫯‍👨🏼' => 'maqanakuq tata: yana qara niraq, tunpa chuya qara niraq',
    '👨🏿‍🫯‍👨🏽' => 'maqanakuq tata: yana qara niraq, tunpa qara niraq',
    '👨🏿‍🫯‍👨🏾' => 'maqanakuq tata: yana qara niraq, tunpa yana qara niraq',
    '👨🏻‍❤‍👨🏻' => 'pitu runakuna sunquwan: qari, qari, chuya qara niraq',
    '👨🏻‍❤‍👨🏼' => 'pitu runakuna sunquwan: qari, qari, chuya qara niraq, tunpa chuya qara niraq',
    '👨🏻‍❤‍👨🏽' => 'pitu runakuna sunquwan: qari, qari, chuya qara niraq, tunpa qara niraq',
    '👨🏻‍❤‍👨🏾' => 'pitu runakuna sunquwan: qari, qari, chuya qara niraq, tunpa yana qara niraq',
    '👨🏻‍❤‍👨🏿' => 'pitu runakuna sunquwan: qari, qari, chuya qara niraq, yana qara niraq',
    '👨🏼‍❤‍👨🏻' => 'pitu runakuna sunquwan: qari, qari, tunpa chuya qara niraq, chuya qara niraq',
    '👨🏼‍❤‍👨🏼' => 'pitu runakuna sunquwan: qari, qari, tunpa chuya qara niraq',
    '👨🏼‍❤‍👨🏽' => 'pitu runakuna sunquwan: qari, qari, tunpa chuya qara niraq, tunpa qara niraq',
    '👨🏼‍❤‍👨🏾' => 'pitu runakuna sunquwan: qari, qari, tunpa chuya qara niraq, tunpa yana qara niraq',
    '👨🏼‍❤‍👨🏿' => 'pitu runakuna sunquwan: qari, qari, tunpa chuya qara niraq, yana qara niraq',
    '👨🏽‍❤‍👨🏻' => 'pitu runakuna sunquwan: qari, qari, tunpa qara niraq, chuya qara niraq',
    '👨🏽‍❤‍👨🏼' => 'pitu runakuna sunquwan: qari, qari, tunpa qara niraq, tunpa chuya qara niraq',
    '👨🏽‍❤‍👨🏽' => 'pitu runakuna sunquwan: qari, qari, tunpa qara niraq',
    '👨🏽‍❤‍👨🏾' => 'pitu runakuna sunquwan: qari, qari, tunpa qara niraq, tunpa yana qara niraq',
    '👨🏽‍❤‍👨🏿' => 'pitu runakuna sunquwan: qari, qari, tunpa qara niraq, yana qara niraq',
    '👨🏾‍❤‍👨🏻' => 'pitu runakuna sunquwan: qari, qari, tunpa yana qara niraq, chuya qara niraq',
    '👨🏾‍❤‍👨🏼' => 'pitu runakuna sunquwan: qari, qari, tunpa yana qara niraq, tunpa chuya qara niraq',
    '👨🏾‍❤‍👨🏽' => 'pitu runakuna sunquwan: qari, qari, tunpa yana qara niraq, tunpa qara niraq',
    '👨🏾‍❤‍👨🏾' => 'pitu runakuna sunquwan: qari, qari, tunpa yana qara niraq',
    '👨🏾‍❤‍👨🏿' => 'pitu runakuna sunquwan: qari, qari, tunpa yana qara niraq, yana qara niraq',
    '👨🏿‍❤‍👨🏻' => 'pitu runakuna sunquwan: qari, qari, yana qara niraq, chuya qara niraq',
    '👨🏿‍❤‍👨🏼' => 'pitu runakuna sunquwan: qari, qari, yana qara niraq, tunpa chuya qara niraq',
    '👨🏿‍❤‍👨🏽' => 'pitu runakuna sunquwan: qari, qari, yana qara niraq, tunpa qara niraq',
    '👨🏿‍❤‍👨🏾' => 'pitu runakuna sunquwan: qari, qari, yana qara niraq, tunpa yana qara niraq',
    '👨🏿‍❤‍👨🏿' => 'pitu runakuna sunquwan: qari, qari, yana qara niraq',
    '👨🏻‍🐰‍👨🏼' => 'runa quwi ninrikunawan: chuya qara niraq, tunpa chuya qara niraq',
    '👨🏻‍🐰‍👨🏽' => 'runa quwi ninrikunawan: chuya qara niraq, tunpa qara niraq',
    '👨🏻‍🐰‍👨🏾' => 'runa quwi ninrikunawan: chuya qara niraq, tunpa yana qara niraq',
    '👨🏻‍🐰‍👨🏿' => 'runa quwi ninrikunawan: chuya qara niraq, yana qara niraq',
    '👨🏼‍🐰‍👨🏻' => 'runa quwi ninrikunawan: tunpa chuya qara niraq, chuya qara niraq',
    '👨🏼‍🐰‍👨🏽' => 'runa quwi ninrikunawan: tunpa chuya qara niraq, tunpa qara niraq',
    '👨🏼‍🐰‍👨🏾' => 'runa quwi ninrikunawan: tunpa chuya qara niraq, tunpa yana qara niraq',
    '👨🏼‍🐰‍👨🏿' => 'runa quwi ninrikunawan: tunpa chuya qara niraq, yana qara niraq',
    '👨🏽‍🐰‍👨🏻' => 'runa quwi ninrikunawan: tunpa qara niraq, chuya qara niraq',
    '👨🏽‍🐰‍👨🏼' => 'runa quwi ninrikunawan: tunpa qara niraq, tunpa chuya qara niraq',
    '👨🏽‍🐰‍👨🏾' => 'runa quwi ninrikunawan: tunpa qara niraq, tunpa yana qara niraq',
    '👨🏽‍🐰‍👨🏿' => 'runa quwi ninrikunawan: tunpa qara niraq, yana qara niraq',
    '👨🏾‍🐰‍👨🏻' => 'runa quwi ninrikunawan: tunpa yana qara niraq, chuya qara niraq',
    '👨🏾‍🐰‍👨🏼' => 'runa quwi ninrikunawan: tunpa yana qara niraq, tunpa chuya qara niraq',
    '👨🏾‍🐰‍👨🏽' => 'runa quwi ninrikunawan: tunpa yana qara niraq, tunpa qara niraq',
    '👨🏾‍🐰‍👨🏿' => 'runa quwi ninrikunawan: tunpa yana qara niraq, yana qara niraq',
    '👨🏿‍🐰‍👨🏻' => 'runa quwi ninrikunawan: yana qara niraq, chuya qara niraq',
    '👨🏿‍🐰‍👨🏼' => 'runa quwi ninrikunawan: yana qara niraq, tunpa chuya qara niraq',
    '👨🏿‍🐰‍👨🏽' => 'runa quwi ninrikunawan: yana qara niraq, tunpa qara niraq',
    '👨🏿‍🐰‍👨🏾' => 'runa quwi ninrikunawan: yana qara niraq, tunpa yana qara niraq',
    '👩🏻‍🫯‍👩🏼' => 'maqanakuq warmi: chuya qara niraq, tunpa chuya qara niraq',
    '👩🏻‍🫯‍👩🏽' => 'maqanakuq warmi: chuya qara niraq, tunpa qara niraq',
    '👩🏻‍🫯‍👩🏾' => 'maqanakuq warmi: chuya qara niraq, tunpa yana qara niraq',
    '👩🏻‍🫯‍👩🏿' => 'maqanakuq warmi: chuya qara niraq, yana qara niraq',
    '👩🏼‍🫯‍👩🏻' => 'maqanakuq warmi: tunpa chuya qara niraq, chuya qara niraq',
    '👩🏼‍🫯‍👩🏽' => 'maqanakuq warmi: tunpa chuya qara niraq, tunpa qara niraq',
    '👩🏼‍🫯‍👩🏾' => 'maqanakuq warmi: tunpa chuya qara niraq, tunpa yana qara niraq',
    '👩🏼‍🫯‍👩🏿' => 'maqanakuq warmi: tunpa chuya qara niraq, yana qara niraq',
    '👩🏽‍🫯‍👩🏻' => 'maqanakuq warmi: tunpa qara niraq, chuya qara niraq',
    '👩🏽‍🫯‍👩🏼' => 'maqanakuq warmi: tunpa qara niraq, tunpa chuya qara niraq',
    '👩🏽‍🫯‍👩🏾' => 'maqanakuq warmi: tunpa qara niraq, tunpa yana qara niraq',
    '👩🏽‍🫯‍👩🏿' => 'maqanakuq warmi: tunpa qara niraq, yana qara niraq',
    '👩🏾‍🫯‍👩🏻' => 'maqanakuq warmi: tunpa yana qara niraq, chuya qara niraq',
    '👩🏾‍🫯‍👩🏼' => 'maqanakuq warmi: tunpa yana qara niraq, tunpa chuya qara niraq',
    '👩🏾‍🫯‍👩🏽' => 'maqanakuq warmi: tunpa yana qara niraq, tunpa qara niraq',
    '👩🏾‍🫯‍👩🏿' => 'maqanakuq warmi: tunpa yana qara niraq, yana qara niraq',
    '👩🏿‍🫯‍👩🏻' => 'maqanakuq warmi: yana qara niraq, chuya qara niraq',
    '👩🏿‍🫯‍👩🏼' => 'maqanakuq warmi: yana qara niraq, tunpa chuya qara niraq',
    '👩🏿‍🫯‍👩🏽' => 'maqanakuq warmi: yana qara niraq, tunpa qara niraq',
    '👩🏿‍🫯‍👩🏾' => 'maqanakuq warmi: yana qara niraq, tunpa yana qara niraq',
    '👩🏻‍❤‍👨🏻' => 'pitu runakuna sunquwan: warmi, qari, chuya qara niraq',
    '👩🏻‍❤‍👨🏼' => 'pitu runakuna sunquwan: warmi, qari, chuya qara niraq, tunpa chuya qara niraq',
    '👩🏻‍❤‍👨🏽' => 'pitu runakuna sunquwan: warmi, qari, chuya qara niraq, tunpa qara niraq',
    '👩🏻‍❤‍👨🏾' => 'pitu runakuna sunquwan: warmi, qari, chuya qara niraq, tunpa yana qara niraq',
    '👩🏻‍❤‍👨🏿' => 'pitu runakuna sunquwan: warmi, qari, chuya qara niraq, yana qara niraq',
    '👩🏼‍❤‍👨🏻' => 'pitu runakuna sunquwan: warmi, qari, tunpa chuya qara niraq, chuya qara niraq',
    '👩🏼‍❤‍👨🏼' => 'pitu runakuna sunquwan: warmi, qari, tunpa chuya qara niraq',
    '👩🏼‍❤‍👨🏽' => 'pitu runakuna sunquwan: warmi, qari, tunpa chuya qara niraq, tunpa qara niraq',
    '👩🏼‍❤‍👨🏾' => 'pitu runakuna sunquwan: warmi, qari, tunpa chuya qara niraq, tunpa yana qara niraq',
    '👩🏼‍❤‍👨🏿' => 'pitu runakuna sunquwan: warmi, qari, tunpa chuya qara niraq, yana qara niraq',
    '👩🏽‍❤‍👨🏻' => 'pitu runakuna sunquwan: warmi, qari, tunpa qara niraq, chuya qara niraq',
    '👩🏽‍❤‍👨🏼' => 'pitu runakuna sunquwan: warmi, qari, tunpa qara niraq, tunpa chuya qara niraq',
    '👩🏽‍❤‍👨🏽' => 'pitu runakuna sunquwan: warmi, qari, tunpa qara niraq',
    '👩🏽‍❤‍👨🏾' => 'pitu runakuna sunquwan: warmi, qari, tunpa qara niraq, tunpa yana qara niraq',
    '👩🏽‍❤‍👨🏿' => 'pitu runakuna sunquwan: warmi, qari, tunpa qara niraq, yana qara niraq',
    '👩🏾‍❤‍👨🏻' => 'pitu runakuna sunquwan: warmi, qari, tunpa yana qara niraq, chuya qara niraq',
    '👩🏾‍❤‍👨🏼' => 'pitu runakuna sunquwan: warmi, qari, tunpa yana qara niraq, tunpa chuya qara niraq',
    '👩🏾‍❤‍👨🏽' => 'pitu runakuna sunquwan: warmi, qari, tunpa yana qara niraq, tunpa qara niraq',
    '👩🏾‍❤‍👨🏾' => 'pitu runakuna sunquwan: warmi, qari, tunpa yana qara niraq',
    '👩🏾‍❤‍👨🏿' => 'pitu runakuna sunquwan: warmi, qari, tunpa yana qara niraq, yana qara niraq',
    '👩🏿‍❤‍👨🏻' => 'pitu runakuna sunquwan: warmi, qari, yana qara niraq, chuya qara niraq',
    '👩🏿‍❤‍👨🏼' => 'pitu runakuna sunquwan: warmi, qari, yana qara niraq, tunpa chuya qara niraq',
    '👩🏿‍❤‍👨🏽' => 'pitu runakuna sunquwan: warmi, qari, yana qara niraq, tunpa qara niraq',
    '👩🏿‍❤‍👨🏾' => 'pitu runakuna sunquwan: warmi, qari, yana qara niraq, tunpa yana qara niraq',
    '👩🏿‍❤‍👨🏿' => 'pitu runakuna sunquwan: warmi, qari, yana qara niraq',
    '👩🏻‍❤‍👩🏻' => 'pitu runakuna sunquwan: warmi, warmi, chuya qara niraq',
    '👩🏻‍❤‍👩🏼' => 'pitu runakuna sunquwan: warmi, warmi, chuya qara niraq, tunpa chuya qara niraq',
    '👩🏻‍❤‍👩🏽' => 'pitu runakuna sunquwan: warmi, warmi, chuya qara niraq, tunpa qara niraq',
    '👩🏻‍❤‍👩🏾' => 'pitu runakuna sunquwan: warmi, warmi, chuya qara niraq, tunpa yana qara niraq',
    '👩🏻‍❤‍👩🏿' => 'pitu runakuna sunquwan: warmi, warmi, chuya qara niraq, yana qara niraq',
    '👩🏼‍❤‍👩🏻' => 'pitu runakuna sunquwan: warmi, warmi, tunpa chuya qara niraq, chuya qara niraq',
    '👩🏼‍❤‍👩🏼' => 'pitu runakuna sunquwan: warmi, warmi, tunpa chuya qara niraq',
    '👩🏼‍❤‍👩🏽' => 'pitu runakuna sunquwan: warmi, warmi, tunpa chuya qara niraq, tunpa qara niraq',
    '👩🏼‍❤‍👩🏾' => 'pitu runakuna sunquwan: warmi, warmi, tunpa chuya qara niraq, tunpa yana qara niraq',
    '👩🏼‍❤‍👩🏿' => 'pitu runakuna sunquwan: warmi, warmi, tunpa chuya qara niraq, yana qara niraq',
    '👩🏽‍❤‍👩🏻' => 'pitu runakuna sunquwan: warmi, warmi, tunpa qara niraq, chuya qara niraq',
    '👩🏽‍❤‍👩🏼' => 'pitu runakuna sunquwan: warmi, warmi, tunpa qara niraq, tunpa chuya qara niraq',
    '👩🏽‍❤‍👩🏽' => 'pitu runakuna sunquwan: warmi, warmi, tunpa qara niraq',
    '👩🏽‍❤‍👩🏾' => 'pitu runakuna sunquwan: warmi, warmi, tunpa qara niraq, tunpa yana qara niraq',
    '👩🏽‍❤‍👩🏿' => 'pitu runakuna sunquwan: warmi, warmi, tunpa qara niraq, yana qara niraq',
    '👩🏾‍❤‍👩🏻' => 'pitu runakuna sunquwan: warmi, warmi, tunpa yana qara niraq, chuya qara niraq',
    '👩🏾‍❤‍👩🏼' => 'pitu runakuna sunquwan: warmi, warmi, tunpa yana qara niraq, tunpa chuya qara niraq',
    '👩🏾‍❤‍👩🏽' => 'pitu runakuna sunquwan: warmi, warmi, tunpa yana qara niraq, tunpa qara niraq',
    '👩🏾‍❤‍👩🏾' => 'pitu runakuna sunquwan: warmi, warmi, tunpa yana qara niraq',
    '👩🏾‍❤‍👩🏿' => 'pitu runakuna sunquwan: warmi, warmi, tunpa yana qara niraq, yana qara niraq',
    '👩🏿‍❤‍👩🏻' => 'pitu runakuna sunquwan: warmi, warmi, yana qara niraq, chuya qara niraq',
    '👩🏿‍❤‍👩🏼' => 'pitu runakuna sunquwan: warmi, warmi, yana qara niraq, tunpa chuya qara niraq',
    '👩🏿‍❤‍👩🏽' => 'pitu runakuna sunquwan: warmi, warmi, yana qara niraq, tunpa qara niraq',
    '👩🏿‍❤‍👩🏾' => 'pitu runakuna sunquwan: warmi, warmi, yana qara niraq, tunpa yana qara niraq',
    '👩🏿‍❤‍👩🏿' => 'pitu runakuna sunquwan: warmi, warmi, yana qara niraq',
    '👩🏻‍🐰‍👩🏼' => 'warmi quwi ninrikunawan: chuya qara niraq, tunpa chuya qara niraq',
    '👩🏻‍🐰‍👩🏽' => 'warmi quwi ninrikunawan: chuya qara niraq, tunpa qara niraq',
    '👩🏻‍🐰‍👩🏾' => 'warmi quwi ninrikunawan: chuya qara niraq, tunpa yana qara niraq',
    '👩🏻‍🐰‍👩🏿' => 'warmi quwi ninrikunawan: chuya qara niraq, yana qara niraq',
    '👩🏼‍🐰‍👩🏻' => 'warmi quwi ninrikunawan: tunpa chuya qara niraq, chuya qara niraq',
    '👩🏼‍🐰‍👩🏽' => 'warmi quwi ninrikunawan: tunpa chuya qara niraq, tunpa qara niraq',
    '👩🏼‍🐰‍👩🏾' => 'warmi quwi ninrikunawan: tunpa chuya qara niraq, tunpa yana qara niraq',
    '👩🏼‍🐰‍👩🏿' => 'warmi quwi ninrikunawan: tunpa chuya qara niraq, yana qara niraq',
    '👩🏽‍🐰‍👩🏻' => 'warmi quwi ninrikunawan: tunpa qara niraq, chuya qara niraq',
    '👩🏽‍🐰‍👩🏼' => 'warmi quwi ninrikunawan: tunpa qara niraq, tunpa chuya qara niraq',
    '👩🏽‍🐰‍👩🏾' => 'warmi quwi ninrikunawan: tunpa qara niraq, tunpa yana qara niraq',
    '👩🏽‍🐰‍👩🏿' => 'warmi quwi ninrikunawan: tunpa qara niraq, yana qara niraq',
    '👩🏾‍🐰‍👩🏻' => 'warmi quwi ninrikunawan: tunpa yana qara niraq, chuya qara niraq',
    '👩🏾‍🐰‍👩🏼' => 'warmi quwi ninrikunawan: tunpa yana qara niraq, tunpa chuya qara niraq',
    '👩🏾‍🐰‍👩🏽' => 'warmi quwi ninrikunawan: tunpa yana qara niraq, tunpa qara niraq',
    '👩🏾‍🐰‍👩🏿' => 'warmi quwi ninrikunawan: tunpa yana qara niraq, yana qara niraq',
    '👩🏿‍🐰‍👩🏻' => 'warmi quwi ninrikunawan: yana qara niraq, chuya qara niraq',
    '👩🏿‍🐰‍👩🏼' => 'warmi quwi ninrikunawan: yana qara niraq, tunpa chuya qara niraq',
    '👩🏿‍🐰‍👩🏽' => 'warmi quwi ninrikunawan: yana qara niraq, tunpa qara niraq',
    '👩🏿‍🐰‍👩🏾' => 'warmi quwi ninrikunawan: yana qara niraq, tunpa yana qara niraq',
    '🧑🏻‍🤝‍🧑🏻' => 'runakuna iskay makikunawan: chuya qara niraq',
    '🧑🏻‍🤝‍🧑🏼' => 'runakuna iskay makikunawan: chuya qara niraq, tunpa chuya qara niraq',
    '🧑🏻‍🤝‍🧑🏽' => 'runakuna iskay makikunawan: chuya qara niraq, tunpa qara niraq',
    '🧑🏻‍🤝‍🧑🏾' => 'runakuna iskay makikunawan: chuya qara niraq, tunpa yana qara niraq',
    '🧑🏻‍🤝‍🧑🏿' => 'runakuna iskay makikunawan: chuya qara niraq, yana qara niraq',
    '🧑🏼‍🤝‍🧑🏻' => 'runakuna iskay makikunawan: tunpa chuya qara niraq, chuya qara niraq',
    '🧑🏼‍🤝‍🧑🏼' => 'runakuna iskay makikunawan: tunpa chuya qara niraq',
    '🧑🏼‍🤝‍🧑🏽' => 'runakuna iskay makikunawan: tunpa chuya qara niraq, tunpa qara niraq',
    '🧑🏼‍🤝‍🧑🏾' => 'runakuna iskay makikunawan: tunpa chuya qara niraq, tunpa yana qara niraq',
    '🧑🏼‍🤝‍🧑🏿' => 'runakuna iskay makikunawan: tunpa chuya qara niraq, yana qara niraq',
    '🧑🏽‍🤝‍🧑🏻' => 'runakuna iskay makikunawan: tunpa qara niraq, chuya qara niraq',
    '🧑🏽‍🤝‍🧑🏼' => 'runakuna iskay makikunawan: tunpa qara niraq, tunpa chuya qara niraq',
    '🧑🏽‍🤝‍🧑🏽' => 'runakuna iskay makikunawan: tunpa qara niraq',
    '🧑🏽‍🤝‍🧑🏾' => 'runakuna iskay makikunawan: tunpa qara niraq, tunpa yana qara niraq',
    '🧑🏽‍🤝‍🧑🏿' => 'runakuna iskay makikunawan: tunpa qara niraq, yana qara niraq',
    '🧑🏾‍🤝‍🧑🏻' => 'runakuna iskay makikunawan: tunpa yana qara niraq, chuya qara niraq',
    '🧑🏾‍🤝‍🧑🏼' => 'runakuna iskay makikunawan: tunpa yana qara niraq, tunpa chuya qara niraq',
    '🧑🏾‍🤝‍🧑🏽' => 'runakuna iskay makikunawan: tunpa yana qara niraq, tunpa qara niraq',
    '🧑🏾‍🤝‍🧑🏾' => 'runakuna iskay makikunawan: tunpa yana qara niraq',
    '🧑🏾‍🤝‍🧑🏿' => 'runakuna iskay makikunawan: tunpa yana qara niraq, yana qara niraq',
    '🧑🏿‍🤝‍🧑🏻' => 'runakuna iskay makikunawan: yana qara niraq, chuya qara niraq',
    '🧑🏿‍🤝‍🧑🏼' => 'runakuna iskay makikunawan: yana qara niraq, tunpa chuya qara niraq',
    '🧑🏿‍🤝‍🧑🏽' => 'runakuna iskay makikunawan: yana qara niraq, tunpa qara niraq',
    '🧑🏿‍🤝‍🧑🏾' => 'runakuna iskay makikunawan: yana qara niraq, tunpa yana qara niraq',
    '🧑🏿‍🤝‍🧑🏿' => 'runakuna iskay makikunawan: yana qara niraq',
    '👩🏻‍🤝‍👩🏼' => 'warmi iskay makikunawan: chuya qara niraq, tunpa chuya qara niraq',
    '👩🏻‍🤝‍👩🏽' => 'warmi iskay makikunawan: chuya qara niraq, tunpa qara niraq',
    '👩🏻‍🤝‍👩🏾' => 'warmi iskay makikunawan: chuya qara niraq, tunpa yana qara niraq',
    '👩🏻‍🤝‍👩🏿' => 'warmi iskay makikunawan: chuya qara niraq, yana qara niraq',
    '👩🏼‍🤝‍👩🏻' => 'warmi iskay makikunawan: tunpa chuya qara niraq, chuya qara niraq',
    '👩🏼‍🤝‍👩🏽' => 'warmi iskay makikunawan: tunpa chuya qara niraq, tunpa qara niraq',
    '👩🏼‍🤝‍👩🏾' => 'warmi iskay makikunawan: tunpa chuya qara niraq, tunpa yana qara niraq',
    '👩🏼‍🤝‍👩🏿' => 'warmi iskay makikunawan: tunpa chuya qara niraq, yana qara niraq',
    '👩🏽‍🤝‍👩🏻' => 'warmi iskay makikunawan: tunpa qara niraq, chuya qara niraq',
    '👩🏽‍🤝‍👩🏼' => 'warmi iskay makikunawan: tunpa qara niraq, tunpa chuya qara niraq',
    '👩🏽‍🤝‍👩🏾' => 'warmi iskay makikunawan: tunpa qara niraq, tunpa yana qara niraq',
    '👩🏽‍🤝‍👩🏿' => 'warmi iskay makikunawan: tunpa qara niraq, yana qara niraq',
    '👩🏾‍🤝‍👩🏻' => 'warmi iskay makikunawan: tunpa yana qara niraq, chuya qara niraq',
    '👩🏾‍🤝‍👩🏼' => 'warmi iskay makikunawan: tunpa yana qara niraq, tunpa chuya qara niraq',
    '👩🏾‍🤝‍👩🏽' => 'warmi iskay makikunawan: tunpa yana qara niraq, tunpa qara niraq',
    '👩🏾‍🤝‍👩🏿' => 'warmi iskay makikunawan: tunpa yana qara niraq, yana qara niraq',
    '👩🏿‍🤝‍👩🏻' => 'warmi iskay makikunawan: yana qara niraq, chuya qara niraq',
    '👩🏿‍🤝‍👩🏼' => 'warmi iskay makikunawan: yana qara niraq, tunpa chuya qara niraq',
    '👩🏿‍🤝‍👩🏽' => 'warmi iskay makikunawan: yana qara niraq, tunpa qara niraq',
    '👩🏿‍🤝‍👩🏾' => 'warmi iskay makikunawan: yana qara niraq, tunpa yana qara niraq',
    '👩🏻‍🤝‍👨🏼' => 'warmi chaymanta runa iskay makikunawan: chuya qara niraq, tunpa chuya qara niraq',
    '👩🏻‍🤝‍👨🏽' => 'warmi chaymanta runa iskay makikunawan: chuya qara niraq, tunpa qara niraq',
    '👩🏻‍🤝‍👨🏾' => 'warmi chaymanta runa iskay makikunawan: chuya qara niraq, tunpa yana qara niraq',
    '👩🏻‍🤝‍👨🏿' => 'warmi chaymanta runa iskay makikunawan: chuya qara niraq, yana qara niraq',
    '👩🏼‍🤝‍👨🏻' => 'warmi chaymanta runa iskay makikunawan: tunpa chuya qara niraq, chuya qara niraq',
    '👩🏼‍🤝‍👨🏽' => 'warmi chaymanta runa iskay makikunawan: tunpa chuya qara niraq, tunpa qara niraq',
    '👩🏼‍🤝‍👨🏾' => 'warmi chaymanta runa iskay makikunawan: tunpa chuya qara niraq, tunpa yana qara niraq',
    '👩🏼‍🤝‍👨🏿' => 'warmi chaymanta runa iskay makikunawan: tunpa chuya qara niraq, yana qara niraq',
    '👩🏽‍🤝‍👨🏻' => 'warmi chaymanta runa iskay makikunawan: tunpa qara niraq, chuya qara niraq',
    '👩🏽‍🤝‍👨🏼' => 'warmi chaymanta runa iskay makikunawan: tunpa qara niraq, tunpa chuya qara niraq',
    '👩🏽‍🤝‍👨🏾' => 'warmi chaymanta runa iskay makikunawan: tunpa qara niraq, tunpa yana qara niraq',
    '👩🏽‍🤝‍👨🏿' => 'warmi chaymanta runa iskay makikunawan: tunpa qara niraq, yana qara niraq',
    '👩🏾‍🤝‍👨🏻' => 'warmi chaymanta runa iskay makikunawan: tunpa yana qara niraq, chuya qara niraq',
    '👩🏾‍🤝‍👨🏼' => 'warmi chaymanta runa iskay makikunawan: tunpa yana qara niraq, tunpa chuya qara niraq',
    '👩🏾‍🤝‍👨🏽' => 'warmi chaymanta runa iskay makikunawan: tunpa yana qara niraq, tunpa qara niraq',
    '👩🏾‍🤝‍👨🏿' => 'warmi chaymanta runa iskay makikunawan: tunpa yana qara niraq, yana qara niraq',
    '👩🏿‍🤝‍👨🏻' => 'warmi chaymanta runa iskay makikunawan: yana qara niraq, chuya qara niraq',
    '👩🏿‍🤝‍👨🏼' => 'warmi chaymanta runa iskay makikunawan: yana qara niraq, tunpa chuya qara niraq',
    '👩🏿‍🤝‍👨🏽' => 'warmi chaymanta runa iskay makikunawan: yana qara niraq, tunpa qara niraq',
    '👩🏿‍🤝‍👨🏾' => 'warmi chaymanta runa iskay makikunawan: yana qara niraq, tunpa yana qara niraq',
    '👨🏻‍🤝‍👨🏼' => 'runa iskay makikunawan: chuya qara niraq, tunpa chuya qara niraq',
    '👨🏻‍🤝‍👨🏽' => 'runa iskay makikunawan: chuya qara niraq, tunpa qara niraq',
    '👨🏻‍🤝‍👨🏾' => 'runa iskay makikunawan: chuya qara niraq, tunpa yana qara niraq',
    '👨🏻‍🤝‍👨🏿' => 'runa iskay makikunawan: chuya qara niraq, yana qara niraq',
    '👨🏼‍🤝‍👨🏻' => 'runa iskay makikunawan: tunpa chuya qara niraq, chuya qara niraq',
    '👨🏼‍🤝‍👨🏽' => 'runa iskay makikunawan: tunpa chuya qara niraq, tunpa qara niraq',
    '👨🏼‍🤝‍👨🏾' => 'runa iskay makikunawan: tunpa chuya qara niraq, tunpa yana qara niraq',
    '👨🏼‍🤝‍👨🏿' => 'runa iskay makikunawan: tunpa chuya qara niraq, yana qara niraq',
    '👨🏽‍🤝‍👨🏻' => 'runa iskay makikunawan: tunpa qara niraq, chuya qara niraq',
    '👨🏽‍🤝‍👨🏼' => 'runa iskay makikunawan: tunpa qara niraq, tunpa chuya qara niraq',
    '👨🏽‍🤝‍👨🏾' => 'runa iskay makikunawan: tunpa qara niraq, tunpa yana qara niraq',
    '👨🏽‍🤝‍👨🏿' => 'runa iskay makikunawan: tunpa qara niraq, yana qara niraq',
    '👨🏾‍🤝‍👨🏻' => 'runa iskay makikunawan: tunpa yana qara niraq, chuya qara niraq',
    '👨🏾‍🤝‍👨🏼' => 'runa iskay makikunawan: tunpa yana qara niraq, tunpa chuya qara niraq',
    '👨🏾‍🤝‍👨🏽' => 'runa iskay makikunawan: tunpa yana qara niraq, tunpa qara niraq',
    '👨🏾‍🤝‍👨🏿' => 'runa iskay makikunawan: tunpa yana qara niraq, yana qara niraq',
    '👨🏿‍🤝‍👨🏻' => 'runa iskay makikunawan: yana qara niraq, chuya qara niraq',
    '👨🏿‍🤝‍👨🏼' => 'runa iskay makikunawan: yana qara niraq, tunpa chuya qara niraq',
    '👨🏿‍🤝‍👨🏽' => 'runa iskay makikunawan: yana qara niraq, tunpa qara niraq',
    '👨🏿‍🤝‍👨🏾' => 'runa iskay makikunawan: yana qara niraq, tunpa yana qara niraq',
    '👩‍❤‍💋‍👨' => 'much’a: warmi, qari',
    '👨‍❤‍💋‍👨' => 'much’a: qari, qari',
    '👩‍❤‍💋‍👩' => 'much’a: warmi, warmi',
    '👨‍👩‍👧‍👦' => 'kuraq ayllu: qari, warmi, warmi warma, yuqalla',
    '👨‍👩‍👦‍👦' => 'kuraq ayllu: qari, warmi, yuqalla, yuqalla',
    '👨‍👩‍👧‍👧' => 'kuraq ayllu: qari, warmi, warmi warma, warmi warma',
    '👨‍👨‍👧‍👦' => 'kuraq ayllu: qari, qari, warmi warma, yuqalla',
    '👨‍👨‍👦‍👦' => 'kuraq ayllu: qari, qari, yuqalla, yuqalla',
    '👨‍👨‍👧‍👧' => 'kuraq ayllu: qari, qari, warmi warma, warmi warma',
    '👩‍👩‍👧‍👦' => 'kuraq ayllu: warmi, warmi, warmi warma, yuqalla',
    '👩‍👩‍👦‍👦' => 'kuraq ayllu: warmi, warmi, yuqalla, yuqalla',
    '👩‍👩‍👧‍👧' => 'kuraq ayllu: warmi, warmi, warmi warma, warmi warma',
    '🧑‍🧑‍🧒‍🧒' => 'ayllu: runa, runa, warma, warma',
    '🫱🏻‍🫲🏼' => 'pipuyasqa makikunapura: chuya qara niraq, tunpa chuya qara niraq',
    '🫱🏻‍🫲🏽' => 'pipuyasqa makikunapura: chuya qara niraq, tunpa qara niraq',
    '🫱🏻‍🫲🏾' => 'pipuyasqa makikunapura: chuya qara niraq, tunpa yana qara niraq',
    '🫱🏻‍🫲🏿' => 'pipuyasqa makikunapura: chuya qara niraq, yana qara niraq',
    '🫱🏼‍🫲🏻' => 'pipuyasqa makikunapura: tunpa chuya qara niraq, chuya qara niraq',
    '🫱🏼‍🫲🏽' => 'pipuyasqa makikunapura: tunpa chuya qara niraq, tunpa qara niraq',
    '🫱🏼‍🫲🏾' => 'pipuyasqa makikunapura: tunpa chuya qara niraq, tunpa yana qara niraq',
    '🫱🏼‍🫲🏿' => 'pipuyasqa makikunapura: tunpa chuya qara niraq, yana qara niraq',
    '🫱🏽‍🫲🏻' => 'pipuyasqa makikunapura: tunpa qara niraq, chuya qara niraq',
    '🫱🏽‍🫲🏼' => 'pipuyasqa makikunapura: tunpa qara niraq, tunpa chuya qara niraq',
    '🫱🏽‍🫲🏾' => 'pipuyasqa makikunapura: tunpa qara niraq, tunpa yana qara niraq',
    '🫱🏽‍🫲🏿' => 'pipuyasqa makikunapura: tunpa qara niraq, yana qara niraq',
    '🫱🏾‍🫲🏻' => 'pipuyasqa makikunapura: tunpa yana qara niraq, chuya qara niraq',
    '🫱🏾‍🫲🏼' => 'pipuyasqa makikunapura: tunpa yana qara niraq, tunpa chuya qara niraq',
    '🫱🏾‍🫲🏽' => 'pipuyasqa makikunapura: tunpa yana qara niraq, tunpa qara niraq',
    '🫱🏾‍🫲🏿' => 'pipuyasqa makikunapura: tunpa yana qara niraq, yana qara niraq',
    '🫱🏿‍🫲🏻' => 'pipuyasqa makikunapura: yana qara niraq, chuya qara niraq',
    '🫱🏿‍🫲🏼' => 'pipuyasqa makikunapura: yana qara niraq, tunpa chuya qara niraq',
    '🫱🏿‍🫲🏽' => 'pipuyasqa makikunapura: yana qara niraq, tunpa qara niraq',
    '🫱🏿‍🫲🏾' => 'pipuyasqa makikunapura: yana qara niraq, tunpa yana qara niraq',
    '👩‍❤‍👨' => 'pitu runakuna sunquwan: warmi, qari',
    '👨‍❤‍👨' => 'pitu runakuna sunquwan: qari, qari',
    '👩‍❤‍👩' => 'pitu runakuna sunquwan: warmi, warmi',
    '👨‍👩‍👦' => 'kuraq ayllu: qari, warmi, yuqalla',
    '👨‍👩‍👧' => 'kuraq ayllu: qari, warmi, warmi warma',
    '👨‍👨‍👦' => 'kuraq ayllu: qari, qari, yuqalla',
    '👨‍👨‍👧' => 'kuraq ayllu: qari, qari, warmi warma',
    '👩‍👩‍👦' => 'kuraq ayllu: warmi, warmi, yuqalla',
    '👩‍👩‍👧' => 'kuraq ayllu: warmi, warmi, warmi warma',
    '👨‍👦‍👦' => 'kuraq ayllu: qari, yuqalla, yuqalla',
    '👨‍👧‍👦' => 'kuraq ayllu: qari, warmi warma, yuqalla',
    '👨‍👧‍👧' => 'kuraq ayllu: qari, warmi warma, warmi warma',
    '👩‍👦‍👦' => 'kuraq ayllu: warmi, yuqalla, yuqalla',
    '👩‍👧‍👦' => 'kuraq ayllu: warmi, warmi warma, yuqalla',
    '👩‍👧‍👧' => 'kuraq ayllu: warmi, warmi warma, warmi warma',
    '🧑‍🤝‍🧑' => 'runakuna iskay makikunawan',
    '🧑‍🧑‍🧒' => 'ayllu: runa, runa, warma',
    '🧑‍🧒‍🧒' => 'ayllu: runa, warma, warma',
    '🧑🏻‍🦰' => 'runa: chuya qara niraq, puka chukcha',
    '🧑🏼‍🦰' => 'runa: tunpa chuya qara niraq, puka chukcha',
    '🧑🏽‍🦰' => 'runa: tunpa qara niraq, puka chukcha',
    '🧑🏾‍🦰' => 'runa: tunpa yana qara niraq, puka chukcha',
    '🧑🏿‍🦰' => 'runa: yana qara niraq, puka chukcha',
    '🧑🏻‍🦱' => 'runa: chuya qara niraq, qaspa chukcha',
    '🧑🏼‍🦱' => 'runa: tunpa chuya qara niraq, qaspa chukcha',
    '🧑🏽‍🦱' => 'runa: tunpa qara niraq, qaspa chukcha',
    '🧑🏾‍🦱' => 'runa: tunpa yana qara niraq, qaspa chukcha',
    '🧑🏿‍🦱' => 'runa: yana qara niraq, qaspa chukcha',
    '🧑🏻‍🦳' => 'runa: chuya qara niraq, yuraq chukcha',
    '🧑🏼‍🦳' => 'runa: tunpa chuya qara niraq, yuraq chukcha',
    '🧑🏽‍🦳' => 'runa: tunpa qara niraq, yuraq chukcha',
    '🧑🏾‍🦳' => 'runa: tunpa yana qara niraq, yuraq chukcha',
    '🧑🏿‍🦳' => 'runa: yana qara niraq, yuraq chukcha',
    '🧑🏻‍🦲' => 'runa: chuya qara niraq, paqla',
    '🧑🏼‍🦲' => 'runa: tunpa chuya qara niraq, paqla',
    '🧑🏽‍🦲' => 'runa: tunpa qara niraq, paqla',
    '🧑🏾‍🦲' => 'runa: tunpa yana qara niraq, paqla',
    '🧑🏿‍🦲' => 'runa: yana qara niraq, paqla',
    '🧑🏻‍🩰' => 'ballet tusuq: chuya qara niraq',
    '🧑🏼‍🩰' => 'ballet tusuq: tunpa chuya qara niraq',
    '🧑🏽‍🩰' => 'ballet tusuq: tunpa qara niraq',
    '🧑🏾‍🩰' => 'ballet tusuq: tunpa yana qara niraq',
    '🧑🏿‍🩰' => 'ballet tusuq: yana qara niraq',
    '🧔🏻‍♂' => 'qari: chuya qara niraq, kaki',
    '🧔🏼‍♂' => 'qari: tunpa chuya qara niraq, kaki',
    '🧔🏽‍♂' => 'qari: tunpa qara niraq, kaki',
    '🧔🏾‍♂' => 'qari: tunpa yana qara niraq, kaki',
    '🧔🏿‍♂' => 'qari: yana qara niraq, kaki',
    '👱🏻‍♂' => 'qari: chuya qara niraq, qillu chukcha',
    '👱🏼‍♂' => 'qari: tunpa chuya qara niraq, qillu chukcha',
    '👱🏽‍♂' => 'qari: tunpa qara niraq, qillu chukcha',
    '👱🏾‍♂' => 'qari: tunpa yana qara niraq, qillu chukcha',
    '👱🏿‍♂' => 'qari: yana qara niraq, qillu chukcha',
    '👨🏻‍🦰' => 'qari: chuya qara niraq, puka chukcha',
    '👨🏼‍🦰' => 'qari: tunpa chuya qara niraq, puka chukcha',
    '👨🏽‍🦰' => 'qari: tunpa qara niraq, puka chukcha',
    '👨🏾‍🦰' => 'qari: tunpa yana qara niraq, puka chukcha',
    '👨🏿‍🦰' => 'qari: yana qara niraq, puka chukcha',
    '👨🏻‍🦱' => 'qari: chuya qara niraq, qaspa chukcha',
    '👨🏼‍🦱' => 'qari: tunpa chuya qara niraq, qaspa chukcha',
    '👨🏽‍🦱' => 'qari: tunpa qara niraq, qaspa chukcha',
    '👨🏾‍🦱' => 'qari: tunpa yana qara niraq, qaspa chukcha',
    '👨🏿‍🦱' => 'qari: yana qara niraq, qaspa chukcha',
    '👨🏻‍🦳' => 'qari: chuya qara niraq, yuraq chukcha',
    '👨🏼‍🦳' => 'qari: tunpa chuya qara niraq, yuraq chukcha',
    '👨🏽‍🦳' => 'qari: tunpa qara niraq, yuraq chukcha',
    '👨🏾‍🦳' => 'qari: tunpa yana qara niraq, yuraq chukcha',
    '👨🏿‍🦳' => 'qari: yana qara niraq, yuraq chukcha',
    '👨🏻‍🦲' => 'qari: chuya qara niraq, paqla',
    '👨🏼‍🦲' => 'qari: tunpa chuya qara niraq, paqla',
    '👨🏽‍🦲' => 'qari: tunpa qara niraq, paqla',
    '👨🏾‍🦲' => 'qari: tunpa yana qara niraq, paqla',
    '👨🏿‍🦲' => 'qari: yana qara niraq, paqla',
    '🧔🏻‍♀' => 'warmi: chuya qara niraq, kʼaki',
    '🧔🏼‍♀' => 'warmi: tunpa chuya qara niraq, kʼaki',
    '🧔🏽‍♀' => 'warmi: tunpa qara niraq, kʼaki',
    '🧔🏾‍♀' => 'warmi: tunpa yana qara niraq, kʼaki',
    '🧔🏿‍♀' => 'warmi: yana qara niraq, kʼaki',
    '👱🏻‍♀' => 'warmi: chuya qara niraq, qʼillu chukcha',
    '👱🏼‍♀' => 'warmi: tunpa chuya qara niraq, qʼillu chukcha',
    '👱🏽‍♀' => 'warmi: tunpa qara niraq, qʼillu chukcha',
    '👱🏾‍♀' => 'warmi: tunpa yana qara niraq, qʼillu chukcha',
    '👱🏿‍♀' => 'warmi: yana qara niraq, qʼillu chukcha',
    '👩🏻‍🦰' => 'warmi: chuya qara niraq, puka chukcha',
    '👩🏼‍🦰' => 'warmi: tunpa chuya qara niraq, puka chukcha',
    '👩🏽‍🦰' => 'warmi: tunpa qara niraq, puka chukcha',
    '👩🏾‍🦰' => 'warmi: tunpa yana qara niraq, puka chukcha',
    '👩🏿‍🦰' => 'warmi: yana qara niraq, puka chukcha',
    '👩🏻‍🦱' => 'warmi: chuya qara niraq, qaspa chukcha',
    '👩🏼‍🦱' => 'warmi: tunpa chuya qara niraq, qaspa chukcha',
    '👩🏽‍🦱' => 'warmi: tunpa qara niraq, qaspa chukcha',
    '👩🏾‍🦱' => 'warmi: tunpa yana qara niraq, qaspa chukcha',
    '👩🏿‍🦱' => 'warmi: yana qara niraq, qaspa chukcha',
    '👩🏻‍🦳' => 'warmi: chuya qara niraq, yuraq chukcha',
    '👩🏼‍🦳' => 'warmi: tunpa chuya qara niraq, yuraq chukcha',
    '👩🏽‍🦳' => 'warmi: tunpa qara niraq, yuraq chukcha',
    '👩🏾‍🦳' => 'warmi: tunpa yana qara niraq, yuraq chukcha',
    '👩🏿‍🦳' => 'warmi: yana qara niraq, yuraq chukcha',
    '👩🏻‍🦲' => 'warmi: chuya qara niraq, paqla',
    '👩🏼‍🦲' => 'warmi: tunpa chuya qara niraq, paqla',
    '👩🏽‍🦲' => 'warmi: tunpa qara niraq, paqla',
    '👩🏾‍🦲' => 'warmi: tunpa yana qara niraq, paqla',
    '👩🏿‍🦲' => 'warmi: yana qara niraq, paqla',
    '🙍🏻‍♂' => 'llakisqa tata: chuya qara niraq',
    '🙍🏼‍♂' => 'llakisqa tata: tunpa chuya qara niraq',
    '🙍🏽‍♂' => 'llakisqa tata: tunpa qara niraq',
    '🙍🏾‍♂' => 'llakisqa tata: tunpa yana qara niraq',
    '🙍🏿‍♂' => 'llakisqa tata: yana qara niraq',
    '🙍🏻‍♀' => 'llakisqa warmi: chuya qara niraq',
    '🙍🏼‍♀' => 'llakisqa warmi: tunpa chuya qara niraq',
    '🙍🏽‍♀' => 'llakisqa warmi: tunpa qara niraq',
    '🙍🏾‍♀' => 'llakisqa warmi: tunpa yana qara niraq',
    '🙍🏿‍♀' => 'llakisqa warmi: yana qara niraq',
    '🙎🏻‍♂' => 'phiñachisqa tata: chuya qara niraq',
    '🙎🏼‍♂' => 'phiñachisqa tata: tunpa chuya qara niraq',
    '🙎🏽‍♂' => 'phiñachisqa tata: tunpa qara niraq',
    '🙎🏾‍♂' => 'phiñachisqa tata: tunpa yana qara niraq',
    '🙎🏿‍♂' => 'phiñachisqa tata: yana qara niraq',
    '🙎🏻‍♀' => 'phiñachisqa warmi: chuya qara niraq',
    '🙎🏼‍♀' => 'phiñachisqa warmi: tunpa chuya qara niraq',
    '🙎🏽‍♀' => 'phiñachisqa warmi: tunpa qara niraq',
    '🙎🏾‍♀' => 'phiñachisqa warmi: tunpa yana qara niraq',
    '🙎🏿‍♀' => 'phiñachisqa warmi: yana qara niraq',
    '🙅🏻‍♂' => 'tata MANA gestowan: chuya qara niraq',
    '🙅🏼‍♂' => 'tata MANA gestowan: tunpa chuya qara niraq',
    '🙅🏽‍♂' => 'tata MANA gestowan: tunpa qara niraq',
    '🙅🏾‍♂' => 'tata MANA gestowan: tunpa yana qara niraq',
    '🙅🏿‍♂' => 'tata MANA gestowan: yana qara niraq',
    '🙅🏻‍♀' => 'warmi MANA gestowan: chuya qara niraq',
    '🙅🏼‍♀' => 'warmi MANA gestowan: tunpa chuya qara niraq',
    '🙅🏽‍♀' => 'warmi MANA gestowan: tunpa qara niraq',
    '🙅🏾‍♀' => 'warmi MANA gestowan: tunpa yana qara niraq',
    '🙅🏿‍♀' => 'warmi MANA gestowan: yana qara niraq',
    '🙆🏻‍♂' => 'tata UYAKUY gestowan: chuya qara niraq',
    '🙆🏼‍♂' => 'tata UYAKUY gestowan: tunpa chuya qara niraq',
    '🙆🏽‍♂' => 'tata UYAKUY gestowan: tunpa qara niraq',
    '🙆🏾‍♂' => 'tata UYAKUY gestowan: tunpa yana qara niraq',
    '🙆🏿‍♂' => 'tata UYAKUY gestowan: yana qara niraq',
    '🙆🏻‍♀' => 'warmi UYAKUY gestowan: chuya qara niraq',
    '🙆🏼‍♀' => 'warmi UYAKUY gestowan: tunpa chuya qara niraq',
    '🙆🏽‍♀' => 'warmi UYAKUY gestowan: tunpa qara niraq',
    '🙆🏾‍♀' => 'warmi UYAKUY gestowan: tunpa yana qara niraq',
    '🙆🏿‍♀' => 'warmi UYAKUY gestowan: yana qara niraq',
    '💁🏻‍♂' => 'tata willakuy kitipi: chuya qara niraq',
    '💁🏼‍♂' => 'tata willakuy kitipi: tunpa chuya qara niraq',
    '💁🏽‍♂' => 'tata willakuy kitipi: tunpa qara niraq',
    '💁🏾‍♂' => 'tata willakuy kitipi: tunpa yana qara niraq',
    '💁🏿‍♂' => 'tata willakuy kitipi: yana qara niraq',
    '💁🏻‍♀' => 'warmi willakuy kitipi: chuya qara niraq',
    '💁🏼‍♀' => 'warmi willakuy kitipi: tunpa chuya qara niraq',
    '💁🏽‍♀' => 'warmi willakuy kitipi: tunpa qara niraq',
    '💁🏾‍♀' => 'warmi willakuy kitipi: tunpa yana qara niraq',
    '💁🏿‍♀' => 'warmi willakuy kitipi: yana qara niraq',
    '🙋🏻‍♂' => 'tata makita hatarichiy: chuya qara niraq',
    '🙋🏼‍♂' => 'tata makita hatarichiy: tunpa chuya qara niraq',
    '🙋🏽‍♂' => 'tata makita hatarichiy: tunpa qara niraq',
    '🙋🏾‍♂' => 'tata makita hatarichiy: tunpa yana qara niraq',
    '🙋🏿‍♂' => 'tata makita hatarichiy: yana qara niraq',
    '🙋🏻‍♀' => 'warmi makita hatarichiy: chuya qara niraq',
    '🙋🏼‍♀' => 'warmi makita hatarichiy: tunpa chuya qara niraq',
    '🙋🏽‍♀' => 'warmi makita hatarichiy: tunpa qara niraq',
    '🙋🏾‍♀' => 'warmi makita hatarichiy: tunpa yana qara niraq',
    '🙋🏿‍♀' => 'warmi makita hatarichiy: yana qara niraq',
    '🧏🏻‍♂' => 'ruqtʼu runa: chuya qara niraq',
    '🧏🏼‍♂' => 'ruqtʼu runa: tunpa chuya qara niraq',
    '🧏🏽‍♂' => 'ruqtʼu runa: tunpa qara niraq',
    '🧏🏾‍♂' => 'ruqtʼu runa: tunpa yana qara niraq',
    '🧏🏿‍♂' => 'ruqtʼu runa: yana qara niraq',
    '🧏🏻‍♀' => 'luqʼu warmi: chuya qara niraq',
    '🧏🏼‍♀' => 'luqʼu warmi: tunpa chuya qara niraq',
    '🧏🏽‍♀' => 'luqʼu warmi: tunpa qara niraq',
    '🧏🏾‍♀' => 'luqʼu warmi: tunpa yana qara niraq',
    '🧏🏿‍♀' => 'luqʼu warmi: yana qara niraq',
    '🙇🏻‍♂' => 'upaykusqa tata: chuya qara niraq',
    '🙇🏼‍♂' => 'upaykusqa tata: tunpa chuya qara niraq',
    '🙇🏽‍♂' => 'upaykusqa tata: tunpa qara niraq',
    '🙇🏾‍♂' => 'upaykusqa tata: tunpa yana qara niraq',
    '🙇🏿‍♂' => 'upaykusqa tata: yana qara niraq',
    '🙇🏻‍♀' => 'upaykusqa warmi: chuya qara niraq',
    '🙇🏼‍♀' => 'upaykusqa warmi: tunpa chuya qara niraq',
    '🙇🏽‍♀' => 'upaykusqa warmi: tunpa qara niraq',
    '🙇🏾‍♀' => 'upaykusqa warmi: tunpa yana qara niraq',
    '🙇🏿‍♀' => 'upaykusqa warmi: yana qara niraq',
    '🤦🏻‍♂' => 'tata makiwan uyapi: chuya qara niraq',
    '🤦🏼‍♂' => 'tata makiwan uyapi: tunpa chuya qara niraq',
    '🤦🏽‍♂' => 'tata makiwan uyapi: tunpa qara niraq',
    '🤦🏾‍♂' => 'tata makiwan uyapi: tunpa yana qara niraq',
    '🤦🏿‍♂' => 'tata makiwan uyapi: yana qara niraq',
    '🤦🏻‍♀' => 'warmi makian uyapi: chuya qara niraq',
    '🤦🏼‍♀' => 'warmi makian uyapi: tunpa chuya qara niraq',
    '🤦🏽‍♀' => 'warmi makian uyapi: tunpa qara niraq',
    '🤦🏾‍♀' => 'warmi makian uyapi: tunpa yana qara niraq',
    '🤦🏿‍♀' => 'warmi makian uyapi: yana qara niraq',
    '🤷🏻‍♂' => 'tata rikrakunayuq hatarichiy: chuya qara niraq',
    '🤷🏼‍♂' => 'tata rikrakunayuq hatarichiy: tunpa chuya qara niraq',
    '🤷🏽‍♂' => 'tata rikrakunayuq hatarichiy: tunpa qara niraq',
    '🤷🏾‍♂' => 'tata rikrakunayuq hatarichiy: tunpa yana qara niraq',
    '🤷🏿‍♂' => 'tata rikrakunayuq hatarichiy: yana qara niraq',
    '🤷🏻‍♀' => 'warmi rikrakunayuq hatarichiy: chuya qara niraq',
    '🤷🏼‍♀' => 'warmi rikrakunayuq hatarichiy: tunpa chuya qara niraq',
    '🤷🏽‍♀' => 'warmi rikrakunayuq hatarichiy: tunpa qara niraq',
    '🤷🏾‍♀' => 'warmi rikrakunayuq hatarichiy: tunpa yana qara niraq',
    '🤷🏿‍♀' => 'warmi rikrakunayuq hatarichiy: yana qara niraq',
    '🧑🏻‍⚕' => 'qhali kaywan llamkaq: chuya qara niraq',
    '🧑🏼‍⚕' => 'qhali kaywan llamkaq: tunpa chuya qara niraq',
    '🧑🏽‍⚕' => 'qhali kaywan llamkaq: tunpa qara niraq',
    '🧑🏾‍⚕' => 'qhali kaywan llamkaq: tunpa yana qara niraq',
    '🧑🏿‍⚕' => 'qhali kaywan llamkaq: yana qara niraq',
    '👨🏻‍⚕' => 'tata qhali kaywan llamkaq: chuya qara niraq',
    '👨🏼‍⚕' => 'tata qhali kaywan llamkaq: tunpa chuya qara niraq',
    '👨🏽‍⚕' => 'tata qhali kaywan llamkaq: tunpa qara niraq',
    '👨🏾‍⚕' => 'tata qhali kaywan llamkaq: tunpa yana qara niraq',
    '👨🏿‍⚕' => 'tata qhali kaywan llamkaq: yana qara niraq',
    '👩🏻‍⚕' => 'warmi qhali kaywan llamkaq: chuya qara niraq',
    '👩🏼‍⚕' => 'warmi qhali kaywan llamkaq: tunpa chuya qara niraq',
    '👩🏽‍⚕' => 'warmi qhali kaywan llamkaq: tunpa qara niraq',
    '👩🏾‍⚕' => 'warmi qhali kaywan llamkaq: tunpa yana qara niraq',
    '👩🏿‍⚕' => 'warmi qhali kaywan llamkaq: yana qara niraq',
    '🧑🏻‍🎓' => 'yachakuq: chuya qara niraq',
    '🧑🏼‍🎓' => 'yachakuq: tunpa chuya qara niraq',
    '🧑🏽‍🎓' => 'yachakuq: tunpa qara niraq',
    '🧑🏾‍🎓' => 'yachakuq: tunpa yana qara niraq',
    '🧑🏿‍🎓' => 'yachakuq: yana qara niraq',
    '👨🏻‍🎓' => 'tata yachakuq: chuya qara niraq',
    '👨🏼‍🎓' => 'tata yachakuq: tunpa chuya qara niraq',
    '👨🏽‍🎓' => 'tata yachakuq: tunpa qara niraq',
    '👨🏾‍🎓' => 'tata yachakuq: tunpa yana qara niraq',
    '👨🏿‍🎓' => 'tata yachakuq: yana qara niraq',
    '👩🏻‍🎓' => 'warmi yachakuq: chuya qara niraq',
    '👩🏼‍🎓' => 'warmi yachakuq: tunpa chuya qara niraq',
    '👩🏽‍🎓' => 'warmi yachakuq: tunpa qara niraq',
    '👩🏾‍🎓' => 'warmi yachakuq: tunpa yana qara niraq',
    '👩🏿‍🎓' => 'warmi yachakuq: yana qara niraq',
    '🧑🏻‍🏫' => 'maestro: chuya qara niraq',
    '🧑🏼‍🏫' => 'maestro: tunpa chuya qara niraq',
    '🧑🏽‍🏫' => 'maestro: tunpa qara niraq',
    '🧑🏾‍🏫' => 'maestro: tunpa yana qara niraq',
    '🧑🏿‍🏫' => 'maestro: yana qara niraq',
    '👨🏻‍🏫' => 'tata yachachiq: chuya qara niraq',
    '👨🏼‍🏫' => 'tata yachachiq: tunpa chuya qara niraq',
    '👨🏽‍🏫' => 'tata yachachiq: tunpa qara niraq',
    '👨🏾‍🏫' => 'tata yachachiq: tunpa yana qara niraq',
    '👨🏿‍🏫' => 'tata yachachiq: yana qara niraq',
    '👩🏻‍🏫' => 'warmi yachachiq: chuya qara niraq',
    '👩🏼‍🏫' => 'warmi yachachiq: tunpa chuya qara niraq',
    '👩🏽‍🏫' => 'warmi yachachiq: tunpa qara niraq',
    '👩🏾‍🏫' => 'warmi yachachiq: tunpa yana qara niraq',
    '👩🏿‍🏫' => 'warmi yachachiq: yana qara niraq',
    '🧑🏻‍⚖' => 'juez: chuya qara niraq',
    '🧑🏼‍⚖' => 'juez: tunpa chuya qara niraq',
    '🧑🏽‍⚖' => 'juez: tunpa qara niraq',
    '🧑🏾‍⚖' => 'juez: tunpa yana qara niraq',
    '🧑🏿‍⚖' => 'juez: yana qara niraq',
    '👨🏻‍⚖' => 'tata juez: chuya qara niraq',
    '👨🏼‍⚖' => 'tata juez: tunpa chuya qara niraq',
    '👨🏽‍⚖' => 'tata juez: tunpa qara niraq',
    '👨🏾‍⚖' => 'tata juez: tunpa yana qara niraq',
    '👨🏿‍⚖' => 'tata juez: yana qara niraq',
    '👩🏻‍⚖' => 'warmi jueza: chuya qara niraq',
    '👩🏼‍⚖' => 'warmi jueza: tunpa chuya qara niraq',
    '👩🏽‍⚖' => 'warmi jueza: tunpa qara niraq',
    '👩🏾‍⚖' => 'warmi jueza: tunpa yana qara niraq',
    '👩🏿‍⚖' => 'warmi jueza: yana qara niraq',
    '🧑🏻‍🌾' => 'granjero: chuya qara niraq',
    '🧑🏼‍🌾' => 'granjero: tunpa chuya qara niraq',
    '🧑🏽‍🌾' => 'granjero: tunpa qara niraq',
    '🧑🏾‍🌾' => 'granjero: tunpa yana qara niraq',
    '🧑🏿‍🌾' => 'granjero: yana qara niraq',
    '👨🏻‍🌾' => 'tata granjero: chuya qara niraq',
    '👨🏼‍🌾' => 'tata granjero: tunpa chuya qara niraq',
    '👨🏽‍🌾' => 'tata granjero: tunpa qara niraq',
    '👨🏾‍🌾' => 'tata granjero: tunpa yana qara niraq',
    '👨🏿‍🌾' => 'tata granjero: yana qara niraq',
    '👩🏻‍🌾' => 'warmi granjera: chuya qara niraq',
    '👩🏼‍🌾' => 'warmi granjera: tunpa chuya qara niraq',
    '👩🏽‍🌾' => 'warmi granjera: tunpa qara niraq',
    '👩🏾‍🌾' => 'warmi granjera: tunpa yana qara niraq',
    '👩🏿‍🌾' => 'warmi granjera: yana qara niraq',
    '🧑🏻‍🍳' => 'wayk’uq: chuya qara niraq',
    '🧑🏼‍🍳' => 'wayk’uq: tunpa chuya qara niraq',
    '🧑🏽‍🍳' => 'wayk’uq: tunpa qara niraq',
    '🧑🏾‍🍳' => 'wayk’uq: tunpa yana qara niraq',
    '🧑🏿‍🍳' => 'wayk’uq: yana qara niraq',
    '👨🏻‍🍳' => 'tata wayk’uq: chuya qara niraq',
    '👨🏼‍🍳' => 'tata wayk’uq: tunpa chuya qara niraq',
    '👨🏽‍🍳' => 'tata wayk’uq: tunpa qara niraq',
    '👨🏾‍🍳' => 'tata wayk’uq: tunpa yana qara niraq',
    '👨🏿‍🍳' => 'tata wayk’uq: yana qara niraq',
    '👩🏻‍🍳' => 'warmi wayk’uq: chuya qara niraq',
    '👩🏼‍🍳' => 'warmi wayk’uq: tunpa chuya qara niraq',
    '👩🏽‍🍳' => 'warmi wayk’uq: tunpa qara niraq',
    '👩🏾‍🍳' => 'warmi wayk’uq: tunpa yana qara niraq',
    '👩🏿‍🍳' => 'warmi wayk’uq: yana qara niraq',
    '🧑🏻‍🔧' => 'mecanico: chuya qara niraq',
    '🧑🏼‍🔧' => 'mecanico: tunpa chuya qara niraq',
    '🧑🏽‍🔧' => 'mecanico: tunpa qara niraq',
    '🧑🏾‍🔧' => 'mecanico: tunpa yana qara niraq',
    '🧑🏿‍🔧' => 'mecanico: yana qara niraq',
    '👨🏻‍🔧' => 'tata mecanico: chuya qara niraq',
    '👨🏼‍🔧' => 'tata mecanico: tunpa chuya qara niraq',
    '👨🏽‍🔧' => 'tata mecanico: tunpa qara niraq',
    '👨🏾‍🔧' => 'tata mecanico: tunpa yana qara niraq',
    '👨🏿‍🔧' => 'tata mecanico: yana qara niraq',
    '👩🏻‍🔧' => 'warmi mecanico: chuya qara niraq',
    '👩🏼‍🔧' => 'warmi mecanico: tunpa chuya qara niraq',
    '👩🏽‍🔧' => 'warmi mecanico: tunpa qara niraq',
    '👩🏾‍🔧' => 'warmi mecanico: tunpa yana qara niraq',
    '👩🏿‍🔧' => 'warmi mecanico: yana qara niraq',
    '🧑🏻‍🏭' => 'fabrica llamkaq: chuya qara niraq',
    '🧑🏼‍🏭' => 'fabrica llamkaq: tunpa chuya qara niraq',
    '🧑🏽‍🏭' => 'fabrica llamkaq: tunpa qara niraq',
    '🧑🏾‍🏭' => 'fabrica llamkaq: tunpa yana qara niraq',
    '🧑🏿‍🏭' => 'fabrica llamkaq: yana qara niraq',
    '👨🏻‍🏭' => 'tata fabrica llamkaq: chuya qara niraq',
    '👨🏼‍🏭' => 'tata fabrica llamkaq: tunpa chuya qara niraq',
    '👨🏽‍🏭' => 'tata fabrica llamkaq: tunpa qara niraq',
    '👨🏾‍🏭' => 'tata fabrica llamkaq: tunpa yana qara niraq',
    '👨🏿‍🏭' => 'tata fabrica llamkaq: yana qara niraq',
    '👩🏻‍🏭' => 'warmi fabrica llamkaq: chuya qara niraq',
    '👩🏼‍🏭' => 'warmi fabrica llamkaq: tunpa chuya qara niraq',
    '👩🏽‍🏭' => 'warmi fabrica llamkaq: tunpa qara niraq',
    '👩🏾‍🏭' => 'warmi fabrica llamkaq: tunpa yana qara niraq',
    '👩🏿‍🏭' => 'warmi fabrica llamkaq: yana qara niraq',
    '🧑🏻‍💼' => 'oficina llamkaq: chuya qara niraq',
    '🧑🏼‍💼' => 'oficina llamkaq: tunpa chuya qara niraq',
    '🧑🏽‍💼' => 'oficina llamkaq: tunpa qara niraq',
    '🧑🏾‍💼' => 'oficina llamkaq: tunpa yana qara niraq',
    '🧑🏿‍💼' => 'oficina llamkaq: yana qara niraq',
    '👨🏻‍💼' => 'tata oficina llamkaq: chuya qara niraq',
    '👨🏼‍💼' => 'tata oficina llamkaq: tunpa chuya qara niraq',
    '👨🏽‍💼' => 'tata oficina llamkaq: tunpa qara niraq',
    '👨🏾‍💼' => 'tata oficina llamkaq: tunpa yana qara niraq',
    '👨🏿‍💼' => 'tata oficina llamkaq: yana qara niraq',
    '👩🏻‍💼' => 'warmi oficina llamkaq: chuya qara niraq',
    '👩🏼‍💼' => 'warmi oficina llamkaq: tunpa chuya qara niraq',
    '👩🏽‍💼' => 'warmi oficina llamkaq: tunpa qara niraq',
    '👩🏾‍💼' => 'warmi oficina llamkaq: tunpa yana qara niraq',
    '👩🏿‍💼' => 'warmi oficina llamkaq: yana qara niraq',
    '🧑🏻‍🔬' => 'hamut’asqa: chuya qara niraq',
    '🧑🏼‍🔬' => 'hamut’asqa: tunpa chuya qara niraq',
    '🧑🏽‍🔬' => 'hamut’asqa: tunpa qara niraq',
    '🧑🏾‍🔬' => 'hamut’asqa: tunpa yana qara niraq',
    '🧑🏿‍🔬' => 'hamut’asqa: yana qara niraq',
    '👨🏻‍🔬' => 'tata hamut’asqa: chuya qara niraq',
    '👨🏼‍🔬' => 'tata hamut’asqa: tunpa chuya qara niraq',
    '👨🏽‍🔬' => 'tata hamut’asqa: tunpa qara niraq',
    '👨🏾‍🔬' => 'tata hamut’asqa: tunpa yana qara niraq',
    '👨🏿‍🔬' => 'tata hamut’asqa: yana qara niraq',
    '👩🏻‍🔬' => 'warmi hamut’asqa: chuya qara niraq',
    '👩🏼‍🔬' => 'warmi hamut’asqa: tunpa chuya qara niraq',
    '👩🏽‍🔬' => 'warmi hamut’asqa: tunpa qara niraq',
    '👩🏾‍🔬' => 'warmi hamut’asqa: tunpa yana qara niraq',
    '👩🏿‍🔬' => 'warmi hamut’asqa: yana qara niraq',
    '🧑🏻‍💻' => 'tecnico: chuya qara niraq',
    '🧑🏼‍💻' => 'tecnico: tunpa chuya qara niraq',
    '🧑🏽‍💻' => 'tecnico: tunpa qara niraq',
    '🧑🏾‍💻' => 'tecnico: tunpa yana qara niraq',
    '🧑🏿‍💻' => 'tecnico: yana qara niraq',
    '👨🏻‍💻' => 'tata tecnico: chuya qara niraq',
    '👨🏼‍💻' => 'tata tecnico: tunpa chuya qara niraq',
    '👨🏽‍💻' => 'tata tecnico: tunpa qara niraq',
    '👨🏾‍💻' => 'tata tecnico: tunpa yana qara niraq',
    '👨🏿‍💻' => 'tata tecnico: yana qara niraq',
    '👩🏻‍💻' => 'warmi tecnico: chuya qara niraq',
    '👩🏼‍💻' => 'warmi tecnico: tunpa chuya qara niraq',
    '👩🏽‍💻' => 'warmi tecnico: tunpa qara niraq',
    '👩🏾‍💻' => 'warmi tecnico: tunpa yana qara niraq',
    '👩🏿‍💻' => 'warmi tecnico: yana qara niraq',
    '🧑🏻‍🎤' => 'takiq: chuya qara niraq',
    '🧑🏼‍🎤' => 'takiq: tunpa chuya qara niraq',
    '🧑🏽‍🎤' => 'takiq: tunpa qara niraq',
    '🧑🏾‍🎤' => 'takiq: tunpa yana qara niraq',
    '🧑🏿‍🎤' => 'takiq: yana qara niraq',
    '👨🏻‍🎤' => 'tata takiq: chuya qara niraq',
    '👨🏼‍🎤' => 'tata takiq: tunpa chuya qara niraq',
    '👨🏽‍🎤' => 'tata takiq: tunpa qara niraq',
    '👨🏾‍🎤' => 'tata takiq: tunpa yana qara niraq',
    '👨🏿‍🎤' => 'tata takiq: yana qara niraq',
    '👩🏻‍🎤' => 'warmi takiq: chuya qara niraq',
    '👩🏼‍🎤' => 'warmi takiq: tunpa chuya qara niraq',
    '👩🏽‍🎤' => 'warmi takiq: tunpa qara niraq',
    '👩🏾‍🎤' => 'warmi takiq: tunpa yana qara niraq',
    '👩🏿‍🎤' => 'warmi takiq: yana qara niraq',
    '🧑🏻‍🎨' => 'llimpiq: chuya qara niraq',
    '🧑🏼‍🎨' => 'llimpiq: tunpa chuya qara niraq',
    '🧑🏽‍🎨' => 'llimpiq: tunpa qara niraq',
    '🧑🏾‍🎨' => 'llimpiq: tunpa yana qara niraq',
    '🧑🏿‍🎨' => 'llimpiq: yana qara niraq',
    '👨🏻‍🎨' => 'tata llimpiq: chuya qara niraq',
    '👨🏼‍🎨' => 'tata llimpiq: tunpa chuya qara niraq',
    '👨🏽‍🎨' => 'tata llimpiq: tunpa qara niraq',
    '👨🏾‍🎨' => 'tata llimpiq: tunpa yana qara niraq',
    '👨🏿‍🎨' => 'tata llimpiq: yana qara niraq',
    '👩🏻‍🎨' => 'warmi llimpiq: chuya qara niraq',
    '👩🏼‍🎨' => 'warmi llimpiq: tunpa chuya qara niraq',
    '👩🏽‍🎨' => 'warmi llimpiq: tunpa qara niraq',
    '👩🏾‍🎨' => 'warmi llimpiq: tunpa yana qara niraq',
    '👩🏿‍🎨' => 'warmi llimpiq: yana qara niraq',
    '🧑🏻‍✈' => 'piloto: chuya qara niraq',
    '🧑🏼‍✈' => 'piloto: tunpa chuya qara niraq',
    '🧑🏽‍✈' => 'piloto: tunpa qara niraq',
    '🧑🏾‍✈' => 'piloto: tunpa yana qara niraq',
    '🧑🏿‍✈' => 'piloto: yana qara niraq',
    '👨🏻‍✈' => 'tata piloto: chuya qara niraq',
    '👨🏼‍✈' => 'tata piloto: tunpa chuya qara niraq',
    '👨🏽‍✈' => 'tata piloto: tunpa qara niraq',
    '👨🏾‍✈' => 'tata piloto: tunpa yana qara niraq',
    '👨🏿‍✈' => 'tata piloto: yana qara niraq',
    '👩🏻‍✈' => 'warmi piloto: chuya qara niraq',
    '👩🏼‍✈' => 'warmi piloto: tunpa chuya qara niraq',
    '👩🏽‍✈' => 'warmi piloto: tunpa qara niraq',
    '👩🏾‍✈' => 'warmi piloto: tunpa yana qara niraq',
    '👩🏿‍✈' => 'warmi piloto: yana qara niraq',
    '🧑🏻‍🚀' => 'astronauta: chuya qara niraq',
    '🧑🏼‍🚀' => 'astronauta: tunpa chuya qara niraq',
    '🧑🏽‍🚀' => 'astronauta: tunpa qara niraq',
    '🧑🏾‍🚀' => 'astronauta: tunpa yana qara niraq',
    '🧑🏿‍🚀' => 'astronauta: yana qara niraq',
    '👨🏻‍🚀' => 'tata astronauta: chuya qara niraq',
    '👨🏼‍🚀' => 'tata astronauta: tunpa chuya qara niraq',
    '👨🏽‍🚀' => 'tata astronauta: tunpa qara niraq',
    '👨🏾‍🚀' => 'tata astronauta: tunpa yana qara niraq',
    '👨🏿‍🚀' => 'tata astronauta: yana qara niraq',
    '👩🏻‍🚀' => 'warmi astronauta: chuya qara niraq',
    '👩🏼‍🚀' => 'warmi astronauta: tunpa chuya qara niraq',
    '👩🏽‍🚀' => 'warmi astronauta: tunpa qara niraq',
    '👩🏾‍🚀' => 'warmi astronauta: tunpa yana qara niraq',
    '👩🏿‍🚀' => 'warmi astronauta: yana qara niraq',
    '🧑🏻‍🚒' => 'bombero: chuya qara niraq',
    '🧑🏼‍🚒' => 'bombero: tunpa chuya qara niraq',
    '🧑🏽‍🚒' => 'bombero: tunpa qara niraq',
    '🧑🏾‍🚒' => 'bombero: tunpa yana qara niraq',
    '🧑🏿‍🚒' => 'bombero: yana qara niraq',
    '👨🏻‍🚒' => 'tata bombero: chuya qara niraq',
    '👨🏼‍🚒' => 'tata bombero: tunpa chuya qara niraq',
    '👨🏽‍🚒' => 'tata bombero: tunpa qara niraq',
    '👨🏾‍🚒' => 'tata bombero: tunpa yana qara niraq',
    '👨🏿‍🚒' => 'tata bombero: yana qara niraq',
    '👩🏻‍🚒' => 'warmi bombera: chuya qara niraq',
    '👩🏼‍🚒' => 'warmi bombera: tunpa chuya qara niraq',
    '👩🏽‍🚒' => 'warmi bombera: tunpa qara niraq',
    '👩🏾‍🚒' => 'warmi bombera: tunpa yana qara niraq',
    '👩🏿‍🚒' => 'warmi bombera: yana qara niraq',
    '👮🏻‍♂' => 'tata policia: chuya qara niraq',
    '👮🏼‍♂' => 'tata policia: tunpa chuya qara niraq',
    '👮🏽‍♂' => 'tata policia: tunpa qara niraq',
    '👮🏾‍♂' => 'tata policia: tunpa yana qara niraq',
    '👮🏿‍♂' => 'tata policia: yana qara niraq',
    '👮🏻‍♀' => 'warmi policia: chuya qara niraq',
    '👮🏼‍♀' => 'warmi policia: tunpa chuya qara niraq',
    '👮🏽‍♀' => 'warmi policia: tunpa qara niraq',
    '👮🏾‍♀' => 'warmi policia: tunpa yana qara niraq',
    '👮🏿‍♀' => 'warmi policia: yana qara niraq',
    '🕵🏻‍♂' => 'tata qhamiyaq: chuya qara niraq',
    '🕵🏼‍♂' => 'tata qhamiyaq: tunpa chuya qara niraq',
    '🕵🏽‍♂' => 'tata qhamiyaq: tunpa qara niraq',
    '🕵🏾‍♂' => 'tata qhamiyaq: tunpa yana qara niraq',
    '🕵🏿‍♂' => 'tata qhamiyaq: yana qara niraq',
    '🕵🏻‍♀' => 'warmi qhamiyaq: chuya qara niraq',
    '🕵🏼‍♀' => 'warmi qhamiyaq: tunpa chuya qara niraq',
    '🕵🏽‍♀' => 'warmi qhamiyaq: tunpa qara niraq',
    '🕵🏾‍♀' => 'warmi qhamiyaq: tunpa yana qara niraq',
    '🕵🏿‍♀' => 'warmi qhamiyaq: yana qara niraq',
    '💂🏻‍♂' => 'tata guardia: chuya qara niraq',
    '💂🏼‍♂' => 'tata guardia: tunpa chuya qara niraq',
    '💂🏽‍♂' => 'tata guardia: tunpa qara niraq',
    '💂🏾‍♂' => 'tata guardia: tunpa yana qara niraq',
    '💂🏿‍♂' => 'tata guardia: yana qara niraq',
    '💂🏻‍♀' => 'warmi guardia: chuya qara niraq',
    '💂🏼‍♀' => 'warmi guardia: tunpa chuya qara niraq',
    '💂🏽‍♀' => 'warmi guardia: tunpa qara niraq',
    '💂🏾‍♀' => 'warmi guardia: tunpa yana qara niraq',
    '💂🏿‍♀' => 'warmi guardia: yana qara niraq',
    '👷🏻‍♂' => 'tata pirqaq: chuya qara niraq',
    '👷🏼‍♂' => 'tata pirqaq: tunpa chuya qara niraq',
    '👷🏽‍♂' => 'tata pirqaq: tunpa qara niraq',
    '👷🏾‍♂' => 'tata pirqaq: tunpa yana qara niraq',
    '👷🏿‍♂' => 'tata pirqaq: yana qara niraq',
    '👷🏻‍♀' => 'warmi pirqaq: chuya qara niraq',
    '👷🏼‍♀' => 'warmi pirqaq: tunpa chuya qara niraq',
    '👷🏽‍♀' => 'warmi pirqaq: tunpa qara niraq',
    '👷🏾‍♀' => 'warmi pirqaq: tunpa yana qara niraq',
    '👷🏿‍♀' => 'warmi pirqaq: yana qara niraq',
    '👳🏻‍♂' => 'tata turbantewan: chuya qara niraq',
    '👳🏼‍♂' => 'tata turbantewan: tunpa chuya qara niraq',
    '👳🏽‍♂' => 'tata turbantewan: tunpa qara niraq',
    '👳🏾‍♂' => 'tata turbantewan: tunpa yana qara niraq',
    '👳🏿‍♂' => 'tata turbantewan: yana qara niraq',
    '👳🏻‍♀' => 'warmi turbantewan: chuya qara niraq',
    '👳🏼‍♀' => 'warmi turbantewan: tunpa chuya qara niraq',
    '👳🏽‍♀' => 'warmi turbantewan: tunpa qara niraq',
    '👳🏾‍♀' => 'warmi turbantewan: tunpa yana qara niraq',
    '👳🏿‍♀' => 'warmi turbantewan: yana qara niraq',
    '🤵🏻‍♂' => 'runa esmoquinwan: chuya qara niraq',
    '🤵🏼‍♂' => 'runa esmoquinwan: tunpa chuya qara niraq',
    '🤵🏽‍♂' => 'runa esmoquinwan: tunpa qara niraq',
    '🤵🏾‍♂' => 'runa esmoquinwan: tunpa yana qara niraq',
    '🤵🏿‍♂' => 'runa esmoquinwan: yana qara niraq',
    '🤵🏻‍♀' => 'warmi tuxedopi: chuya qara niraq',
    '🤵🏼‍♀' => 'warmi tuxedopi: tunpa chuya qara niraq',
    '🤵🏽‍♀' => 'warmi tuxedopi: tunpa qara niraq',
    '🤵🏾‍♀' => 'warmi tuxedopi: tunpa yana qara niraq',
    '🤵🏿‍♀' => 'warmi tuxedopi: yana qara niraq',
    '👰🏻‍♂' => 'runa velopi: chuya qara niraq',
    '👰🏼‍♂' => 'runa velopi: tunpa chuya qara niraq',
    '👰🏽‍♂' => 'runa velopi: tunpa qara niraq',
    '👰🏾‍♂' => 'runa velopi: tunpa yana qara niraq',
    '👰🏿‍♂' => 'runa velopi: yana qara niraq',
    '👰🏻‍♀' => 'warmi velopi: chuya qara niraq',
    '👰🏼‍♀' => 'warmi velopi: tunpa chuya qara niraq',
    '👰🏽‍♀' => 'warmi velopi: tunpa qara niraq',
    '👰🏾‍♀' => 'warmi velopi: tunpa yana qara niraq',
    '👰🏿‍♀' => 'warmi velopi: yana qara niraq',
    '👩🏻‍🍼' => 'warmi wawata ñuñuchichkan: chuya qara niraq',
    '👩🏼‍🍼' => 'warmi wawata ñuñuchichkan: tunpa chuya qara niraq',
    '👩🏽‍🍼' => 'warmi wawata ñuñuchichkan: tunpa qara niraq',
    '👩🏾‍🍼' => 'warmi wawata ñuñuchichkan: tunpa yana qara niraq',
    '👩🏿‍🍼' => 'warmi wawata ñuñuchichkan: yana qara niraq',
    '👨🏻‍🍼' => 'runa wawata ñuñuchichkan: chuya qara niraq',
    '👨🏼‍🍼' => 'runa wawata ñuñuchichkan: tunpa chuya qara niraq',
    '👨🏽‍🍼' => 'runa wawata ñuñuchichkan: tunpa qara niraq',
    '👨🏾‍🍼' => 'runa wawata ñuñuchichkan: tunpa yana qara niraq',
    '👨🏿‍🍼' => 'runa wawata ñuñuchichkan: yana qara niraq',
    '🧑🏻‍🍼' => 'runa wawawan ñuñuchichkan: chuya qara niraq',
    '🧑🏼‍🍼' => 'runa wawawan ñuñuchichkan: tunpa chuya qara niraq',
    '🧑🏽‍🍼' => 'runa wawawan ñuñuchichkan: tunpa qara niraq',
    '🧑🏾‍🍼' => 'runa wawawan ñuñuchichkan: tunpa yana qara niraq',
    '🧑🏿‍🍼' => 'runa wawawan ñuñuchichkan: yana qara niraq',
    '🧑🏻‍🎄' => 'mx claus: chuya qara niraq',
    '🧑🏼‍🎄' => 'mx claus: tunpa chuya qara niraq',
    '🧑🏽‍🎄' => 'mx claus: tunpa qara niraq',
    '🧑🏾‍🎄' => 'mx claus: tunpa yana qara niraq',
    '🧑🏿‍🎄' => 'mx claus: yana qara niraq',
    '🦸🏻‍♂' => 'runa superheroe: chuya qara niraq',
    '🦸🏼‍♂' => 'runa superheroe: tunpa chuya qara niraq',
    '🦸🏽‍♂' => 'runa superheroe: tunpa qara niraq',
    '🦸🏾‍♂' => 'runa superheroe: tunpa yana qara niraq',
    '🦸🏿‍♂' => 'runa superheroe: yana qara niraq',
    '🦸🏻‍♀' => 'warmi superheroe: chuya qara niraq',
    '🦸🏼‍♀' => 'warmi superheroe: tunpa chuya qara niraq',
    '🦸🏽‍♀' => 'warmi superheroe: tunpa qara niraq',
    '🦸🏾‍♀' => 'warmi superheroe: tunpa yana qara niraq',
    '🦸🏿‍♀' => 'warmi superheroe: yana qara niraq',
    '🦹🏻‍♂' => 'runa supervillano: chuya qara niraq',
    '🦹🏼‍♂' => 'runa supervillano: tunpa chuya qara niraq',
    '🦹🏽‍♂' => 'runa supervillano: tunpa qara niraq',
    '🦹🏾‍♂' => 'runa supervillano: tunpa yana qara niraq',
    '🦹🏿‍♂' => 'runa supervillano: yana qara niraq',
    '🦹🏻‍♀' => 'warmi supervillana: chuya qara niraq',
    '🦹🏼‍♀' => 'warmi supervillana: tunpa chuya qara niraq',
    '🦹🏽‍♀' => 'warmi supervillana: tunpa qara niraq',
    '🦹🏾‍♀' => 'warmi supervillana: tunpa yana qara niraq',
    '🦹🏿‍♀' => 'warmi supervillana: yana qara niraq',
    '🧙🏻‍♂' => 'tata watuq: chuya qara niraq',
    '🧙🏼‍♂' => 'tata watuq: tunpa chuya qara niraq',
    '🧙🏽‍♂' => 'tata watuq: tunpa qara niraq',
    '🧙🏾‍♂' => 'tata watuq: tunpa yana qara niraq',
    '🧙🏿‍♂' => 'tata watuq: yana qara niraq',
    '🧙🏻‍♀' => 'warmi watuq: chuya qara niraq',
    '🧙🏼‍♀' => 'warmi watuq: tunpa chuya qara niraq',
    '🧙🏽‍♀' => 'warmi watuq: tunpa qara niraq',
    '🧙🏾‍♀' => 'warmi watuq: tunpa yana qara niraq',
    '🧙🏿‍♀' => 'warmi watuq: yana qara niraq',
    '🧚🏻‍♂' => 'tata hada: chuya qara niraq',
    '🧚🏼‍♂' => 'tata hada: tunpa chuya qara niraq',
    '🧚🏽‍♂' => 'tata hada: tunpa qara niraq',
    '🧚🏾‍♂' => 'tata hada: tunpa yana qara niraq',
    '🧚🏿‍♂' => 'tata hada: yana qara niraq',
    '🧚🏻‍♀' => 'warmi hada: chuya qara niraq',
    '🧚🏼‍♀' => 'warmi hada: tunpa chuya qara niraq',
    '🧚🏽‍♀' => 'warmi hada: tunpa qara niraq',
    '🧚🏾‍♀' => 'warmi hada: tunpa yana qara niraq',
    '🧚🏿‍♀' => 'warmi hada: yana qara niraq',
    '🧛🏻‍♂' => 'tata vampiro: chuya qara niraq',
    '🧛🏼‍♂' => 'tata vampiro: tunpa chuya qara niraq',
    '🧛🏽‍♂' => 'tata vampiro: tunpa qara niraq',
    '🧛🏾‍♂' => 'tata vampiro: tunpa yana qara niraq',
    '🧛🏿‍♂' => 'tata vampiro: yana qara niraq',
    '🧛🏻‍♀' => 'warmi vampiro: chuya qara niraq',
    '🧛🏼‍♀' => 'warmi vampiro: tunpa chuya qara niraq',
    '🧛🏽‍♀' => 'warmi vampiro: tunpa qara niraq',
    '🧛🏾‍♀' => 'warmi vampiro: tunpa yana qara niraq',
    '🧛🏿‍♀' => 'warmi vampiro: yana qara niraq',
    '🧜🏻‍♂' => 'tata triton: chuya qara niraq',
    '🧜🏼‍♂' => 'tata triton: tunpa chuya qara niraq',
    '🧜🏽‍♂' => 'tata triton: tunpa qara niraq',
    '🧜🏾‍♂' => 'tata triton: tunpa yana qara niraq',
    '🧜🏿‍♂' => 'tata triton: yana qara niraq',
    '🧜🏻‍♀' => 'sirena: chuya qara niraq',
    '🧜🏼‍♀' => 'sirena: tunpa chuya qara niraq',
    '🧜🏽‍♀' => 'sirena: tunpa qara niraq',
    '🧜🏾‍♀' => 'sirena: tunpa yana qara niraq',
    '🧜🏿‍♀' => 'sirena: yana qara niraq',
    '🧝🏻‍♂' => 'tata elfo: chuya qara niraq',
    '🧝🏼‍♂' => 'tata elfo: tunpa chuya qara niraq',
    '🧝🏽‍♂' => 'tata elfo: tunpa qara niraq',
    '🧝🏾‍♂' => 'tata elfo: tunpa yana qara niraq',
    '🧝🏿‍♂' => 'tata elfo: yana qara niraq',
    '🧝🏻‍♀' => 'warmi elfo: chuya qara niraq',
    '🧝🏼‍♀' => 'warmi elfo: tunpa chuya qara niraq',
    '🧝🏽‍♀' => 'warmi elfo: tunpa qara niraq',
    '🧝🏾‍♀' => 'warmi elfo: tunpa yana qara niraq',
    '🧝🏿‍♀' => 'warmi elfo: yana qara niraq',
    '💆🏻‍♂' => 'tata masaje uyapi: chuya qara niraq',
    '💆🏼‍♂' => 'tata masaje uyapi: tunpa chuya qara niraq',
    '💆🏽‍♂' => 'tata masaje uyapi: tunpa qara niraq',
    '💆🏾‍♂' => 'tata masaje uyapi: tunpa yana qara niraq',
    '💆🏿‍♂' => 'tata masaje uyapi: yana qara niraq',
    '💆🏻‍♀' => 'warmi masaje uyapi: chuya qara niraq',
    '💆🏼‍♀' => 'warmi masaje uyapi: tunpa chuya qara niraq',
    '💆🏽‍♀' => 'warmi masaje uyapi: tunpa qara niraq',
    '💆🏾‍♀' => 'warmi masaje uyapi: tunpa yana qara niraq',
    '💆🏿‍♀' => 'warmi masaje uyapi: yana qara niraq',
    '💇🏻‍♂' => 'tata chukcha rutukuy: chuya qara niraq',
    '💇🏼‍♂' => 'tata chukcha rutukuy: tunpa chuya qara niraq',
    '💇🏽‍♂' => 'tata chukcha rutukuy: tunpa qara niraq',
    '💇🏾‍♂' => 'tata chukcha rutukuy: tunpa yana qara niraq',
    '💇🏿‍♂' => 'tata chukcha rutukuy: yana qara niraq',
    '💇🏻‍♀' => 'warmi chukcha rutukuy: chuya qara niraq',
    '💇🏼‍♀' => 'warmi chukcha rutukuy: tunpa chuya qara niraq',
    '💇🏽‍♀' => 'warmi chukcha rutukuy: tunpa qara niraq',
    '💇🏾‍♀' => 'warmi chukcha rutukuy: tunpa yana qara niraq',
    '💇🏿‍♀' => 'warmi chukcha rutukuy: yana qara niraq',
    '🚶🏻‍♂' => 'tata purichkan: chuya qara niraq',
    '🚶🏼‍♂' => 'tata purichkan: tunpa chuya qara niraq',
    '🚶🏽‍♂' => 'tata purichkan: tunpa qara niraq',
    '🚶🏾‍♂' => 'tata purichkan: tunpa yana qara niraq',
    '🚶🏿‍♂' => 'tata purichkan: yana qara niraq',
    '🚶🏻‍♀' => 'warmi purichkan: chuya qara niraq',
    '🚶🏼‍♀' => 'warmi purichkan: tunpa chuya qara niraq',
    '🚶🏽‍♀' => 'warmi purichkan: tunpa qara niraq',
    '🚶🏾‍♀' => 'warmi purichkan: tunpa yana qara niraq',
    '🚶🏿‍♀' => 'warmi purichkan: yana qara niraq',
    '🧍🏻‍♂' => 'tata sayariy: chuya qara niraq',
    '🧍🏼‍♂' => 'tata sayariy: tunpa chuya qara niraq',
    '🧍🏽‍♂' => 'tata sayariy: tunpa qara niraq',
    '🧍🏾‍♂' => 'tata sayariy: tunpa yana qara niraq',
    '🧍🏿‍♂' => 'tata sayariy: yana qara niraq',
    '🧍🏻‍♀' => 'warmi sayariy: chuya qara niraq',
    '🧍🏼‍♀' => 'warmi sayariy: tunpa chuya qara niraq',
    '🧍🏽‍♀' => 'warmi sayariy: tunpa qara niraq',
    '🧍🏾‍♀' => 'warmi sayariy: tunpa yana qara niraq',
    '🧍🏿‍♀' => 'warmi sayariy: yana qara niraq',
    '🧎🏻‍♂' => 'qunqurisqa tata: chuya qara niraq',
    '🧎🏼‍♂' => 'qunqurisqa tata: tunpa chuya qara niraq',
    '🧎🏽‍♂' => 'qunqurisqa tata: tunpa qara niraq',
    '🧎🏾‍♂' => 'qunqurisqa tata: tunpa yana qara niraq',
    '🧎🏿‍♂' => 'qunqurisqa tata: yana qara niraq',
    '🧎🏻‍♀' => 'qunqurisqa warmi: chuya qara niraq',
    '🧎🏼‍♀' => 'qunqurisqa warmi: tunpa chuya qara niraq',
    '🧎🏽‍♀' => 'qunqurisqa warmi: tunpa qara niraq',
    '🧎🏾‍♀' => 'qunqurisqa warmi: tunpa yana qara niraq',
    '🧎🏿‍♀' => 'qunqurisqa warmi: yana qara niraq',
    '🧑🏻‍🦯' => 'runa yuraq cañawan: chuya qara niraq',
    '🧑🏼‍🦯' => 'runa yuraq cañawan: tunpa chuya qara niraq',
    '🧑🏽‍🦯' => 'runa yuraq cañawan: tunpa qara niraq',
    '🧑🏾‍🦯' => 'runa yuraq cañawan: tunpa yana qara niraq',
    '🧑🏿‍🦯' => 'runa yuraq cañawan: yana qara niraq',
    '👨🏻‍🦯' => 'runa yuraq warrawan: chuya qara niraq',
    '👨🏼‍🦯' => 'runa yuraq warrawan: tunpa chuya qara niraq',
    '👨🏽‍🦯' => 'runa yuraq warrawan: tunpa qara niraq',
    '👨🏾‍🦯' => 'runa yuraq warrawan: tunpa yana qara niraq',
    '👨🏿‍🦯' => 'runa yuraq warrawan: yana qara niraq',
    '👩🏻‍🦯' => 'warmi yuraq cañawan: chuya qara niraq',
    '👩🏼‍🦯' => 'warmi yuraq cañawan: tunpa chuya qara niraq',
    '👩🏽‍🦯' => 'warmi yuraq cañawan: tunpa qara niraq',
    '👩🏾‍🦯' => 'warmi yuraq cañawan: tunpa yana qara niraq',
    '👩🏿‍🦯' => 'warmi yuraq cañawan: yana qara niraq',
    '🧑🏻‍🦼' => 'runa motorizado silla de ruedas nisqapi: chuya qara niraq',
    '🧑🏼‍🦼' => 'runa motorizado silla de ruedas nisqapi: tunpa chuya qara niraq',
    '🧑🏽‍🦼' => 'runa motorizado silla de ruedas nisqapi: tunpa qara niraq',
    '🧑🏾‍🦼' => 'runa motorizado silla de ruedas nisqapi: tunpa yana qara niraq',
    '🧑🏿‍🦼' => 'runa motorizado silla de ruedas nisqapi: yana qara niraq',
    '👨🏻‍🦼' => 'runa motorizado silla de ruedas nisqawan: chuya qara niraq',
    '👨🏼‍🦼' => 'runa motorizado silla de ruedas nisqawan: tunpa chuya qara niraq',
    '👨🏽‍🦼' => 'runa motorizado silla de ruedas nisqawan: tunpa qara niraq',
    '👨🏾‍🦼' => 'runa motorizado silla de ruedas nisqawan: tunpa yana qara niraq',
    '👨🏿‍🦼' => 'runa motorizado silla de ruedas nisqawan: yana qara niraq',
    '👩🏻‍🦼' => 'warmi motorizado silla de ruedaspi: chuya qara niraq',
    '👩🏼‍🦼' => 'warmi motorizado silla de ruedaspi: tunpa chuya qara niraq',
    '👩🏽‍🦼' => 'warmi motorizado silla de ruedaspi: tunpa qara niraq',
    '👩🏾‍🦼' => 'warmi motorizado silla de ruedaspi: tunpa yana qara niraq',
    '👩🏿‍🦼' => 'warmi motorizado silla de ruedaspi: yana qara niraq',
    '🧑🏻‍🦽' => 'runa manual silla de ruedaspi: chuya qara niraq',
    '🧑🏼‍🦽' => 'runa manual silla de ruedaspi: tunpa chuya qara niraq',
    '🧑🏽‍🦽' => 'runa manual silla de ruedaspi: tunpa qara niraq',
    '🧑🏾‍🦽' => 'runa manual silla de ruedaspi: tunpa yana qara niraq',
    '🧑🏿‍🦽' => 'runa manual silla de ruedaspi: yana qara niraq',
    '👨🏻‍🦽' => 'runa manual silla de ruedas nisqapi: chuya qara niraq',
    '👨🏼‍🦽' => 'runa manual silla de ruedas nisqapi: tunpa chuya qara niraq',
    '👨🏽‍🦽' => 'runa manual silla de ruedas nisqapi: tunpa qara niraq',
    '👨🏾‍🦽' => 'runa manual silla de ruedas nisqapi: tunpa yana qara niraq',
    '👨🏿‍🦽' => 'runa manual silla de ruedas nisqapi: yana qara niraq',
    '👩🏻‍🦽' => 'warmi manual silla de ruedas: chuya qara niraq',
    '👩🏼‍🦽' => 'warmi manual silla de ruedas: tunpa chuya qara niraq',
    '👩🏽‍🦽' => 'warmi manual silla de ruedas: tunpa qara niraq',
    '👩🏾‍🦽' => 'warmi manual silla de ruedas: tunpa yana qara niraq',
    '👩🏿‍🦽' => 'warmi manual silla de ruedas: yana qara niraq',
    '🏃🏻‍♂' => 'tata phawachkan: chuya qara niraq',
    '🏃🏼‍♂' => 'tata phawachkan: tunpa chuya qara niraq',
    '🏃🏽‍♂' => 'tata phawachkan: tunpa qara niraq',
    '🏃🏾‍♂' => 'tata phawachkan: tunpa yana qara niraq',
    '🏃🏿‍♂' => 'tata phawachkan: yana qara niraq',
    '🏃🏻‍♀' => 'warmi phawachkan: chuya qara niraq',
    '🏃🏼‍♀' => 'warmi phawachkan: tunpa chuya qara niraq',
    '🏃🏽‍♀' => 'warmi phawachkan: tunpa qara niraq',
    '🏃🏾‍♀' => 'warmi phawachkan: tunpa yana qara niraq',
    '🏃🏿‍♀' => 'warmi phawachkan: yana qara niraq',
    '👯🏻‍♀' => 'warmi quwi ninrikunawan: chuya qara niraq',
    '👯🏼‍♀' => 'warmi quwi ninrikunawan: tunpa chuya qara niraq',
    '👯🏽‍♀' => 'warmi quwi ninrikunawan: tunpa qara niraq',
    '👯🏾‍♀' => 'warmi quwi ninrikunawan: tunpa yana qara niraq',
    '👯🏿‍♀' => 'warmi quwi ninrikunawan: yana qara niraq',
    '👯🏻‍♂' => 'runa quwi ninrikunawan: chuya qara niraq',
    '👯🏼‍♂' => 'runa quwi ninrikunawan: tunpa chuya qara niraq',
    '👯🏽‍♂' => 'runa quwi ninrikunawan: tunpa qara niraq',
    '👯🏾‍♂' => 'runa quwi ninrikunawan: tunpa yana qara niraq',
    '👯🏿‍♂' => 'runa quwi ninrikunawan: yana qara niraq',
    '🧖🏻‍♂' => 'tata wapsi wasipi: chuya qara niraq',
    '🧖🏼‍♂' => 'tata wapsi wasipi: tunpa chuya qara niraq',
    '🧖🏽‍♂' => 'tata wapsi wasipi: tunpa qara niraq',
    '🧖🏾‍♂' => 'tata wapsi wasipi: tunpa yana qara niraq',
    '🧖🏿‍♂' => 'tata wapsi wasipi: yana qara niraq',
    '🧖🏻‍♀' => 'warmi wapsi wasipi: chuya qara niraq',
    '🧖🏼‍♀' => 'warmi wapsi wasipi: tunpa chuya qara niraq',
    '🧖🏽‍♀' => 'warmi wapsi wasipi: tunpa qara niraq',
    '🧖🏾‍♀' => 'warmi wapsi wasipi: tunpa yana qara niraq',
    '🧖🏿‍♀' => 'warmi wapsi wasipi: yana qara niraq',
    '🧗🏻‍♂' => 'wichaq tata: chuya qara niraq',
    '🧗🏼‍♂' => 'wichaq tata: tunpa chuya qara niraq',
    '🧗🏽‍♂' => 'wichaq tata: tunpa qara niraq',
    '🧗🏾‍♂' => 'wichaq tata: tunpa yana qara niraq',
    '🧗🏿‍♂' => 'wichaq tata: yana qara niraq',
    '🧗🏻‍♀' => 'wichaq warmi: chuya qara niraq',
    '🧗🏼‍♀' => 'wichaq warmi: tunpa chuya qara niraq',
    '🧗🏽‍♀' => 'wichaq warmi: tunpa qara niraq',
    '🧗🏾‍♀' => 'wichaq warmi: tunpa yana qara niraq',
    '🧗🏿‍♀' => 'wichaq warmi: yana qara niraq',
    '🏌🏻‍♂' => 'tata golfista: chuya qara niraq',
    '🏌🏼‍♂' => 'tata golfista: tunpa chuya qara niraq',
    '🏌🏽‍♂' => 'tata golfista: tunpa qara niraq',
    '🏌🏾‍♂' => 'tata golfista: tunpa yana qara niraq',
    '🏌🏿‍♂' => 'tata golfista: yana qara niraq',
    '🏌🏻‍♀' => 'warmi golfista: chuya qara niraq',
    '🏌🏼‍♀' => 'warmi golfista: tunpa chuya qara niraq',
    '🏌🏽‍♀' => 'warmi golfista: tunpa qara niraq',
    '🏌🏾‍♀' => 'warmi golfista: tunpa yana qara niraq',
    '🏌🏿‍♀' => 'warmi golfista: yana qara niraq',
    '🏄🏻‍♂' => 'tata surfeando: chuya qara niraq',
    '🏄🏼‍♂' => 'tata surfeando: tunpa chuya qara niraq',
    '🏄🏽‍♂' => 'tata surfeando: tunpa qara niraq',
    '🏄🏾‍♂' => 'tata surfeando: tunpa yana qara niraq',
    '🏄🏿‍♂' => 'tata surfeando: yana qara niraq',
    '🏄🏻‍♀' => 'warmi surfeando: chuya qara niraq',
    '🏄🏼‍♀' => 'warmi surfeando: tunpa chuya qara niraq',
    '🏄🏽‍♀' => 'warmi surfeando: tunpa qara niraq',
    '🏄🏾‍♀' => 'warmi surfeando: tunpa yana qara niraq',
    '🏄🏿‍♀' => 'warmi surfeando: yana qara niraq',
    '🚣🏻‍♂' => 'runa wampʼu remoswan: chuya qara niraq',
    '🚣🏼‍♂' => 'runa wampʼu remoswan: tunpa chuya qara niraq',
    '🚣🏽‍♂' => 'runa wampʼu remoswan: tunpa qara niraq',
    '🚣🏾‍♂' => 'runa wampʼu remoswan: tunpa yana qara niraq',
    '🚣🏿‍♂' => 'runa wampʼu remoswan: yana qara niraq',
    '🚣🏻‍♀' => 'warmi wampʼu remoswan: chuya qara niraq',
    '🚣🏼‍♀' => 'warmi wampʼu remoswan: tunpa chuya qara niraq',
    '🚣🏽‍♀' => 'warmi wampʼu remoswan: tunpa qara niraq',
    '🚣🏾‍♀' => 'warmi wampʼu remoswan: tunpa yana qara niraq',
    '🚣🏿‍♀' => 'warmi wampʼu remoswan: yana qara niraq',
    '🏊🏻‍♂' => 'tata waytachkan: chuya qara niraq',
    '🏊🏼‍♂' => 'tata waytachkan: tunpa chuya qara niraq',
    '🏊🏽‍♂' => 'tata waytachkan: tunpa qara niraq',
    '🏊🏾‍♂' => 'tata waytachkan: tunpa yana qara niraq',
    '🏊🏿‍♂' => 'tata waytachkan: yana qara niraq',
    '🏊🏻‍♀' => 'warmi waytachkan: chuya qara niraq',
    '🏊🏼‍♀' => 'warmi waytachkan: tunpa chuya qara niraq',
    '🏊🏽‍♀' => 'warmi waytachkan: tunpa qara niraq',
    '🏊🏾‍♀' => 'warmi waytachkan: tunpa yana qara niraq',
    '🏊🏿‍♀' => 'warmi waytachkan: yana qara niraq',
    '⛹🏻‍♂' => 'tata p’uluta chuqapachkan: chuya qara niraq',
    '⛹🏼‍♂' => 'tata p’uluta chuqapachkan: tunpa chuya qara niraq',
    '⛹🏽‍♂' => 'tata p’uluta chuqapachkan: tunpa qara niraq',
    '⛹🏾‍♂' => 'tata p’uluta chuqapachkan: tunpa yana qara niraq',
    '⛹🏿‍♂' => 'tata p’uluta chuqapachkan: yana qara niraq',
    '⛹🏻‍♀' => 'warmi p’uluta chuqapachkan: chuya qara niraq',
    '⛹🏼‍♀' => 'warmi p’uluta chuqapachkan: tunpa chuya qara niraq',
    '⛹🏽‍♀' => 'warmi p’uluta chuqapachkan: tunpa qara niraq',
    '⛹🏾‍♀' => 'warmi p’uluta chuqapachkan: tunpa yana qara niraq',
    '⛹🏿‍♀' => 'warmi p’uluta chuqapachkan: yana qara niraq',
    '🏋🏻‍♂' => 'tata sayayninkunata jatarichichkan: chuya qara niraq',
    '🏋🏼‍♂' => 'tata sayayninkunata jatarichichkan: tunpa chuya qara niraq',
    '🏋🏽‍♂' => 'tata sayayninkunata jatarichichkan: tunpa qara niraq',
    '🏋🏾‍♂' => 'tata sayayninkunata jatarichichkan: tunpa yana qara niraq',
    '🏋🏿‍♂' => 'tata sayayninkunata jatarichichkan: yana qara niraq',
    '🏋🏻‍♀' => 'warmi sayayninkunata jatarichichkan: chuya qara niraq',
    '🏋🏼‍♀' => 'warmi sayayninkunata jatarichichkan: tunpa chuya qara niraq',
    '🏋🏽‍♀' => 'warmi sayayninkunata jatarichichkan: tunpa qara niraq',
    '🏋🏾‍♀' => 'warmi sayayninkunata jatarichichkan: tunpa yana qara niraq',
    '🏋🏿‍♀' => 'warmi sayayninkunata jatarichichkan: yana qara niraq',
    '🚴🏻‍♂' => 'tata bicicletapi: chuya qara niraq',
    '🚴🏼‍♂' => 'tata bicicletapi: tunpa chuya qara niraq',
    '🚴🏽‍♂' => 'tata bicicletapi: tunpa qara niraq',
    '🚴🏾‍♂' => 'tata bicicletapi: tunpa yana qara niraq',
    '🚴🏿‍♂' => 'tata bicicletapi: yana qara niraq',
    '🚴🏻‍♀' => 'warmi bicicletapi: chuya qara niraq',
    '🚴🏼‍♀' => 'warmi bicicletapi: tunpa chuya qara niraq',
    '🚴🏽‍♀' => 'warmi bicicletapi: tunpa qara niraq',
    '🚴🏾‍♀' => 'warmi bicicletapi: tunpa yana qara niraq',
    '🚴🏿‍♀' => 'warmi bicicletapi: yana qara niraq',
    '🚵🏻‍♂' => 'tata urqu bicicletapi: chuya qara niraq',
    '🚵🏼‍♂' => 'tata urqu bicicletapi: tunpa chuya qara niraq',
    '🚵🏽‍♂' => 'tata urqu bicicletapi: tunpa qara niraq',
    '🚵🏾‍♂' => 'tata urqu bicicletapi: tunpa yana qara niraq',
    '🚵🏿‍♂' => 'tata urqu bicicletapi: yana qara niraq',
    '🚵🏻‍♀' => 'warmi urqu bicicletapi: chuya qara niraq',
    '🚵🏼‍♀' => 'warmi urqu bicicletapi: tunpa chuya qara niraq',
    '🚵🏽‍♀' => 'warmi urqu bicicletapi: tunpa qara niraq',
    '🚵🏾‍♀' => 'warmi urqu bicicletapi: tunpa yana qara niraq',
    '🚵🏿‍♀' => 'warmi urqu bicicletapi: yana qara niraq',
    '🤸🏻‍♂' => 'tata gimnasia ruwachkan: chuya qara niraq',
    '🤸🏼‍♂' => 'tata gimnasia ruwachkan: tunpa chuya qara niraq',
    '🤸🏽‍♂' => 'tata gimnasia ruwachkan: tunpa qara niraq',
    '🤸🏾‍♂' => 'tata gimnasia ruwachkan: tunpa yana qara niraq',
    '🤸🏿‍♂' => 'tata gimnasia ruwachkan: yana qara niraq',
    '🤸🏻‍♀' => 'warmi gimnasia ruwachkan: chuya qara niraq',
    '🤸🏼‍♀' => 'warmi gimnasia ruwachkan: tunpa chuya qara niraq',
    '🤸🏽‍♀' => 'warmi gimnasia ruwachkan: tunpa qara niraq',
    '🤸🏾‍♀' => 'warmi gimnasia ruwachkan: tunpa yana qara niraq',
    '🤸🏿‍♀' => 'warmi gimnasia ruwachkan: yana qara niraq',
    '🤼🏻‍♀' => 'maqanakuq warmi: chuya qara niraq',
    '🤼🏼‍♀' => 'maqanakuq warmi: tunpa chuya qara niraq',
    '🤼🏽‍♀' => 'maqanakuq warmi: tunpa qara niraq',
    '🤼🏾‍♀' => 'maqanakuq warmi: tunpa yana qara niraq',
    '🤼🏿‍♀' => 'maqanakuq warmi: yana qara niraq',
    '🤼🏻‍♂' => 'maqanakuq tata: chuya qara niraq',
    '🤼🏼‍♂' => 'maqanakuq tata: tunpa chuya qara niraq',
    '🤼🏽‍♂' => 'maqanakuq tata: tunpa qara niraq',
    '🤼🏾‍♂' => 'maqanakuq tata: tunpa yana qara niraq',
    '🤼🏿‍♂' => 'maqanakuq tata: yana qara niraq',
    '🤽🏻‍♂' => 'tata Water polo pukllachkan: chuya qara niraq',
    '🤽🏼‍♂' => 'tata Water polo pukllachkan: tunpa chuya qara niraq',
    '🤽🏽‍♂' => 'tata Water polo pukllachkan: tunpa qara niraq',
    '🤽🏾‍♂' => 'tata Water polo pukllachkan: tunpa yana qara niraq',
    '🤽🏿‍♂' => 'tata Water polo pukllachkan: yana qara niraq',
    '🤽🏻‍♀' => 'warmi water polo pukllachkan: chuya qara niraq',
    '🤽🏼‍♀' => 'warmi water polo pukllachkan: tunpa chuya qara niraq',
    '🤽🏽‍♀' => 'warmi water polo pukllachkan: tunpa qara niraq',
    '🤽🏾‍♀' => 'warmi water polo pukllachkan: tunpa yana qara niraq',
    '🤽🏿‍♀' => 'warmi water polo pukllachkan: yana qara niraq',
    '🤾🏻‍♂' => 'tata balonmano pukllachkan: chuya qara niraq',
    '🤾🏼‍♂' => 'tata balonmano pukllachkan: tunpa chuya qara niraq',
    '🤾🏽‍♂' => 'tata balonmano pukllachkan: tunpa qara niraq',
    '🤾🏾‍♂' => 'tata balonmano pukllachkan: tunpa yana qara niraq',
    '🤾🏿‍♂' => 'tata balonmano pukllachkan: yana qara niraq',
    '🤾🏻‍♀' => 'warmi balonmano pukllachkan: chuya qara niraq',
    '🤾🏼‍♀' => 'warmi balonmano pukllachkan: tunpa chuya qara niraq',
    '🤾🏽‍♀' => 'warmi balonmano pukllachkan: tunpa qara niraq',
    '🤾🏾‍♀' => 'warmi balonmano pukllachkan: tunpa yana qara niraq',
    '🤾🏿‍♀' => 'warmi balonmano pukllachkan: yana qara niraq',
    '🤹🏻‍♂' => 'tata malabares ruwachkan: chuya qara niraq',
    '🤹🏼‍♂' => 'tata malabares ruwachkan: tunpa chuya qara niraq',
    '🤹🏽‍♂' => 'tata malabares ruwachkan: tunpa qara niraq',
    '🤹🏾‍♂' => 'tata malabares ruwachkan: tunpa yana qara niraq',
    '🤹🏿‍♂' => 'tata malabares ruwachkan: yana qara niraq',
    '🤹🏻‍♀' => 'warmi malabares ruwachkan: chuya qara niraq',
    '🤹🏼‍♀' => 'warmi malabares ruwachkan: tunpa chuya qara niraq',
    '🤹🏽‍♀' => 'warmi malabares ruwachkan: tunpa qara niraq',
    '🤹🏾‍♀' => 'warmi malabares ruwachkan: tunpa yana qara niraq',
    '🤹🏿‍♀' => 'warmi malabares ruwachkan: yana qara niraq',
    '🧘🏻‍♂' => 'tata yoga yupipi: chuya qara niraq',
    '🧘🏼‍♂' => 'tata yoga yupipi: tunpa chuya qara niraq',
    '🧘🏽‍♂' => 'tata yoga yupipi: tunpa qara niraq',
    '🧘🏾‍♂' => 'tata yoga yupipi: tunpa yana qara niraq',
    '🧘🏿‍♂' => 'tata yoga yupipi: yana qara niraq',
    '🧘🏻‍♀' => 'warmi yoga yupipi: chuya qara niraq',
    '🧘🏼‍♀' => 'warmi yoga yupipi: tunpa chuya qara niraq',
    '🧘🏽‍♀' => 'warmi yoga yupipi: tunpa qara niraq',
    '🧘🏾‍♀' => 'warmi yoga yupipi: tunpa yana qara niraq',
    '🧘🏿‍♀' => 'warmi yoga yupipi: yana qara niraq',
    '🧑‍🦰' => 'runa: puka chukcha',
    '🧑‍🦱' => 'runa: qaspa chukcha',
    '🧑‍🦳' => 'runa: yuraq chukcha',
    '🧑‍🦲' => 'runa: paqla',
    '👨‍🦰' => 'qari: puka chukcha',
    '👨‍🦱' => 'qari: qaspa chukcha',
    '👨‍🦳' => 'qari: yuraq chukcha',
    '👨‍🦲' => 'qari: paqla',
    '👩‍🦰' => 'warmi: puka chukcha',
    '👩‍🦱' => 'warmi: qaspa chukcha',
    '👩‍🦳' => 'warmi: yuraq chukcha',
    '👩‍🦲' => 'warmi: paqla',
    '👨‍👦' => 'kuraq ayllu: qari, yuqalla',
    '👨‍👧' => 'kuraq ayllu: qari, warmi warma',
    '👩‍👦' => 'kuraq ayllu: warmi, yuqalla',
    '👩‍👧' => 'kuraq ayllu: warmi, warmi warma',
    '😶‍🌫' => 'uya phuyukunapi',
    '😮‍💨' => 'uya samachkan',
    '🙂‍↕' => 'vertical tapsiy umata',
    '😵‍💫' => 'uya espiral ñawikunawan',
    '❤‍🔥' => 'sunqu ninapi',
    '❤‍🩹' => 'allichasqa sunqu',
    '👁‍🗨' => 'ñawi rimasqa phukpupi',
    '🧔‍♂' => 'qari: kaki',
    '👱‍♂' => 'qari: qillu chukcha',
    '🧔‍♀' => 'warmi: kʼaki',
    '👱‍♀' => 'warmi: qʼillu chukcha',
    '🙍‍♂' => 'llakisqa tata',
    '🙍‍♀' => 'llakisqa warmi',
    '🙎‍♂' => 'phiñachisqa tata',
    '🙎‍♀' => 'phiñachisqa warmi',
    '🙅‍♂' => 'tata MANA gestowan',
    '🙅‍♀' => 'warmi MANA gestowan',
    '🙆‍♂' => 'tata UYAKUY gestowan',
    '🙆‍♀' => 'warmi UYAKUY gestowan',
    '💁‍♂' => 'tata willakuy kitipi',
    '💁‍♀' => 'warmi willakuy kitipi',
    '🙋‍♂' => 'tata makita hatarichiy',
    '🙋‍♀' => 'warmi makita hatarichiy',
    '🧏‍♂' => 'ruqtʼu runa',
    '🧏‍♀' => 'luqʼu warmi',
    '🙇‍♂' => 'upaykusqa tata',
    '🙇‍♀' => 'upaykusqa warmi',
    '🤦‍♂' => 'tata makiwan uyapi',
    '🤦‍♀' => 'warmi makian uyapi',
    '🤷‍♂' => 'tata rikrakunayuq hatarichiy',
    '🤷‍♀' => 'warmi rikrakunayuq hatarichiy',
    '🧑‍⚕' => 'qhali kaywan llamkaq',
    '👨‍⚕' => 'tata qhali kaywan llamkaq',
    '👩‍⚕' => 'warmi qhali kaywan llamkaq',
    '🧑‍🎓' => 'yachakuq',
    '👨‍🎓' => 'tata yachakuq',
    '👩‍🎓' => 'warmi yachakuq',
    '🧑‍🏫' => 'maestro',
    '👨‍🏫' => 'tata yachachiq',
    '👩‍🏫' => 'warmi yachachiq',
    '🧑‍⚖' => 'juez',
    '👨‍⚖' => 'tata juez',
    '👩‍⚖' => 'warmi jueza',
    '🧑‍🌾' => 'granjero',
    '👨‍🌾' => 'tata granjero',
    '👩‍🌾' => 'warmi granjera',
    '🧑‍🍳' => 'wayk’uq',
    '👨‍🍳' => 'tata wayk’uq',
    '👩‍🍳' => 'warmi wayk’uq',
    '🧑‍🔧' => 'mecanico',
    '👨‍🔧' => 'tata mecanico',
    '👩‍🔧' => 'warmi mecanico',
    '🧑‍🏭' => 'fabrica llamkaq',
    '👨‍🏭' => 'tata fabrica llamkaq',
    '👩‍🏭' => 'warmi fabrica llamkaq',
    '🧑‍💼' => 'oficina llamkaq',
    '👨‍💼' => 'tata oficina llamkaq',
    '👩‍💼' => 'warmi oficina llamkaq',
    '🧑‍🔬' => 'hamut’asqa',
    '👨‍🔬' => 'tata hamut’asqa',
    '👩‍🔬' => 'warmi hamut’asqa',
    '🧑‍💻' => 'tecnico',
    '👨‍💻' => 'tata tecnico',
    '👩‍💻' => 'warmi tecnico',
    '🧑‍🎤' => 'takiq',
    '👨‍🎤' => 'tata takiq',
    '👩‍🎤' => 'warmi takiq',
    '🧑‍🎨' => 'llimpiq',
    '👨‍🎨' => 'tata llimpiq',
    '👩‍🎨' => 'warmi llimpiq',
    '🧑‍✈' => 'piloto',
    '👨‍✈' => 'tata piloto',
    '👩‍✈' => 'warmi piloto',
    '🧑‍🚀' => 'astronauta',
    '👨‍🚀' => 'tata astronauta',
    '👩‍🚀' => 'warmi astronauta',
    '🧑‍🚒' => 'bombero',
    '👨‍🚒' => 'tata bombero',
    '👩‍🚒' => 'warmi bombera',
    '👮‍♂' => 'tata policia',
    '👮‍♀' => 'warmi policia',
    '🕵‍♂' => 'tata qhamiyaq',
    '🕵‍♀' => 'warmi qhamiyaq',
    '💂‍♂' => 'tata guardia',
    '💂‍♀' => 'warmi guardia',
    '👷‍♂' => 'tata pirqaq',
    '👷‍♀' => 'warmi pirqaq',
    '👳‍♂' => 'tata turbantewan',
    '👳‍♀' => 'warmi turbantewan',
    '🤵‍♂' => 'runa esmoquinwan',
    '🤵‍♀' => 'warmi tuxedopi',
    '👰‍♂' => 'runa velopi',
    '👰‍♀' => 'warmi velopi',
    '👩‍🍼' => 'warmi wawata ñuñuchichkan',
    '👨‍🍼' => 'runa wawata ñuñuchichkan',
    '🧑‍🍼' => 'runa wawawan ñuñuchichkan',
    '🧑‍🎄' => 'mx claus',
    '🦸‍♂' => 'runa superheroe',
    '🦸‍♀' => 'warmi superheroe',
    '🦹‍♂' => 'runa supervillano',
    '🦹‍♀' => 'warmi supervillana',
    '🧙‍♂' => 'tata watuq',
    '🧙‍♀' => 'warmi watuq',
    '🧚‍♂' => 'tata hada',
    '🧚‍♀' => 'warmi hada',
    '🧛‍♂' => 'tata vampiro',
    '🧛‍♀' => 'warmi vampiro',
    '🧜‍♂' => 'tata triton',
    '🧜‍♀' => 'sirena',
    '🧝‍♂' => 'tata elfo',
    '🧝‍♀' => 'warmi elfo',
    '🧞‍♂' => 'tata genio lamparamanta',
    '🧞‍♀' => 'warmi genio lamparamanta',
    '🧟‍♂' => 'tata zombi',
    '🧟‍♀' => 'warmi zombi',
    '💆‍♂' => 'tata masaje uyapi',
    '💆‍♀' => 'warmi masaje uyapi',
    '💇‍♂' => 'tata chukcha rutukuy',
    '💇‍♀' => 'warmi chukcha rutukuy',
    '🚶‍♂' => 'tata purichkan',
    '🚶‍♀' => 'warmi purichkan',
    '🧍‍♂' => 'tata sayariy',
    '🧍‍♀' => 'warmi sayariy',
    '🧎‍♂' => 'qunqurisqa tata',
    '🧎‍♀' => 'qunqurisqa warmi',
    '🧑‍🦯' => 'runa yuraq cañawan',
    '👨‍🦯' => 'runa yuraq warrawan',
    '👩‍🦯' => 'warmi yuraq cañawan',
    '🧑‍🦼' => 'runa motorizado silla de ruedas nisqapi',
    '👨‍🦼' => 'runa motorizado silla de ruedas nisqawan',
    '👩‍🦼' => 'warmi motorizado silla de ruedaspi',
    '🧑‍🦽' => 'runa manual silla de ruedaspi',
    '👨‍🦽' => 'runa manual silla de ruedas nisqapi',
    '👩‍🦽' => 'warmi manual silla de ruedas',
    '🏃‍♂' => 'tata phawachkan',
    '🏃‍♀' => 'warmi phawachkan',
    '🧑‍🩰' => 'ballet tusuq',
    '👯‍♂' => 'runa quwi ninrikunawan',
    '👯‍♀' => 'warmi quwi ninrikunawan',
    '🧖‍♂' => 'tata wapsi wasipi',
    '🧖‍♀' => 'warmi wapsi wasipi',
    '🧗‍♂' => 'wichaq tata',
    '🧗‍♀' => 'wichaq warmi',
    '🏌‍♂' => 'tata golfista',
    '🏌‍♀' => 'warmi golfista',
    '🏄‍♂' => 'tata surfeando',
    '🏄‍♀' => 'warmi surfeando',
    '🚣‍♂' => 'runa wampʼu remoswan',
    '🚣‍♀' => 'warmi wampʼu remoswan',
    '🏊‍♂' => 'tata waytachkan',
    '🏊‍♀' => 'warmi waytachkan',
    '⛹‍♂' => 'tata p’uluta chuqapachkan',
    '⛹‍♀' => 'warmi p’uluta chuqapachkan',
    '🏋‍♂' => 'tata sayayninkunata jatarichichkan',
    '🏋‍♀' => 'warmi sayayninkunata jatarichichkan',
    '🚴‍♂' => 'tata bicicletapi',
    '🚴‍♀' => 'warmi bicicletapi',
    '🚵‍♂' => 'tata urqu bicicletapi',
    '🚵‍♀' => 'warmi urqu bicicletapi',
    '🤸‍♂' => 'tata gimnasia ruwachkan',
    '🤸‍♀' => 'warmi gimnasia ruwachkan',
    '🤼‍♂' => 'maqanakuq tata',
    '🤼‍♀' => 'maqanakuq warmi',
    '🤽‍♂' => 'tata Water polo pukllachkan',
    '🤽‍♀' => 'warmi water polo pukllachkan',
    '🤾‍♂' => 'tata balonmano pukllachkan',
    '🤾‍♀' => 'warmi balonmano pukllachkan',
    '🤹‍♂' => 'tata malabares ruwachkan',
    '🤹‍♀' => 'warmi malabares ruwachkan',
    '🧘‍♂' => 'tata yoga yupipi',
    '🧘‍♀' => 'warmi yoga yupipi',
    '🧑‍🧒' => 'ayllu: runa, warma',
    '🐕‍🦺' => 'llamkaq allqu',
    '🐈‍⬛' => 'yana misi',
    '🐻‍❄' => 'polar jukumari',
    '🐦‍⬛' => 'yana pisqu',
    '🐦‍🔥' => 'fenix',
    '🍋‍🟩' => 'lima',
    '🍄‍🟫' => 'chumpi hongo',
    '⛓‍💥' => 'pakisqa cadena',
    '🏳‍🌈' => 'k’uychi whipala',
    '🏳‍⚧' => 'transgenero whipala',
    '🏴‍☠' => 'pirata whipala',
    '👋🏻' => 'qinquykachasqa maki: chuya qara niraq',
    '👋🏼' => 'qinquykachasqa maki: tunpa chuya qara niraq',
    '👋🏽' => 'qinquykachasqa maki: tunpa qara niraq',
    '👋🏾' => 'qinquykachasqa maki: tunpa yana qara niraq',
    '👋🏿' => 'qinquykachasqa maki: yana qara niraq',
    '🤚🏻' => 'juqharisqa maki: chuya qara niraq',
    '🤚🏼' => 'juqharisqa maki: tunpa chuya qara niraq',
    '🤚🏽' => 'juqharisqa maki: tunpa qara niraq',
    '🤚🏾' => 'juqharisqa maki: tunpa yana qara niraq',
    '🤚🏿' => 'juqharisqa maki: yana qara niraq',
    '🖐🏻' => 'maki iskay rukanakunawa mastasqa: chuya qara niraq',
    '🖐🏼' => 'maki iskay rukanakunawa mastasqa: tunpa chuya qara niraq',
    '🖐🏽' => 'maki iskay rukanakunawa mastasqa: tunpa qara niraq',
    '🖐🏾' => 'maki iskay rukanakunawa mastasqa: tunpa yana qara niraq',
    '🖐🏿' => 'maki iskay rukanakunawa mastasqa: yana qara niraq',
    '✋🏻' => 'huqharisqa maki: chuya qara niraq',
    '✋🏼' => 'huqharisqa maki: tunpa chuya qara niraq',
    '✋🏽' => 'huqharisqa maki: tunpa qara niraq',
    '✋🏾' => 'huqharisqa maki: tunpa yana qara niraq',
    '✋🏿' => 'huqharisqa maki: yana qara niraq',
    '🖖🏻' => 'vulcano napay: chuya qara niraq',
    '🖖🏼' => 'vulcano napay: tunpa chuya qara niraq',
    '🖖🏽' => 'vulcano napay: tunpa qara niraq',
    '🖖🏾' => 'vulcano napay: tunpa yana qara niraq',
    '🖖🏿' => 'vulcano napay: yana qara niraq',
    '🫱🏻' => 'pañaman maki: chuya qara niraq',
    '🫱🏼' => 'pañaman maki: tunpa chuya qara niraq',
    '🫱🏽' => 'pañaman maki: tunpa qara niraq',
    '🫱🏾' => 'pañaman maki: tunpa yana qara niraq',
    '🫱🏿' => 'pañaman maki: yana qara niraq',
    '🫲🏻' => 'lluqiman maki: chuya qara niraq',
    '🫲🏼' => 'lluqiman maki: tunpa chuya qara niraq',
    '🫲🏽' => 'lluqiman maki: tunpa qara niraq',
    '🫲🏾' => 'lluqiman maki: tunpa yana qara niraq',
    '🫲🏿' => 'lluqiman maki: yana qara niraq',
    '🫳🏻' => 'uranman maki pampa: chuya qara niraq',
    '🫳🏼' => 'uranman maki pampa: tunpa chuya qara niraq',
    '🫳🏽' => 'uranman maki pampa: tunpa qara niraq',
    '🫳🏾' => 'uranman maki pampa: tunpa yana qara niraq',
    '🫳🏿' => 'uranman maki pampa: yana qara niraq',
    '🫴🏻' => 'hanaqman maki pampa: chuya qara niraq',
    '🫴🏼' => 'hanaqman maki pampa: tunpa chuya qara niraq',
    '🫴🏽' => 'hanaqman maki pampa: tunpa qara niraq',
    '🫴🏾' => 'hanaqman maki pampa: tunpa yana qara niraq',
    '🫴🏿' => 'hanaqman maki pampa: yana qara niraq',
    '🫷🏻' => 'tanqaspa lluqi maki: chuya qara niraq',
    '🫷🏼' => 'tanqaspa lluqi maki: tunpa chuya qara niraq',
    '🫷🏽' => 'tanqaspa lluqi maki: tunpa qara niraq',
    '🫷🏾' => 'tanqaspa lluqi maki: tunpa yana qara niraq',
    '🫷🏿' => 'tanqaspa lluqi maki: yana qara niraq',
    '🫸🏻' => 'tanqaspa paña maki: chuya qara niraq',
    '🫸🏼' => 'tanqaspa paña maki: tunpa chuya qara niraq',
    '🫸🏽' => 'tanqaspa paña maki: tunpa qara niraq',
    '🫸🏾' => 'tanqaspa paña maki: tunpa yana qara niraq',
    '🫸🏿' => 'tanqaspa paña maki: yana qara niraq',
    '👌🏻' => 'UYAKUY maki: chuya qara niraq',
    '👌🏼' => 'UYAKUY maki: tunpa chuya qara niraq',
    '👌🏽' => 'UYAKUY maki: tunpa qara niraq',
    '👌🏾' => 'UYAKUY maki: tunpa yana qara niraq',
    '👌🏿' => 'UYAKUY maki: yana qara niraq',
    '🤌🏻' => 'tʼipsisqa rukanakuna: chuya qara niraq',
    '🤌🏼' => 'tʼipsisqa rukanakuna: tunpa chuya qara niraq',
    '🤌🏽' => 'tʼipsisqa rukanakuna: tunpa qara niraq',
    '🤌🏾' => 'tʼipsisqa rukanakuna: tunpa yana qara niraq',
    '🤌🏿' => 'tʼipsisqa rukanakuna: yana qara niraq',
    '🤏🏻' => 'tʼipsisqa maki: chuya qara niraq',
    '🤏🏼' => 'tʼipsisqa maki: tunpa chuya qara niraq',
    '🤏🏽' => 'tʼipsisqa maki: tunpa qara niraq',
    '🤏🏾' => 'tʼipsisqa maki: tunpa yana qara niraq',
    '🤏🏿' => 'tʼipsisqa maki: yana qara niraq',
    '✌🏻' => 'yalli maki: chuya qara niraq',
    '✌🏼' => 'yalli maki: tunpa chuya qara niraq',
    '✌🏽' => 'yalli maki: tunpa qara niraq',
    '✌🏾' => 'yalli maki: tunpa yana qara niraq',
    '✌🏿' => 'yalli maki: yana qara niraq',
    '🤞🏻' => 'chakatasqa rukanakuna: chuya qara niraq',
    '🤞🏼' => 'chakatasqa rukanakuna: tunpa chuya qara niraq',
    '🤞🏽' => 'chakatasqa rukanakuna: tunpa qara niraq',
    '🤞🏾' => 'chakatasqa rukanakuna: tunpa yana qara niraq',
    '🤞🏿' => 'chakatasqa rukanakuna: yana qara niraq',
    '🫰🏻' => 'maki chakatasqa iskay rukanawan: chuya qara niraq',
    '🫰🏼' => 'maki chakatasqa iskay rukanawan: tunpa chuya qara niraq',
    '🫰🏽' => 'maki chakatasqa iskay rukanawan: tunpa qara niraq',
    '🫰🏾' => 'maki chakatasqa iskay rukanawan: tunpa yana qara niraq',
    '🫰🏿' => 'maki chakatasqa iskay rukanawan: yana qara niraq',
    '🤟🏻' => 'munanki yupi: chuya qara niraq',
    '🤟🏼' => 'munanki yupi: tunpa chuya qara niraq',
    '🤟🏽' => 'munanki yupi: tunpa qara niraq',
    '🤟🏾' => 'munanki yupi: tunpa yana qara niraq',
    '🤟🏿' => 'munanki yupi: yana qara niraq',
    '🤘🏻' => 'waqrakuna unancha: chuya qara niraq',
    '🤘🏼' => 'waqrakuna unancha: tunpa chuya qara niraq',
    '🤘🏽' => 'waqrakuna unancha: tunpa qara niraq',
    '🤘🏾' => 'waqrakuna unancha: tunpa yana qara niraq',
    '🤘🏿' => 'waqrakuna unancha: yana qara niraq',
    '🤙🏻' => 'waqyawani maki: chuya qara niraq',
    '🤙🏼' => 'waqyawani maki: tunpa chuya qara niraq',
    '🤙🏽' => 'waqyawani maki: tunpa qara niraq',
    '🤙🏾' => 'waqyawani maki: tunpa yana qara niraq',
    '🤙🏿' => 'waqyawani maki: yana qara niraq',
    '👈🏻' => 'tʼupsi rukʼanawan lluqʼiman chimpuy: chuya qara niraq',
    '👈🏼' => 'tʼupsi rukʼanawan lluqʼiman chimpuy: tunpa chuya qara niraq',
    '👈🏽' => 'tʼupsi rukʼanawan lluqʼiman chimpuy: tunpa qara niraq',
    '👈🏾' => 'tʼupsi rukʼanawan lluqʼiman chimpuy: tunpa yana qara niraq',
    '👈🏿' => 'tʼupsi rukʼanawan lluqʼiman chimpuy: yana qara niraq',
    '👉🏻' => 'tʼupsi rukʼanawan pañaman chimpuy: chuya qara niraq',
    '👉🏼' => 'tʼupsi rukʼanawan pañaman chimpuy: tunpa chuya qara niraq',
    '👉🏽' => 'tʼupsi rukʼanawan pañaman chimpuy: tunpa qara niraq',
    '👉🏾' => 'tʼupsi rukʼanawan pañaman chimpuy: tunpa yana qara niraq',
    '👉🏿' => 'tʼupsi rukʼanawan pañaman chimpuy: yana qara niraq',
    '👆🏻' => 'tʼupsi rukʼanawan hanaqman chimpuy: chuya qara niraq',
    '👆🏼' => 'tʼupsi rukʼanawan hanaqman chimpuy: tunpa chuya qara niraq',
    '👆🏽' => 'tʼupsi rukʼanawan hanaqman chimpuy: tunpa qara niraq',
    '👆🏾' => 'tʼupsi rukʼanawan hanaqman chimpuy: tunpa yana qara niraq',
    '👆🏿' => 'tʼupsi rukʼanawan hanaqman chimpuy: yana qara niraq',
    '🖕🏻' => 'chawpi rukana: chuya qara niraq',
    '🖕🏼' => 'chawpi rukana: tunpa chuya qara niraq',
    '🖕🏽' => 'chawpi rukana: tunpa qara niraq',
    '🖕🏾' => 'chawpi rukana: tunpa yana qara niraq',
    '🖕🏿' => 'chawpi rukana: yana qara niraq',
    '👇🏻' => 'tʼupsi rukʼanawan uranman chimpuy: chuya qara niraq',
    '👇🏼' => 'tʼupsi rukʼanawan uranman chimpuy: tunpa chuya qara niraq',
    '👇🏽' => 'tʼupsi rukʼanawan uranman chimpuy: tunpa qara niraq',
    '👇🏾' => 'tʼupsi rukʼanawan uranman chimpuy: tunpa yana qara niraq',
    '👇🏿' => 'tʼupsi rukʼanawan uranman chimpuy: yana qara niraq',
    '☝🏻' => 'rukʼanawan hanaqman chimpuy: chuya qara niraq',
    '☝🏼' => 'rukʼanawan hanaqman chimpuy: tunpa chuya qara niraq',
    '☝🏽' => 'rukʼanawan hanaqman chimpuy: tunpa qara niraq',
    '☝🏾' => 'rukʼanawan hanaqman chimpuy: tunpa yana qara niraq',
    '☝🏿' => 'rukʼanawan hanaqman chimpuy: yana qara niraq',
    '🫵🏻' => 'indice rukanawan chimpusqa qawaqman: chuya qara niraq',
    '🫵🏼' => 'indice rukanawan chimpusqa qawaqman: tunpa chuya qara niraq',
    '🫵🏽' => 'indice rukanawan chimpusqa qawaqman: tunpa qara niraq',
    '🫵🏾' => 'indice rukanawan chimpusqa qawaqman: tunpa yana qara niraq',
    '🫵🏿' => 'indice rukanawan chimpusqa qawaqman: yana qara niraq',
    '👍🏻' => 'hanaqpi rukʼana: chuya qara niraq',
    '👍🏼' => 'hanaqpi rukʼana: tunpa chuya qara niraq',
    '👍🏽' => 'hanaqpi rukʼana: tunpa qara niraq',
    '👍🏾' => 'hanaqpi rukʼana: tunpa yana qara niraq',
    '👍🏿' => 'hanaqpi rukʼana: yana qara niraq',
    '👎🏻' => 'uranpi rukʼana: chuya qara niraq',
    '👎🏼' => 'uranpi rukʼana: tunpa chuya qara niraq',
    '👎🏽' => 'uranpi rukʼana: tunpa qara niraq',
    '👎🏾' => 'uranpi rukʼana: tunpa yana qara niraq',
    '👎🏿' => 'uranpi rukʼana: yana qara niraq',
    '✊🏻' => 'juqharisqa saqma: chuya qara niraq',
    '✊🏼' => 'juqharisqa saqma: tunpa chuya qara niraq',
    '✊🏽' => 'juqharisqa saqma: tunpa qara niraq',
    '✊🏾' => 'juqharisqa saqma: tunpa yana qara niraq',
    '✊🏿' => 'juqharisqa saqma: yana qara niraq',
    '👊🏻' => 'saqma unancha: chuya qara niraq',
    '👊🏼' => 'saqma unancha: tunpa chuya qara niraq',
    '👊🏽' => 'saqma unancha: tunpa qara niraq',
    '👊🏾' => 'saqma unancha: tunpa yana qara niraq',
    '👊🏿' => 'saqma unancha: yana qara niraq',
    '🤛🏻' => 'lluqʼi saqma: chuya qara niraq',
    '🤛🏼' => 'lluqʼi saqma: tunpa chuya qara niraq',
    '🤛🏽' => 'lluqʼi saqma: tunpa qara niraq',
    '🤛🏾' => 'lluqʼi saqma: tunpa yana qara niraq',
    '🤛🏿' => 'lluqʼi saqma: yana qara niraq',
    '🤜🏻' => 'paña saqma: chuya qara niraq',
    '🤜🏼' => 'paña saqma: tunpa chuya qara niraq',
    '🤜🏽' => 'paña saqma: tunpa qara niraq',
    '🤜🏾' => 'paña saqma: tunpa yana qara niraq',
    '🤜🏿' => 'paña saqma: yana qara niraq',
    '👏🏻' => 'jayllisqa makikuna: chuya qara niraq',
    '👏🏼' => 'jayllisqa makikuna: tunpa chuya qara niraq',
    '👏🏽' => 'jayllisqa makikuna: tunpa qara niraq',
    '👏🏾' => 'jayllisqa makikuna: tunpa yana qara niraq',
    '👏🏿' => 'jayllisqa makikuna: yana qara niraq',
    '🙌🏻' => 'juqharisqa makikuna: chuya qara niraq',
    '🙌🏼' => 'juqharisqa makikuna: tunpa chuya qara niraq',
    '🙌🏽' => 'juqharisqa makikuna: tunpa qara niraq',
    '🙌🏾' => 'juqharisqa makikuna: tunpa yana qara niraq',
    '🙌🏿' => 'juqharisqa makikuna: yana qara niraq',
    '🫶🏻' => 'sunqu makikunawan: chuya qara niraq',
    '🫶🏼' => 'sunqu makikunawan: tunpa chuya qara niraq',
    '🫶🏽' => 'sunqu makikunawan: tunpa qara niraq',
    '🫶🏾' => 'sunqu makikunawan: tunpa yana qara niraq',
    '🫶🏿' => 'sunqu makikunawan: yana qara niraq',
    '👐🏻' => 'kichasqa makikuna: chuya qara niraq',
    '👐🏼' => 'kichasqa makikuna: tunpa chuya qara niraq',
    '👐🏽' => 'kichasqa makikuna: tunpa qara niraq',
    '👐🏾' => 'kichasqa makikuna: tunpa yana qara niraq',
    '👐🏿' => 'kichasqa makikuna: yana qara niraq',
    '🤲🏻' => 'makikunawan plegaria unancha: chuya qara niraq',
    '🤲🏼' => 'makikunawan plegaria unancha: tunpa chuya qara niraq',
    '🤲🏽' => 'makikunawan plegaria unancha: tunpa qara niraq',
    '🤲🏾' => 'makikunawan plegaria unancha: tunpa yana qara niraq',
    '🤲🏿' => 'makikunawan plegaria unancha: yana qara niraq',
    '🤝🏻' => 'pipuyasqa makikunapura: chuya qara niraq',
    '🤝🏼' => 'pipuyasqa makikunapura: tunpa chuya qara niraq',
    '🤝🏽' => 'pipuyasqa makikunapura: tunpa qara niraq',
    '🤝🏾' => 'pipuyasqa makikunapura: tunpa yana qara niraq',
    '🤝🏿' => 'pipuyasqa makikunapura: yana qara niraq',
    '🙏🏻' => 'makikuna rezando: chuya qara niraq',
    '🙏🏼' => 'makikuna rezando: tunpa chuya qara niraq',
    '🙏🏽' => 'makikuna rezando: tunpa qara niraq',
    '🙏🏾' => 'makikuna rezando: tunpa yana qara niraq',
    '🙏🏿' => 'makikuna rezando: yana qara niraq',
    '✍🏻' => 'maki qillqachkan: chuya qara niraq',
    '✍🏼' => 'maki qillqachkan: tunpa chuya qara niraq',
    '✍🏽' => 'maki qillqachkan: tunpa qara niraq',
    '✍🏾' => 'maki qillqachkan: tunpa yana qara niraq',
    '✍🏿' => 'maki qillqachkan: yana qara niraq',
    '💅🏻' => 'esmalte sillukunapaq: chuya qara niraq',
    '💅🏼' => 'esmalte sillukunapaq: tunpa chuya qara niraq',
    '💅🏽' => 'esmalte sillukunapaq: tunpa qara niraq',
    '💅🏾' => 'esmalte sillukunapaq: tunpa yana qara niraq',
    '💅🏿' => 'esmalte sillukunapaq: yana qara niraq',
    '🤳🏻' => 'selfie: chuya qara niraq',
    '🤳🏼' => 'selfie: tunpa chuya qara niraq',
    '🤳🏽' => 'selfie: tunpa qara niraq',
    '🤳🏾' => 'selfie: tunpa yana qara niraq',
    '🤳🏿' => 'selfie: yana qara niraq',
    '💪🏻' => 'iskaychasqa bicepkuna: chuya qara niraq',
    '💪🏼' => 'iskaychasqa bicepkuna: tunpa chuya qara niraq',
    '💪🏽' => 'iskaychasqa bicepkuna: tunpa qara niraq',
    '💪🏾' => 'iskaychasqa bicepkuna: tunpa yana qara niraq',
    '💪🏿' => 'iskaychasqa bicepkuna: yana qara niraq',
    '🦵🏻' => 'chanka: chuya qara niraq',
    '🦵🏼' => 'chanka: tunpa chuya qara niraq',
    '🦵🏽' => 'chanka: tunpa qara niraq',
    '🦵🏾' => 'chanka: tunpa yana qara niraq',
    '🦵🏿' => 'chanka: yana qara niraq',
    '🦶🏻' => 'chaki: chuya qara niraq',
    '🦶🏼' => 'chaki: tunpa chuya qara niraq',
    '🦶🏽' => 'chaki: tunpa qara niraq',
    '🦶🏾' => 'chaki: tunpa yana qara niraq',
    '🦶🏿' => 'chaki: yana qara niraq',
    '👂🏻' => 'ninri: chuya qara niraq',
    '👂🏼' => 'ninri: tunpa chuya qara niraq',
    '👂🏽' => 'ninri: tunpa qara niraq',
    '👂🏾' => 'ninri: tunpa yana qara niraq',
    '👂🏿' => 'ninri: yana qara niraq',
    '🦻🏻' => 'ninri uyarisqa yanapayniwan: chuya qara niraq',
    '🦻🏼' => 'ninri uyarisqa yanapayniwan: tunpa chuya qara niraq',
    '🦻🏽' => 'ninri uyarisqa yanapayniwan: tunpa qara niraq',
    '🦻🏾' => 'ninri uyarisqa yanapayniwan: tunpa yana qara niraq',
    '🦻🏿' => 'ninri uyarisqa yanapayniwan: yana qara niraq',
    '👃🏻' => 'sinqa: chuya qara niraq',
    '👃🏼' => 'sinqa: tunpa chuya qara niraq',
    '👃🏽' => 'sinqa: tunpa qara niraq',
    '👃🏾' => 'sinqa: tunpa yana qara niraq',
    '👃🏿' => 'sinqa: yana qara niraq',
    '👶🏻' => 'wawa: chuya qara niraq',
    '👶🏼' => 'wawa: tunpa chuya qara niraq',
    '👶🏽' => 'wawa: tunpa qara niraq',
    '👶🏾' => 'wawa: tunpa yana qara niraq',
    '👶🏿' => 'wawa: yana qara niraq',
    '🧒🏻' => 'irqi: chuya qara niraq',
    '🧒🏼' => 'irqi: tunpa chuya qara niraq',
    '🧒🏽' => 'irqi: tunpa qara niraq',
    '🧒🏾' => 'irqi: tunpa yana qara niraq',
    '🧒🏿' => 'irqi: yana qara niraq',
    '👦🏻' => 'yuqalla: chuya qara niraq',
    '👦🏼' => 'yuqalla: tunpa chuya qara niraq',
    '👦🏽' => 'yuqalla: tunpa qara niraq',
    '👦🏾' => 'yuqalla: tunpa yana qara niraq',
    '👦🏿' => 'yuqalla: yana qara niraq',
    '👧🏻' => 'warmi warma: chuya qara niraq',
    '👧🏼' => 'warmi warma: tunpa chuya qara niraq',
    '👧🏽' => 'warmi warma: tunpa qara niraq',
    '👧🏾' => 'warmi warma: tunpa yana qara niraq',
    '👧🏿' => 'warmi warma: yana qara niraq',
    '🧑🏻' => 'runa: chuya qara niraq',
    '🧑🏼' => 'runa: tunpa chuya qara niraq',
    '🧑🏽' => 'runa: tunpa qara niraq',
    '🧑🏾' => 'runa: tunpa yana qara niraq',
    '🧑🏿' => 'runa: yana qara niraq',
    '👱🏻' => 'runa: chuya qara niraq, qillu chukcha',
    '👱🏼' => 'runa: tunpa chuya qara niraq, qillu chukcha',
    '👱🏽' => 'runa: tunpa qara niraq, qillu chukcha',
    '👱🏾' => 'runa: tunpa yana qara niraq, qillu chukcha',
    '👱🏿' => 'runa: yana qara niraq, qillu chukcha',
    '👨🏻' => 'qari: chuya qara niraq',
    '👨🏼' => 'qari: tunpa chuya qara niraq',
    '👨🏽' => 'qari: tunpa qara niraq',
    '👨🏾' => 'qari: tunpa yana qara niraq',
    '👨🏿' => 'qari: yana qara niraq',
    '🧔🏻' => 'runa: chuya qara niraq, kʼaki',
    '🧔🏼' => 'runa: tunpa chuya qara niraq, kʼaki',
    '🧔🏽' => 'runa: tunpa qara niraq, kʼaki',
    '🧔🏾' => 'runa: tunpa yana qara niraq, kʼaki',
    '🧔🏿' => 'runa: yana qara niraq, kʼaki',
    '👩🏻' => 'warmi: chuya qara niraq',
    '👩🏼' => 'warmi: tunpa chuya qara niraq',
    '👩🏽' => 'warmi: tunpa qara niraq',
    '👩🏾' => 'warmi: tunpa yana qara niraq',
    '👩🏿' => 'warmi: yana qara niraq',
    '🧓🏻' => 'ñawpa runa: chuya qara niraq',
    '🧓🏼' => 'ñawpa runa: tunpa chuya qara niraq',
    '🧓🏽' => 'ñawpa runa: tunpa qara niraq',
    '🧓🏾' => 'ñawpa runa: tunpa yana qara niraq',
    '🧓🏿' => 'ñawpa runa: yana qara niraq',
    '👴🏻' => 'hatun tata: chuya qara niraq',
    '👴🏼' => 'hatun tata: tunpa chuya qara niraq',
    '👴🏽' => 'hatun tata: tunpa qara niraq',
    '👴🏾' => 'hatun tata: tunpa yana qara niraq',
    '👴🏿' => 'hatun tata: yana qara niraq',
    '👵🏻' => 'hatun mama: chuya qara niraq',
    '👵🏼' => 'hatun mama: tunpa chuya qara niraq',
    '👵🏽' => 'hatun mama: tunpa qara niraq',
    '👵🏾' => 'hatun mama: tunpa yana qara niraq',
    '👵🏿' => 'hatun mama: yana qara niraq',
    '🙍🏻' => 'llakisqa runa: chuya qara niraq',
    '🙍🏼' => 'llakisqa runa: tunpa chuya qara niraq',
    '🙍🏽' => 'llakisqa runa: tunpa qara niraq',
    '🙍🏾' => 'llakisqa runa: tunpa yana qara niraq',
    '🙍🏿' => 'llakisqa runa: yana qara niraq',
    '🙎🏻' => 'phiñachisqa runa: chuya qara niraq',
    '🙎🏼' => 'phiñachisqa runa: tunpa chuya qara niraq',
    '🙎🏽' => 'phiñachisqa runa: tunpa qara niraq',
    '🙎🏾' => 'phiñachisqa runa: tunpa yana qara niraq',
    '🙎🏿' => 'phiñachisqa runa: yana qara niraq',
    '🙅🏻' => 'runa MANA rikuy: chuya qara niraq',
    '🙅🏼' => 'runa MANA rikuy: tunpa chuya qara niraq',
    '🙅🏽' => 'runa MANA rikuy: tunpa qara niraq',
    '🙅🏾' => 'runa MANA rikuy: tunpa yana qara niraq',
    '🙅🏿' => 'runa MANA rikuy: yana qara niraq',
    '🙆🏻' => 'runa UYAKUY rikuy: chuya qara niraq',
    '🙆🏼' => 'runa UYAKUY rikuy: tunpa chuya qara niraq',
    '🙆🏽' => 'runa UYAKUY rikuy: tunpa qara niraq',
    '🙆🏾' => 'runa UYAKUY rikuy: tunpa yana qara niraq',
    '🙆🏿' => 'runa UYAKUY rikuy: yana qara niraq',
    '💁🏻' => 'runa willakuy kitipi: chuya qara niraq',
    '💁🏼' => 'runa willakuy kitipi: tunpa chuya qara niraq',
    '💁🏽' => 'runa willakuy kitipi: tunpa qara niraq',
    '💁🏾' => 'runa willakuy kitipi: tunpa yana qara niraq',
    '💁🏿' => 'runa willakuy kitipi: yana qara niraq',
    '🙋🏻' => 'runa makita hatarichiy: chuya qara niraq',
    '🙋🏼' => 'runa makita hatarichiy: tunpa chuya qara niraq',
    '🙋🏽' => 'runa makita hatarichiy: tunpa qara niraq',
    '🙋🏾' => 'runa makita hatarichiy: tunpa yana qara niraq',
    '🙋🏿' => 'runa makita hatarichiy: yana qara niraq',
    '🧏🏻' => 'luqtʼu runa: chuya qara niraq',
    '🧏🏼' => 'luqtʼu runa: tunpa chuya qara niraq',
    '🧏🏽' => 'luqtʼu runa: tunpa qara niraq',
    '🧏🏾' => 'luqtʼu runa: tunpa yana qara niraq',
    '🧏🏿' => 'luqtʼu runa: yana qara niraq',
    '🙇🏻' => 'upaykusqa runa: chuya qara niraq',
    '🙇🏼' => 'upaykusqa runa: tunpa chuya qara niraq',
    '🙇🏽' => 'upaykusqa runa: tunpa qara niraq',
    '🙇🏾' => 'upaykusqa runa: tunpa yana qara niraq',
    '🙇🏿' => 'upaykusqa runa: yana qara niraq',
    '🤦🏻' => 'runa makian uyapi: chuya qara niraq',
    '🤦🏼' => 'runa makian uyapi: tunpa chuya qara niraq',
    '🤦🏽' => 'runa makian uyapi: tunpa qara niraq',
    '🤦🏾' => 'runa makian uyapi: tunpa yana qara niraq',
    '🤦🏿' => 'runa makian uyapi: yana qara niraq',
    '🤷🏻' => 'runa rikrakunayuq hatarichiy: chuya qara niraq',
    '🤷🏼' => 'runa rikrakunayuq hatarichiy: tunpa chuya qara niraq',
    '🤷🏽' => 'runa rikrakunayuq hatarichiy: tunpa qara niraq',
    '🤷🏾' => 'runa rikrakunayuq hatarichiy: tunpa yana qara niraq',
    '🤷🏿' => 'runa rikrakunayuq hatarichiy: yana qara niraq',
    '👮🏻' => 'policia: chuya qara niraq',
    '👮🏼' => 'policia: tunpa chuya qara niraq',
    '👮🏽' => 'policia: tunpa qara niraq',
    '👮🏾' => 'policia: tunpa yana qara niraq',
    '👮🏿' => 'policia: yana qara niraq',
    '🕵🏻' => 'qhamiyaq: chuya qara niraq',
    '🕵🏼' => 'qhamiyaq: tunpa chuya qara niraq',
    '🕵🏽' => 'qhamiyaq: tunpa qara niraq',
    '🕵🏾' => 'qhamiyaq: tunpa yana qara niraq',
    '🕵🏿' => 'qhamiyaq: yana qara niraq',
    '💂🏻' => 'guardia: chuya qara niraq',
    '💂🏼' => 'guardia: tunpa chuya qara niraq',
    '💂🏽' => 'guardia: tunpa qara niraq',
    '💂🏾' => 'guardia: tunpa yana qara niraq',
    '💂🏿' => 'guardia: yana qara niraq',
    '🥷🏻' => 'ninja: chuya qara niraq',
    '🥷🏼' => 'ninja: tunpa chuya qara niraq',
    '🥷🏽' => 'ninja: tunpa qara niraq',
    '🥷🏾' => 'ninja: tunpa yana qara niraq',
    '🥷🏿' => 'ninja: yana qara niraq',
    '👷🏻' => 'Pirqaq: chuya qara niraq',
    '👷🏼' => 'Pirqaq: tunpa chuya qara niraq',
    '👷🏽' => 'Pirqaq: tunpa qara niraq',
    '👷🏾' => 'Pirqaq: tunpa yana qara niraq',
    '👷🏿' => 'Pirqaq: yana qara niraq',
    '🫅🏻' => 'runa kurunawan: chuya qara niraq',
    '🫅🏼' => 'runa kurunawan: tunpa chuya qara niraq',
    '🫅🏽' => 'runa kurunawan: tunpa qara niraq',
    '🫅🏾' => 'runa kurunawan: tunpa yana qara niraq',
    '🫅🏿' => 'runa kurunawan: yana qara niraq',
    '🤴🏻' => 'awki: chuya qara niraq',
    '🤴🏼' => 'awki: tunpa chuya qara niraq',
    '🤴🏽' => 'awki: tunpa qara niraq',
    '🤴🏾' => 'awki: tunpa yana qara niraq',
    '🤴🏿' => 'awki: yana qara niraq',
    '👸🏻' => 'ñusta: chuya qara niraq',
    '👸🏼' => 'ñusta: tunpa chuya qara niraq',
    '👸🏽' => 'ñusta: tunpa qara niraq',
    '👸🏾' => 'ñusta: tunpa yana qara niraq',
    '👸🏿' => 'ñusta: yana qara niraq',
    '👳🏻' => 'runa turbantewan: chuya qara niraq',
    '👳🏼' => 'runa turbantewan: tunpa chuya qara niraq',
    '👳🏽' => 'runa turbantewan: tunpa qara niraq',
    '👳🏾' => 'runa turbantewan: tunpa yana qara niraq',
    '👳🏿' => 'runa turbantewan: yana qara niraq',
    '👲🏻' => 'runa casquetewan: chuya qara niraq',
    '👲🏼' => 'runa casquetewan: tunpa chuya qara niraq',
    '👲🏽' => 'runa casquetewan: tunpa qara niraq',
    '👲🏾' => 'runa casquetewan: tunpa yana qara niraq',
    '👲🏿' => 'runa casquetewan: yana qara niraq',
    '🧕🏻' => 'warmi barbijowan: chuya qara niraq',
    '🧕🏼' => 'warmi barbijowan: tunpa chuya qara niraq',
    '🧕🏽' => 'warmi barbijowan: tunpa qara niraq',
    '🧕🏾' => 'warmi barbijowan: tunpa yana qara niraq',
    '🧕🏿' => 'warmi barbijowan: yana qara niraq',
    '🤵🏻' => 'runa tuxedopi: chuya qara niraq',
    '🤵🏼' => 'runa tuxedopi: tunpa chuya qara niraq',
    '🤵🏽' => 'runa tuxedopi: tunpa qara niraq',
    '🤵🏾' => 'runa tuxedopi: tunpa yana qara niraq',
    '🤵🏿' => 'runa tuxedopi: yana qara niraq',
    '👰🏻' => 'runa velowan: chuya qara niraq',
    '👰🏼' => 'runa velowan: tunpa chuya qara niraq',
    '👰🏽' => 'runa velowan: tunpa qara niraq',
    '👰🏾' => 'runa velowan: tunpa yana qara niraq',
    '👰🏿' => 'runa velowan: yana qara niraq',
    '🤰🏻' => 'wiksayuq warmi: chuya qara niraq',
    '🤰🏼' => 'wiksayuq warmi: tunpa chuya qara niraq',
    '🤰🏽' => 'wiksayuq warmi: tunpa qara niraq',
    '🤰🏾' => 'wiksayuq warmi: tunpa yana qara niraq',
    '🤰🏿' => 'wiksayuq warmi: yana qara niraq',
    '🫃🏻' => 'qari wiksayuq: chuya qara niraq',
    '🫃🏼' => 'qari wiksayuq: tunpa chuya qara niraq',
    '🫃🏽' => 'qari wiksayuq: tunpa qara niraq',
    '🫃🏾' => 'qari wiksayuq: tunpa yana qara niraq',
    '🫃🏿' => 'qari wiksayuq: yana qara niraq',
    '🫄🏻' => 'wiksayuq runa: chuya qara niraq',
    '🫄🏼' => 'wiksayuq runa: tunpa chuya qara niraq',
    '🫄🏽' => 'wiksayuq runa: tunpa qara niraq',
    '🫄🏾' => 'wiksayuq runa: tunpa yana qara niraq',
    '🫄🏿' => 'wiksayuq runa: yana qara niraq',
    '🤱🏻' => 'ñuñuchiy: chuya qara niraq',
    '🤱🏼' => 'ñuñuchiy: tunpa chuya qara niraq',
    '🤱🏽' => 'ñuñuchiy: tunpa qara niraq',
    '🤱🏾' => 'ñuñuchiy: tunpa yana qara niraq',
    '🤱🏿' => 'ñuñuchiy: yana qara niraq',
    '👼🏻' => 'wawa angel: chuya qara niraq',
    '👼🏼' => 'wawa angel: tunpa chuya qara niraq',
    '👼🏽' => 'wawa angel: tunpa qara niraq',
    '👼🏾' => 'wawa angel: tunpa yana qara niraq',
    '👼🏿' => 'wawa angel: yana qara niraq',
    '🎅🏻' => 'Papa Noel: chuya qara niraq',
    '🎅🏼' => 'Papa Noel: tunpa chuya qara niraq',
    '🎅🏽' => 'Papa Noel: tunpa qara niraq',
    '🎅🏾' => 'Papa Noel: tunpa yana qara niraq',
    '🎅🏿' => 'Papa Noel: yana qara niraq',
    '🤶🏻' => 'Mama Noel: chuya qara niraq',
    '🤶🏼' => 'Mama Noel: tunpa chuya qara niraq',
    '🤶🏽' => 'Mama Noel: tunpa qara niraq',
    '🤶🏾' => 'Mama Noel: tunpa yana qara niraq',
    '🤶🏿' => 'Mama Noel: yana qara niraq',
    '🦸🏻' => 'superheroe: chuya qara niraq',
    '🦸🏼' => 'superheroe: tunpa chuya qara niraq',
    '🦸🏽' => 'superheroe: tunpa qara niraq',
    '🦸🏾' => 'superheroe: tunpa yana qara niraq',
    '🦸🏿' => 'superheroe: yana qara niraq',
    '🦹🏻' => 'supervillano: chuya qara niraq',
    '🦹🏼' => 'supervillano: tunpa chuya qara niraq',
    '🦹🏽' => 'supervillano: tunpa qara niraq',
    '🦹🏾' => 'supervillano: tunpa yana qara niraq',
    '🦹🏿' => 'supervillano: yana qara niraq',
    '🧙🏻' => 'watuq: chuya qara niraq',
    '🧙🏼' => 'watuq: tunpa chuya qara niraq',
    '🧙🏽' => 'watuq: tunpa qara niraq',
    '🧙🏾' => 'watuq: tunpa yana qara niraq',
    '🧙🏿' => 'watuq: yana qara niraq',
    '🧚🏻' => 'hada: chuya qara niraq',
    '🧚🏼' => 'hada: tunpa chuya qara niraq',
    '🧚🏽' => 'hada: tunpa qara niraq',
    '🧚🏾' => 'hada: tunpa yana qara niraq',
    '🧚🏿' => 'hada: yana qara niraq',
    '🧛🏻' => 'vampiro: chuya qara niraq',
    '🧛🏼' => 'vampiro: tunpa chuya qara niraq',
    '🧛🏽' => 'vampiro: tunpa qara niraq',
    '🧛🏾' => 'vampiro: tunpa yana qara niraq',
    '🧛🏿' => 'vampiro: yana qara niraq',
    '🧜🏻' => 'runa sirena: chuya qara niraq',
    '🧜🏼' => 'runa sirena: tunpa chuya qara niraq',
    '🧜🏽' => 'runa sirena: tunpa qara niraq',
    '🧜🏾' => 'runa sirena: tunpa yana qara niraq',
    '🧜🏿' => 'runa sirena: yana qara niraq',
    '🧝🏻' => 'elfo: chuya qara niraq',
    '🧝🏼' => 'elfo: tunpa chuya qara niraq',
    '🧝🏽' => 'elfo: tunpa qara niraq',
    '🧝🏾' => 'elfo: tunpa yana qara niraq',
    '🧝🏿' => 'elfo: yana qara niraq',
    '💆🏻' => 'runa masaje uyapi: chuya qara niraq',
    '💆🏼' => 'runa masaje uyapi: tunpa chuya qara niraq',
    '💆🏽' => 'runa masaje uyapi: tunpa qara niraq',
    '💆🏾' => 'runa masaje uyapi: tunpa yana qara niraq',
    '💆🏿' => 'runa masaje uyapi: yana qara niraq',
    '💇🏻' => 'runa chukcha rutukuy: chuya qara niraq',
    '💇🏼' => 'runa chukcha rutukuy: tunpa chuya qara niraq',
    '💇🏽' => 'runa chukcha rutukuy: tunpa qara niraq',
    '💇🏾' => 'runa chukcha rutukuy: tunpa yana qara niraq',
    '💇🏿' => 'runa chukcha rutukuy: yana qara niraq',
    '🚶🏻' => 'runa purichkan: chuya qara niraq',
    '🚶🏼' => 'runa purichkan: tunpa chuya qara niraq',
    '🚶🏽' => 'runa purichkan: tunpa qara niraq',
    '🚶🏾' => 'runa purichkan: tunpa yana qara niraq',
    '🚶🏿' => 'runa purichkan: yana qara niraq',
    '🧍🏻' => 'runa sayariy: chuya qara niraq',
    '🧍🏼' => 'runa sayariy: tunpa chuya qara niraq',
    '🧍🏽' => 'runa sayariy: tunpa qara niraq',
    '🧍🏾' => 'runa sayariy: tunpa yana qara niraq',
    '🧍🏿' => 'runa sayariy: yana qara niraq',
    '🧎🏻' => 'qunqurisqa runa: chuya qara niraq',
    '🧎🏼' => 'qunqurisqa runa: tunpa chuya qara niraq',
    '🧎🏽' => 'qunqurisqa runa: tunpa qara niraq',
    '🧎🏾' => 'qunqurisqa runa: tunpa yana qara niraq',
    '🧎🏿' => 'qunqurisqa runa: yana qara niraq',
    '🏃🏻' => 'runa phawachkan: chuya qara niraq',
    '🏃🏼' => 'runa phawachkan: tunpa chuya qara niraq',
    '🏃🏽' => 'runa phawachkan: tunpa qara niraq',
    '🏃🏾' => 'runa phawachkan: tunpa yana qara niraq',
    '🏃🏿' => 'runa phawachkan: yana qara niraq',
    '💃🏻' => 'warmi tusuchkan: chuya qara niraq',
    '💃🏼' => 'warmi tusuchkan: tunpa chuya qara niraq',
    '💃🏽' => 'warmi tusuchkan: tunpa qara niraq',
    '💃🏾' => 'warmi tusuchkan: tunpa yana qara niraq',
    '💃🏿' => 'warmi tusuchkan: yana qara niraq',
    '🕺🏻' => 'runa tusuchkan: chuya qara niraq',
    '🕺🏼' => 'runa tusuchkan: tunpa chuya qara niraq',
    '🕺🏽' => 'runa tusuchkan: tunpa qara niraq',
    '🕺🏾' => 'runa tusuchkan: tunpa yana qara niraq',
    '🕺🏿' => 'runa tusuchkan: yana qara niraq',
    '🕴🏻' => 'runa trajepi levitando: chuya qara niraq',
    '🕴🏼' => 'runa trajepi levitando: tunpa chuya qara niraq',
    '🕴🏽' => 'runa trajepi levitando: tunpa qara niraq',
    '🕴🏾' => 'runa trajepi levitando: tunpa yana qara niraq',
    '🕴🏿' => 'runa trajepi levitando: yana qara niraq',
    '👯🏻' => 'runakuna quwi ninrikunawan: chuya qara niraq',
    '👯🏼' => 'runakuna quwi ninrikunawan: tunpa chuya qara niraq',
    '👯🏽' => 'runakuna quwi ninrikunawan: tunpa qara niraq',
    '👯🏾' => 'runakuna quwi ninrikunawan: tunpa yana qara niraq',
    '👯🏿' => 'runakuna quwi ninrikunawan: yana qara niraq',
    '🧖🏻' => 'runa wapsi wasipi: chuya qara niraq',
    '🧖🏼' => 'runa wapsi wasipi: tunpa chuya qara niraq',
    '🧖🏽' => 'runa wapsi wasipi: tunpa qara niraq',
    '🧖🏾' => 'runa wapsi wasipi: tunpa yana qara niraq',
    '🧖🏿' => 'runa wapsi wasipi: yana qara niraq',
    '🧗🏻' => 'wichaq runa: chuya qara niraq',
    '🧗🏼' => 'wichaq runa: tunpa chuya qara niraq',
    '🧗🏽' => 'wichaq runa: tunpa qara niraq',
    '🧗🏾' => 'wichaq runa: tunpa yana qara niraq',
    '🧗🏿' => 'wichaq runa: yana qara niraq',
    '🏇🏻' => 'atipanaku kawallukuna: chuya qara niraq',
    '🏇🏼' => 'atipanaku kawallukuna: tunpa chuya qara niraq',
    '🏇🏽' => 'atipanaku kawallukuna: tunpa qara niraq',
    '🏇🏾' => 'atipanaku kawallukuna: tunpa yana qara niraq',
    '🏇🏿' => 'atipanaku kawallukuna: yana qara niraq',
    '🏂🏻' => 'snowboarder: chuya qara niraq',
    '🏂🏼' => 'snowboarder: tunpa chuya qara niraq',
    '🏂🏽' => 'snowboarder: tunpa qara niraq',
    '🏂🏾' => 'snowboarder: tunpa yana qara niraq',
    '🏂🏿' => 'snowboarder: yana qara niraq',
    '🏌🏻' => 'golfista: chuya qara niraq',
    '🏌🏼' => 'golfista: tunpa chuya qara niraq',
    '🏌🏽' => 'golfista: tunpa qara niraq',
    '🏌🏾' => 'golfista: tunpa yana qara niraq',
    '🏌🏿' => 'golfista: yana qara niraq',
    '🏄🏻' => 'runa surfeando: chuya qara niraq',
    '🏄🏼' => 'runa surfeando: tunpa chuya qara niraq',
    '🏄🏽' => 'runa surfeando: tunpa qara niraq',
    '🏄🏾' => 'runa surfeando: tunpa yana qara niraq',
    '🏄🏿' => 'runa surfeando: yana qara niraq',
    '🚣🏻' => 'runa wampʼu rmoswan: chuya qara niraq',
    '🚣🏼' => 'runa wampʼu rmoswan: tunpa chuya qara niraq',
    '🚣🏽' => 'runa wampʼu rmoswan: tunpa qara niraq',
    '🚣🏾' => 'runa wampʼu rmoswan: tunpa yana qara niraq',
    '🚣🏿' => 'runa wampʼu rmoswan: yana qara niraq',
    '🏊🏻' => 'runa waytʼachkan: chuya qara niraq',
    '🏊🏼' => 'runa waytʼachkan: tunpa chuya qara niraq',
    '🏊🏽' => 'runa waytʼachkan: tunpa qara niraq',
    '🏊🏾' => 'runa waytʼachkan: tunpa yana qara niraq',
    '🏊🏿' => 'runa waytʼachkan: yana qara niraq',
    '⛹🏻' => 'runa p’uluta chuqapachkan: chuya qara niraq',
    '⛹🏼' => 'runa p’uluta chuqapachkan: tunpa chuya qara niraq',
    '⛹🏽' => 'runa p’uluta chuqapachkan: tunpa qara niraq',
    '⛹🏾' => 'runa p’uluta chuqapachkan: tunpa yana qara niraq',
    '⛹🏿' => 'runa p’uluta chuqapachkan: yana qara niraq',
    '🏋🏻' => 'runa llasayninkunata jatarichichkan: chuya qara niraq',
    '🏋🏼' => 'runa llasayninkunata jatarichichkan: tunpa chuya qara niraq',
    '🏋🏽' => 'runa llasayninkunata jatarichichkan: tunpa qara niraq',
    '🏋🏾' => 'runa llasayninkunata jatarichichkan: tunpa yana qara niraq',
    '🏋🏿' => 'runa llasayninkunata jatarichichkan: yana qara niraq',
    '🚴🏻' => 'runa bicicletapi: chuya qara niraq',
    '🚴🏼' => 'runa bicicletapi: tunpa chuya qara niraq',
    '🚴🏽' => 'runa bicicletapi: tunpa qara niraq',
    '🚴🏾' => 'runa bicicletapi: tunpa yana qara niraq',
    '🚴🏿' => 'runa bicicletapi: yana qara niraq',
    '🚵🏻' => 'runa urqu bicicletapi: chuya qara niraq',
    '🚵🏼' => 'runa urqu bicicletapi: tunpa chuya qara niraq',
    '🚵🏽' => 'runa urqu bicicletapi: tunpa qara niraq',
    '🚵🏾' => 'runa urqu bicicletapi: tunpa yana qara niraq',
    '🚵🏿' => 'runa urqu bicicletapi: yana qara niraq',
    '🤸🏻' => 'runa gimnasia ruwachkan: chuya qara niraq',
    '🤸🏼' => 'runa gimnasia ruwachkan: tunpa chuya qara niraq',
    '🤸🏽' => 'runa gimnasia ruwachkan: tunpa qara niraq',
    '🤸🏾' => 'runa gimnasia ruwachkan: tunpa yana qara niraq',
    '🤸🏿' => 'runa gimnasia ruwachkan: yana qara niraq',
    '🤼🏻' => 'maqanakuq runa: chuya qara niraq',
    '🤼🏼' => 'maqanakuq runa: tunpa chuya qara niraq',
    '🤼🏽' => 'maqanakuq runa: tunpa qara niraq',
    '🤼🏾' => 'maqanakuq runa: tunpa yana qara niraq',
    '🤼🏿' => 'maqanakuq runa: yana qara niraq',
    '🤽🏻' => 'runa water polo pukllachkan: chuya qara niraq',
    '🤽🏼' => 'runa water polo pukllachkan: tunpa chuya qara niraq',
    '🤽🏽' => 'runa water polo pukllachkan: tunpa qara niraq',
    '🤽🏾' => 'runa water polo pukllachkan: tunpa yana qara niraq',
    '🤽🏿' => 'runa water polo pukllachkan: yana qara niraq',
    '🤾🏻' => 'runa balonmano pukllachkan: chuya qara niraq',
    '🤾🏼' => 'runa balonmano pukllachkan: tunpa chuya qara niraq',
    '🤾🏽' => 'runa balonmano pukllachkan: tunpa qara niraq',
    '🤾🏾' => 'runa balonmano pukllachkan: tunpa yana qara niraq',
    '🤾🏿' => 'runa balonmano pukllachkan: yana qara niraq',
    '🤹🏻' => 'runa malabares ruwachkan: chuya qara niraq',
    '🤹🏼' => 'runa malabares ruwachkan: tunpa chuya qara niraq',
    '🤹🏽' => 'runa malabares ruwachkan: tunpa qara niraq',
    '🤹🏾' => 'runa malabares ruwachkan: tunpa yana qara niraq',
    '🤹🏿' => 'runa malabares ruwachkan: yana qara niraq',
    '🧘🏻' => 'runa yoga yupipi: chuya qara niraq',
    '🧘🏼' => 'runa yoga yupipi: tunpa chuya qara niraq',
    '🧘🏽' => 'runa yoga yupipi: tunpa qara niraq',
    '🧘🏾' => 'runa yoga yupipi: tunpa yana qara niraq',
    '🧘🏿' => 'runa yoga yupipi: yana qara niraq',
    '🛀🏻' => 'runa armakuyniyuq: chuya qara niraq',
    '🛀🏼' => 'runa armakuyniyuq: tunpa chuya qara niraq',
    '🛀🏽' => 'runa armakuyniyuq: tunpa qara niraq',
    '🛀🏾' => 'runa armakuyniyuq: tunpa yana qara niraq',
    '🛀🏿' => 'runa armakuyniyuq: yana qara niraq',
    '🛌🏻' => 'runa puñunapi: chuya qara niraq',
    '🛌🏼' => 'runa puñunapi: tunpa chuya qara niraq',
    '🛌🏽' => 'runa puñunapi: tunpa qara niraq',
    '🛌🏾' => 'runa puñunapi: tunpa yana qara niraq',
    '🛌🏿' => 'runa puñunapi: yana qara niraq',
    '👭🏻' => 'warmi iskay makikunawan: chuya qara niraq',
    '👭🏼' => 'warmi iskay makikunawan: tunpa chuya qara niraq',
    '👭🏽' => 'warmi iskay makikunawan: tunpa qara niraq',
    '👭🏾' => 'warmi iskay makikunawan: tunpa yana qara niraq',
    '👭🏿' => 'warmi iskay makikunawan: yana qara niraq',
    '👫🏻' => 'warmi chaymanta runa iskay makikunawan: chuya qara niraq',
    '👫🏼' => 'warmi chaymanta runa iskay makikunawan: tunpa chuya qara niraq',
    '👫🏽' => 'warmi chaymanta runa iskay makikunawan: tunpa qara niraq',
    '👫🏾' => 'warmi chaymanta runa iskay makikunawan: tunpa yana qara niraq',
    '👫🏿' => 'warmi chaymanta runa iskay makikunawan: yana qara niraq',
    '👬🏻' => 'runa iskay makikunawan: chuya qara niraq',
    '👬🏼' => 'runa iskay makikunawan: tunpa chuya qara niraq',
    '👬🏽' => 'runa iskay makikunawan: tunpa qara niraq',
    '👬🏾' => 'runa iskay makikunawan: tunpa yana qara niraq',
    '👬🏿' => 'runa iskay makikunawan: yana qara niraq',
    '💏🏻' => 'much’a: chuya qara niraq',
    '💏🏼' => 'much’a: tunpa chuya qara niraq',
    '💏🏽' => 'much’a: tunpa qara niraq',
    '💏🏾' => 'much’a: tunpa yana qara niraq',
    '💏🏿' => 'much’a: yana qara niraq',
    '💑🏻' => 'pitu runakuna sunquwan: chuya qara niraq',
    '💑🏼' => 'pitu runakuna sunquwan: tunpa chuya qara niraq',
    '💑🏽' => 'pitu runakuna sunquwan: tunpa qara niraq',
    '💑🏾' => 'pitu runakuna sunquwan: tunpa yana qara niraq',
    '💑🏿' => 'pitu runakuna sunquwan: yana qara niraq',
    '🏻' => 'chuya qara niraq',
    '🏼' => 'tunpa chuya qara niraq',
    '🏽' => 'tunpa qara niraq',
    '🏾' => 'tunpa yana qara niraq',
    '🏿' => 'yana qara niraq',
    '😀' => 'kusisqa uya',
    '😃' => 'kusisqa uya hatun ñawikunawan',
    '😄' => 'kusisqa uya kusisqa ñawikunawan',
    '😁' => 'kancharisqa uya kusisqa ñawikunawan',
    '😆' => 'kusisqa uya wichqasqa ñawikunawan',
    '😅' => 'kusisqa uya sutʼuwan',
    '🤣' => 'muyusqa kusi jallpʼapi',
    '😂' => 'kusisqa uya wiqikunawan',
    '🙂' => 'pisi kusisqa uya',
    '🙃' => 'tikrasqa uya',
    '🫠' => 'chullusqa uya',
    '😉' => 'chʼirmi uya',
    '😊' => 'kusisqa uyata kusisqa ñawikunawan',
    '😇' => 'kusisqa uya aureolawan',
    '🥰' => 'kusisqa uya sunqukunawan',
    '😍' => 'kusisqa uya sunqukunawan ñawikunapi',
    '🤩' => 'quyllur añasqa',
    '😘' => 'uya chʼamqasqa huk muchʼata',
    '😗' => 'muchʼasqa uya',
    '☺' => 'chiqchisqa uya',
    '😚' => 'muchʼasqa uyata wichqasqa ñawikunawan',
    '😙' => 'muchʼasqa uyata kusisqa ñawikunawan',
    '🥲' => 'kusisqa uya wiqiwan',
    '😋' => 'uya mikuspa mikuna',
    '😛' => 'uya qalluwan',
    '😜' => 'chʼirmi uya qalluwan',
    '🤪' => 'waqʼa uya',
    '😝' => 'wichqasqa ñawikuna qalluwan',
    '🤑' => 'simi qullqiwan uya',
    '🤗' => 'kusisqa uya kichasqa makikunawan',
    '🤭' => 'uya makiwan simipi',
    '🫢' => 'uya kichasqa ñawikunawan maki simipi',
    '🫣' => 'uya chinkachisqa ñawiwan',
    '🤫' => 'chin niy uya',
    '🤔' => 'yuyasqa uya',
    '🫡' => 'uya rimaykuspa',
    '🤐' => 'uya ziper simipi',
    '🤨' => 'uya wichasqa urku chukchapi',
    '😐' => 'chusaq uya',
    '😑' => 'mana rimasqa uya',
    '😶' => 'uya mana simiyuqwan',
    '🫥' => 'chusupa siqinwan uya',
    '😏' => 'kʼaskiskachasqa uya',
    '😒' => 'mana kusisqa uya',
    '🙄' => 'uya muyusqa ñawikunawan',
    '😬' => 'uya muecaswan',
    '🤥' => 'llullakusqa uya',
    '🫨' => 'kuyusqa uya',
    '😌' => 'llamsayasqa uya',
    '😔' => 'yuyaspa uya',
    '😪' => 'uya puñuywan',
    '🤤' => 'llawsasuru uyu',
    '😴' => 'puñusqa uya',
    '🫩' => 'ñawi urapi bolsayuq uya',
    '😷' => 'uya barbijowan',
    '🤒' => 'termometrowan uya',
    '🤕' => 'uya manku umawan',
    '🤢' => 'unqusqa uya',
    '🤮' => 'wischusqa uya',
    '🤧' => 'jachisqa uya',
    '🥵' => 'qʼuñi uya',
    '🥶' => 'chiri uya',
    '🥴' => 'uma muyuy',
    '😵' => 'takasqa uya',
    '🤯' => 'tuqyasqa uma',
    '🤠' => 'baquero uya chukuwan',
    '🥳' => 'qʼuchukusqa uya',
    '🥸' => 'pakasqa uya',
    '😎' => 'kusisqa uya lenteswan',
    '🤓' => 'yuyaq uya',
    '🧐' => 'uya monoculowan',
    '😕' => 'chaqrusqa uya',
    '🫤' => 'uya wiksu simiwan',
    '😟' => 'llakisqa uya',
    '🙁' => 'pisi llakisqa uya',
    '☹' => 'sipʼusqa uya',
    '😮' => 'uya kichasqa simiwan',
    '😯' => 'chin kasqa uya',
    '😲' => 'añasqa uya',
    '😳' => 'manchakusqa uya',
    '🫪' => 'distorsionado uya',
    '🥺' => 'uyllasqa uya',
    '🥹' => 'uya wiqikunawan hapisqa',
    '😦' => 'añasqa uya kichasqa simiwan',
    '😧' => 'ñakʼari uya',
    '😨' => 'mancharisqa uya',
    '😰' => 'takurisqa uya sutʼuwan',
    '😥' => 'llakisqa ichaqa llamsayasqa uya',
    '😢' => 'waqasqa uya',
    '😭' => 'waqasqa uya wiqikunawan',
    '😱' => 'uya qaparisqa manchanawan',
    '😖' => 'pantasqa uya',
    '😣' => 'yanapakusqa uya',
    '😞' => 'sunqunnasqa uya',
    '😓' => 'llakisqa uya sutʼuwan',
    '😩' => 'ayqusqa uya',
    '😫' => 'saykusqa uya',
    '🥱' => 'hanyasqa uya',
    '😤' => 'uya qʼusñiwan sinqamanta',
    '😡' => 'piñasqa uya',
    '😠' => 'phiñakusqa uya',
    '🤬' => 'uya unanchakunawan simipi',
    '😈' => 'kusisqa uya waqrakunawan',
    '👿' => 'phiñakusqa uya waqrakunawan',
    '💀' => 'saqru',
    '☠' => 'saqru chaymanta chakatasqa tullukuna',
    '💩' => 'aka',
    '🤡' => 'pʼaqpaku uya',
    '👹' => 'ogro',
    '👺' => 'huchuy kuku',
    '👻' => 'kuku',
    '👽' => 'alien',
    '👾' => 'pʼarqa alienígena',
    '🤖' => 'robot',
    '😺' => 'kusisqa misi',
    '😸' => 'kusisqa misi uya kusisqa ñawikunawan',
    '😹' => 'misi wiqikunawan kusirikuyninmanta',
    '😻' => 'asisqa misi sunqukunawan ñawikunapi',
    '😼' => 'misi muyusqa kusiwan',
    '😽' => 'muchʼasqa misi',
    '🙀' => 'mancharisqa misi',
    '😿' => 'waqasqa misi',
    '😾' => 'turisqa misi',
    '🙈' => 'kusillo mana saqrayuqwan rikuy',
    '🙉' => 'kusillo mana saqrayuqwan uyariy',
    '🙊' => 'kusillo mana saqrayuqwan parlay',
    '💌' => 'munay qillqa',
    '💘' => 'sunqu wachʼiwan',
    '💝' => 'sunqu cintawan',
    '💖' => 'kʼanchasqa sunqu',
    '💗' => 'paqarisqa sunqu',
    '💓' => 'phatatasqa sunqu',
    '💞' => 'muyusqa sunqukuna',
    '💕' => 'iskay sunqukuna',
    '💟' => 'sunqu rikchay',
    '❣' => 'sunqu exclamasion',
    '💔' => 'pakasqa sunqu',
    '❤' => 'puka sunqu',
    '🩷' => 'rusadu sunqu',
    '🧡' => 'willapi sunqu',
    '💛' => 'qʼillu sunqu',
    '💚' => 'qʼumir sunqu',
    '💙' => 'anqas sunqu',
    '🩵' => 'chuya anqas sunqu',
    '💜' => 'kulli sunqu',
    '🤎' => 'cafe sunqu',
    '🖤' => 'yana sunqu',
    '🩶' => 'uqi sunqu',
    '🤍' => 'yuraq sunqu',
    '💋' => 'muchʼa unancha',
    '💯' => 'pachaq chikukuna',
    '💢' => 'phiñakuy unancha',
    '🫯' => 'maqanakuy phuyu',
    '💥' => 'tupa',
    '💫' => 'muyu muyu',
    '💦' => 'jumpʼi sutukuna',
    '💨' => 'karuman phawachkan',
    '🕳' => 't’uqu',
    '💬' => 'rimaypa glubun',
    '🗨' => 'lluq’i rimasqa phukpupi',
    '🗯' => 'paña phiñasqa phukpu',
    '💭' => 'yuyaypa glubun',
    '💤' => 'zzz',
    '👋' => 'qinquykachasqa maki',
    '🤚' => 'juqharisqa maki',
    '🖐' => 'maki iskay rukanakunawa mastasqa',
    '✋' => 'huqharisqa maki',
    '🖖' => 'vulcano napay',
    '🫱' => 'pañaman maki',
    '🫲' => 'lluqiman maki',
    '🫳' => 'uranman maki pampa',
    '🫴' => 'hanaqman maki pampa',
    '🫷' => 'tanqaspa lluqi maki',
    '🫸' => 'tanqaspa paña maki',
    '👌' => 'UYAKUY maki',
    '🤌' => 'tʼipsisqa rukanakuna',
    '🤏' => 'tʼipsisqa maki',
    '✌' => 'yalli maki',
    '🤞' => 'chakatasqa rukanakuna',
    '🫰' => 'maki chakatasqa iskay rukanawan',
    '🤟' => 'munanki yupi',
    '🤘' => 'waqrakuna unancha',
    '🤙' => 'waqyawani maki',
    '👈' => 'tʼupsi rukʼanawan lluqʼiman chimpuy',
    '👉' => 'tʼupsi rukʼanawan pañaman chimpuy',
    '👆' => 'tʼupsi rukʼanawan hanaqman chimpuy',
    '🖕' => 'chawpi rukana',
    '👇' => 'tʼupsi rukʼanawan uranman chimpuy',
    '☝' => 'rukʼanawan hanaqman chimpuy',
    '🫵' => 'indice rukanawan chimpusqa qawaqman',
    '👍' => 'hanaqpi rukʼana',
    '👎' => 'uranpi rukʼana',
    '✊' => 'juqharisqa saqma',
    '👊' => 'saqma unancha',
    '🤛' => 'lluqʼi saqma',
    '🤜' => 'paña saqma',
    '👏' => 'jayllisqa makikuna',
    '🙌' => 'juqharisqa makikuna',
    '🫶' => 'sunqu makikunawan',
    '👐' => 'kichasqa makikuna',
    '🤲' => 'makikunawan plegaria unancha',
    '🤝' => 'pipuyasqa makikunapura',
    '🙏' => 'makikuna rezando',
    '✍' => 'maki qillqachkan',
    '💅' => 'esmalte sillukunapaq',
    '🤳' => 'selfie',
    '💪' => 'iskaychasqa bicepkuna',
    '🦾' => 'mecanico maki',
    '🦿' => 'mecanico chaka',
    '🦵' => 'chanka',
    '🦶' => 'chaki',
    '👂' => 'ninri',
    '🦻' => 'ninri uyarisqa yanapayniwan',
    '👃' => 'sinqa',
    '🧠' => 'ñuqtu',
    '🫀' => 'anatomico sunqu',
    '🫁' => 'surqʼankuna',
    '🦷' => 'kiru',
    '🦴' => 'tullu',
    '👀' => 'ñawikuna',
    '👁' => 'ñawi',
    '👅' => 'qallu',
    '👄' => 'simi',
    '🫦' => 'kachupakuspa simi',
    '👶' => 'wawa',
    '🧒' => 'irqi',
    '👦' => 'yuqalla',
    '👧' => 'warmi warma',
    '🧑' => 'runa',
    '👱' => 'runa: qillu chukcha',
    '👨' => 'qari',
    '🧔' => 'runa: kʼaki',
    '👩' => 'warmi',
    '🧓' => 'ñawpa runa',
    '👴' => 'hatun tata',
    '👵' => 'hatun mama',
    '🙍' => 'llakisqa runa',
    '🙎' => 'phiñachisqa runa',
    '🙅' => 'runa MANA rikuy',
    '🙆' => 'runa UYAKUY rikuy',
    '💁' => 'runa willakuy kitipi',
    '🙋' => 'runa makita hatarichiy',
    '🧏' => 'luqtʼu runa',
    '🙇' => 'upaykusqa runa',
    '🤦' => 'runa makian uyapi',
    '🤷' => 'runa rikrakunayuq hatarichiy',
    '👮' => 'policia',
    '🕵' => 'qhamiyaq',
    '💂' => 'guardia',
    '🥷' => 'ninja',
    '👷' => 'Pirqaq',
    '🫅' => 'runa kurunawan',
    '🤴' => 'awki',
    '👸' => 'ñusta',
    '👳' => 'runa turbantewan',
    '👲' => 'runa casquetewan',
    '🧕' => 'warmi barbijowan',
    '🤵' => 'runa tuxedopi',
    '👰' => 'runa velowan',
    '🤰' => 'wiksayuq warmi',
    '🫃' => 'qari wiksayuq',
    '🫄' => 'wiksayuq runa',
    '🤱' => 'ñuñuchiy',
    '👼' => 'wawa angel',
    '🎅' => 'Papa Noel',
    '🤶' => 'Mama Noel',
    '🦸' => 'superheroe',
    '🦹' => 'supervillano',
    '🧙' => 'watuq',
    '🧚' => 'hada',
    '🧛' => 'vampiro',
    '🧜' => 'runa sirena',
    '🧝' => 'elfo',
    '🧞' => 'genio lamparamanta',
    '🧟' => 'zombi',
    '🧌' => 'troll nisqa',
    '🫈' => 'chukchasapa kawsaq',
    '💆' => 'runa masaje uyapi',
    '💇' => 'runa chukcha rutukuy',
    '🚶' => 'runa purichkan',
    '🧍' => 'runa sayariy',
    '🧎' => 'qunqurisqa runa',
    '🏃' => 'runa phawachkan',
    '💃' => 'warmi tusuchkan',
    '🕺' => 'runa tusuchkan',
    '🕴' => 'runa trajepi levitando',
    '👯' => 'runakuna quwi ninrikunawan',
    '🧖' => 'runa wapsi wasipi',
    '🧗' => 'wichaq runa',
    '🤺' => 'runa esgrimapi',
    '🏇' => 'atipanaku kawallukuna',
    '⛷' => 'esquiador',
    '🏂' => 'snowboarder',
    '🏌' => 'golfista',
    '🏄' => 'runa surfeando',
    '🚣' => 'runa wampʼu rmoswan',
    '🏊' => 'runa waytʼachkan',
    '⛹' => 'runa p’uluta chuqapachkan',
    '🏋' => 'runa llasayninkunata jatarichichkan',
    '🚴' => 'runa bicicletapi',
    '🚵' => 'runa urqu bicicletapi',
    '🤸' => 'runa gimnasia ruwachkan',
    '🤼' => 'maqanakuq runa',
    '🤽' => 'runa water polo pukllachkan',
    '🤾' => 'runa balonmano pukllachkan',
    '🤹' => 'runa malabares ruwachkan',
    '🧘' => 'runa yoga yupipi',
    '🛀' => 'runa armakuyniyuq',
    '🛌' => 'runa puñunapi',
    '👭' => 'warmi iskay makikunawan',
    '👫' => 'warmi chaymanta runa iskay makikunawan',
    '👬' => 'runa iskay makikunawan',
    '💏' => 'much’a',
    '💑' => 'pitu runakuna sunquwan',
    '🗣' => 'uma parlachkan',
    '👤' => 'ukhu rikchay',
    '👥' => 'ukhu rikchaykuna',
    '🫂' => 'runakuna makʼalliwan',
    '👪' => 'kuraq ayllu',
    '👣' => 'yupinay',
    '🫆' => 'dedopa marcan',
    '🦰' => 'puka chukcha',
    '🦱' => 'qaspa chukcha',
    '🦳' => 'yuraq chukcha',
    '🦲' => 'paqla',
    '🐵' => 'kusillu uya',
    '🐒' => 'kusillu',
    '🦍' => 'gorila',
    '🦧' => 'orangutan',
    '🐶' => 'allqu uya',
    '🐕' => 'allqu',
    '🦮' => 'yanapakuq allqu',
    '🐩' => 'poodle',
    '🐺' => 'k’ita allqu',
    '🦊' => 'atuq',
    '🦝' => 'mapache',
    '🐱' => 'misi uya',
    '🐈' => 'misi',
    '🦁' => 'leon',
    '🐯' => 'tigre uya',
    '🐅' => 'tigre',
    '🐆' => 'leopardo',
    '🐴' => 'kawallu uya',
    '🫎' => 'alce',
    '🫏' => 'asnu',
    '🐎' => 'kawallu',
    '🦄' => 'unicornio',
    '🦓' => 'zebra',
    '🦌' => 'taruka',
    '🦬' => 'bison',
    '🐮' => 'waka uya',
    '🐂' => 'buey',
    '🐃' => 'bufalo yakumanta',
    '🐄' => 'waka',
    '🐷' => 'khuchi uya',
    '🐖' => 'kuchi',
    '🐗' => 'lumi kuchi',
    '🐽' => 'kuchi sinqa',
    '🐏' => 'carnero',
    '🐑' => 'uwija',
    '🐐' => 'chiwu',
    '🐪' => 'camello',
    '🐫' => 'camello iskay qhupukunawan',
    '🦙' => 'llama',
    '🦒' => 'jirafa',
    '🐘' => 'elefante',
    '🦣' => 'mamut',
    '🦏' => 'rinoceronte',
    '🦛' => 'hipopotamo',
    '🐭' => 'ukucha uya',
    '🐁' => 'ukucha',
    '🐀' => 'rata',
    '🐹' => 'hamster',
    '🐰' => 'quwi uya',
    '🐇' => 'quwi',
    '🐿' => 'ardilla',
    '🦫' => 'castor',
    '🦔' => 'erizo',
    '🦇' => 'masu',
    '🐻' => 'ukumari',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'perezoso',
    '🦦' => 'nutria',
    '🦨' => 'añas',
    '🦘' => 'kanguro',
    '🦡' => 'tejon',
    '🐾' => 'sillu yupinay',
    '🦃' => 'pavo',
    '🐔' => 'pollo',
    '🐓' => 'kanka',
    '🐣' => 'chiwchi pakisqa runtuwan',
    '🐤' => 'chiwchi',
    '🐥' => 'huchuy pollo chimpa rikuchkan',
    '🐦' => 'p’isqu',
    '🐧' => 'pinguino',
    '🕊' => 'urpi',
    '🦅' => 'anka',
    '🦆' => 'pili',
    '🦢' => 'cisne',
    '🦉' => 'búho',
    '🦤' => 'dodo',
    '🪶' => 'phuru',
    '🦩' => 'flamenco',
    '🦚' => 'pavo real',
    '🦜' => 'uritu',
    '🪽' => 'rapra',
    '🪿' => 'ganso',
    '🐸' => 'jamp’atu',
    '🐊' => 'kayman',
    '🐢' => 'tortuga',
    '🦎' => 'qaraywa',
    '🐍' => 'amaru',
    '🐲' => 'dragon uya',
    '🐉' => 'dragon',
    '🦕' => 'sauropodo',
    '🦖' => 'T-Rex',
    '🐳' => 'ballena yakuta chamqachkan',
    '🐋' => 'ballena',
    '🐬' => 'delfin',
    '🫍' => 'orca',
    '🦭' => 'foca',
    '🐟' => 'challwa',
    '🐠' => 'tropical challwa',
    '🐡' => 'globo challwa',
    '🦈' => 'tiburon',
    '🐙' => 'pulpo',
    '🐚' => 'muyusqa churu',
    '🪸' => 'coral nisqa',
    '🪼' => 'medusa',
    '🦀' => 'cangrejo',
    '🦞' => 'langosta',
    '🦐' => 'camaron',
    '🦑' => 'calamar',
    '🦪' => 'ostra',
    '🐌' => 'churu',
    '🦋' => 'pillpintu',
    '🐛' => 'khuru',
    '🐜' => 'sikʼimira',
    '🐝' => 'wara',
    '🪲' => 'aka tanqa',
    '🐞' => 'mariquita',
    '🦗' => 'cricket',
    '🪳' => 'cucaracha',
    '🕷' => 'kusi kusi',
    '🕸' => 'llika',
    '🦂' => 'escorpión',
    '🦟' => 'mosquito',
    '🪰' => 'paway',
    '🪱' => 'sillwi uru',
    '🦠' => 'microbio',
    '💐' => 'tikakunamanta',
    '🌸' => 'cerezo tika',
    '💮' => 'yuraq tika',
    '🪷' => 'loto',
    '🏵' => 'muyu whipala',
    '🌹' => 'rosa',
    '🥀' => 'qawisqa tika',
    '🌺' => 'hibisco',
    '🌻' => 'girasol',
    '🌼' => 'cerezo',
    '🌷' => 'tulipán',
    '🪻' => 'jacinto',
    '🌱' => 'wayna mallki',
    '🪴' => 'macetapi sachʼa',
    '🌲' => 'sacha perene rapiwan',
    '🌳' => 'sacha caduca rapiwan',
    '🌴' => 'chunta',
    '🌵' => 'kisqa',
    '🌾' => 'pʼanqa arrozmanta',
    '🌿' => 'qhura',
    '☘' => 'ispinku',
    '🍀' => 'ispinku tawa laqhiwan',
    '🍁' => 'arce laqhi',
    '🍂' => 'urmasqa laqhi',
    '🍃' => 'wayrapi laqhikuna',
    '🪹' => 'chusaq qisa',
    '🪺' => 'qisa runtukunawan',
    '🍄' => 'kʼallnpa',
    '🪾' => 'sacha manam rapiwan',
    '🍇' => 'uwas',
    '🍈' => 'melón',
    '🍉' => 'sandía',
    '🍊' => 'mandarina',
    '🍋' => 'limun',
    '🍌' => 'platanu',
    '🍍' => 'piña',
    '🥭' => 'mango',
    '🍎' => 'puka manzana',
    '🍏' => 'qumir manzana',
    '🍐' => 'pera',
    '🍑' => 'rurasnu',
    '🍒' => 'cherris',
    '🍓' => 'fresa',
    '🫐' => 'arandanos',
    '🥝' => 'kiwi ruru',
    '🍅' => 'tomate',
    '🫒' => 'oliva',
    '🥥' => 'coco',
    '🥑' => 'palta',
    '🍆' => 'berenjena',
    '🥔' => 'patata',
    '🥕' => 'zanahoria',
    '🌽' => 'chuqllu',
    '🌶' => 'jaya pimienta',
    '🫑' => 'pimiento',
    '🥒' => 'pepino',
    '🥬' => 'qʼumir laqhikunawan',
    '🥦' => 'brocoli',
    '🧄' => 'ajo',
    '🧅' => 'cebolla',
    '🥜' => 'chuqupi',
    '🫘' => 'porotokuna',
    '🌰' => 'chʼumpi',
    '🫚' => 'jenjibre sapi',
    '🫛' => 'arwijakuna',
    '🫜' => 'rábano nisqa',
    '🍞' => 'tʼanta',
    '🥐' => 'croissant',
    '🥖' => 'baguette tʼanta',
    '🫓' => 'llaplla t’anta',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'panqueques',
    '🧇' => 'waffle',
    '🧀' => 'kʼallpi masaramanta',
    '🍖' => 'aycha tullupi',
    '🍗' => 'chanka pollo',
    '🥩' => 'chuleta aychamanta',
    '🥓' => 'tocino',
    '🍔' => 'hamburgesa',
    '🍟' => 'papas fritas',
    '🍕' => 'piza',
    '🌭' => 'hot dog',
    '🥪' => 'sandwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'juntʼachisqa tʼanta moldepi',
    '🧆' => 'fatafel',
    '🥚' => 'runtu',
    '🍳' => 'waykʼuchkan',
    '🥘' => 'pisi llata mikunapaq',
    '🍲' => 'llata mikunapaq',
    '🫕' => 'fondue',
    '🥣' => 'cuenco willawan',
    '🥗' => 'qʼumir ensalada',
    '🍿' => 'palomitas de maiz',
    '🧈' => 'mantequilla',
    '🧂' => 'kachi',
    '🥫' => 'mikhuna latapi',
    '🍱' => 'bento tawakʼuchu',
    '🍘' => 'galleta arrozmanta',
    '🍙' => 'muyu arrozwan',
    '🍚' => 'waykʼusqa arroz',
    '🍛' => 'arroz currywan',
    '🍜' => 'mati fideuswan',
    '🍝' => 'espagueti',
    '🍠' => 'miski waykʼusqa papa',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'thiqtisqa yukra',
    '🍥' => 'challwa pastel muyuqwan',
    '🥮' => 'killa pastel',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'galleta samipaq',
    '🥡' => 'tawak’uchu aparikuypaq',
    '🍦' => 'llampʼu helado',
    '🍧' => 'raspadillo',
    '🍨' => 'helado',
    '🍩' => 'dona',
    '🍪' => 'galleta',
    '🎂' => 'wata huntaypaq torta',
    '🍰' => 'torta',
    '🧁' => 'cupcake',
    '🥧' => 'tarta',
    '🍫' => 'chocolate barra',
    '🍬' => 'miski',
    '🍭' => 'chupete',
    '🍮' => 'raqʼa',
    '🍯' => 'miskʼi manka',
    '🍼' => 'biberón',
    '🥛' => 'wilali qirupi',
    '☕' => 'qʼuñi upyana',
    '🫖' => 'te qiru',
    '🍵' => 'chhapukucha tepaq mana ninriwan',
    '🍶' => 'sake',
    '🍾' => 'descorche jumiwa',
    '🍷' => 'vino qiru',
    '🍸' => 'cocktail qiru',
    '🍹' => 'tropical upyana',
    '🍺' => 'cerveza jumiwa',
    '🍻' => 'cerveza qirukuna anqusachkan',
    '🥂' => 'qirukuna anqusachkan',
    '🥃' => 'qiru vidriomanta',
    '🫗' => 'taqtaspa yaku',
    '🥤' => 'qiru bombillawan',
    '🧋' => 'phukpu te',
    '🧃' => 'upyana tawakʼuchu',
    '🧉' => 'mate',
    '🧊' => 'chiri',
    '🥢' => 'palillos',
    '🍽' => 'tenedor chaymanta khuchuna platowan',
    '🍴' => 'tenedor chaymanta khuchuna',
    '🥄' => 'wislla',
    '🔪' => 'khuchuna waykʼuypaq',
    '🫙' => 'puyñu',
    '🏺' => 'anfora',
    '🌍' => 'saywasiqʼi Europa, Africapas Qawachkan',
    '🌎' => 'saywasiqʼi america qawachkan',
    '🌏' => 'saywasiqʼi asia, austrakia qawachkan',
    '🌐' => 'saywasiqʼi meridianoswan',
    '🗺' => 'pacha saywasiq’i',
    '🗾' => 'Japón saywasiqi',
    '🧭' => 'compas',
    '🏔' => 'rit’i urqupi',
    '⛰' => 'urqu',
    '🛘' => 'allpa kuyuriy',
    '🌋' => 'ariq',
    '🗻' => 'fuji urqi',
    '🏕' => 'tampuchay',
    '🏖' => 'maqya paqa achiwawan',
    '🏜' => 'purum',
    '🏝' => 'purum wat’a',
    '🏞' => 'nacional parque',
    '🏟' => 'estadium',
    '🏛' => 'ñawpa wasichiy',
    '🏗' => 'hatun wasi wasichiynin',
    '🧱' => 'pirqa',
    '🪨' => 'rumi',
    '🪵' => 'kuru',
    '🛖' => 'chuklla',
    '🏘' => 'wasikuna',
    '🏚' => 'saqisqa wasi',
    '🏠' => 'wasi',
    '🏡' => 'wasi inkillwan',
    '🏢' => 'jatariki oficinakunapaq',
    '🏣' => 'Japónmanta oficina chaskipaq',
    '🏤' => 'oficina chaskipaq',
    '🏥' => 'hampina wasi',
    '🏦' => 'banco',
    '🏨' => 'tampuwasi',
    '🏩' => 'munaymanta tampu wasi',
    '🏪' => 'qatuna 24 phanikunawan',
    '🏫' => 'yachaywasi',
    '🏬' => 'qhatuna kiti',
    '🏭' => 'ruway',
    '🏯' => 'Japones pukara',
    '🏰' => 'pukara',
    '💒' => 'sawa',
    '🗼' => 'Tokio torre',
    '🗽' => 'Qhispi kay Wanki',
    '⛪' => 'iglesia',
    '🕌' => 'mezquita',
    '🛕' => 'templo indu',
    '🕍' => 'sinagoga',
    '⛩' => 'sintoismo santuario',
    '🕋' => 'kaaba',
    '⛲' => 'pukyu',
    '⛺' => 'carpa',
    '🌁' => 'kamanchaka',
    '🌃' => 'tuta chʼaskakunawan',
    '🏙' => 'paisaje llaqtapi',
    '🌄' => 'paqarin urqukunapura',
    '🌅' => 'paqarin',
    '🌆' => 'rikusqa llaqtamanta tutapi',
    '🌇' => 'inti-haykupuynin',
    '🌉' => 'chaka tutapi',
    '♨' => 'q’uñi yaku',
    '🎠' => 'carrusel kawallu',
    '🛝' => 'resbalín nisqa',
    '🎡' => 'noria qhatunapi',
    '🎢' => 'montaña rusa',
    '💈' => 'poste barberopaq',
    '🎪' => 'circo qatu',
    '🚂' => 'locomotora',
    '🚃' => 'tren ferrocarrilpaq',
    '🚄' => 'utqhay tren',
    '🚅' => 'bala tren',
    '🚆' => 'tren',
    '🚇' => 'metro',
    '🚈' => 'tren ligero',
    '🚉' => 'estacion',
    '🚊' => 'tranvia',
    '🚝' => 'monorrail',
    '🚞' => 'ferrocarril urqupaq',
    '🚋' => 'vagon tranviapaq',
    '🚌' => 'bus',
    '🚍' => 'qatiq autobus',
    '🚎' => 'trolebus',
    '🚐' => 'minibus',
    '🚑' => 'ambulancia',
    '🚒' => 'carru bomberospaq',
    '🚓' => 'policia carru',
    '🚔' => 'qatiq carru policiapaq',
    '🚕' => 'taxi',
    '🚖' => 'qatiq taxi',
    '🚗' => 'carru',
    '🚘' => 'qatiq carru',
    '🚙' => 'autocaravana',
    '🛻' => 'carru pallaypaq',
    '🚚' => 'qupuspa camión',
    '🚛' => 'articulado caminón',
    '🚜' => 'tractor',
    '🏎' => 'carrera carrupi',
    '🏍' => 'motocicleta',
    '🛵' => 'patinador motorwan',
    '🦽' => 'manual ruedaswan tiyana',
    '🦼' => 'muturwan ruedaswan tiyana',
    '🛺' => 'kikin calesa',
    '🚲' => 'bicicleta',
    '🛴' => 'patinador',
    '🛹' => 'patineta',
    '🛼' => 'ruedaswan patines',
    '🚏' => 'parada autobúspaq',
    '🛣' => 'autopista',
    '🛤' => 'ferrocarril tren',
    '🛢' => 'tambor aceitewan',
    '⛽' => 'bomba gasolinera',
    '🛞' => 'rueda',
    '🚨' => 'sirena policia carrumanta',
    '🚥' => 'kinranpa semaforo',
    '🚦' => 'sayanpa semaforo',
    '🛑' => 'alto unancha',
    '🚧' => 'wasichiy',
    '⚓' => 'linderuyachiq',
    '🛟' => 'salvavidas anillu',
    '⛵' => 'velero',
    '🛶' => 'canoa',
    '🚤' => 'utqhay lancha',
    '🛳' => 'pasajero barcomanta',
    '⛴' => 'apay',
    '🛥' => 'lancha motorwan',
    '🚢' => 'nave',
    '✈' => 'latap’isqu',
    '🛩' => 'huchuy latap’isqu',
    '🛫' => 'lata pʼisqu luqsina',
    '🛬' => 'lata pʼisqu chayana',
    '🪂' => 'paracaídas',
    '🚁' => 'helicoptero',
    '🚟' => 'warkhusqa ferrocarril',
    '🚠' => 'teleferico urqupi',
    '🚡' => 'teleferico',
    '🛰' => 'satelite',
    '🚀' => 'cohete',
    '🛸' => 'platillo volador',
    '🛎' => 'chhullupi botonespaq',
    '🧳' => 'equipaje',
    '⌛' => 'tukusqa arenawan intiwatana',
    '⏳' => 'manam tukusqa arenawan intiwatana',
    '⌚' => 'inti watana',
    '⏰' => 'despertador',
    '⏱' => 'cronografo',
    '⏲' => 'reloj temporizador',
    '🕰' => 'reloj chimeneapaq',
    '🕛' => 'chunka iskayniyuq',
    '🕧' => 'chunka iskayniyuq-kimsa chunkawan',
    '🕐' => 'huk',
    '🕜' => 'huk chaymanta kimsa chunkawan',
    '🕑' => 'iskay',
    '🕝' => 'iskay chaymanta kimsa chunkawan',
    '🕒' => 'kimsa',
    '🕞' => 'kimsa chaymanta kimsa chunkawan',
    '🕓' => 'tawa',
    '🕟' => 'tawa chaymanta kimsa chunkawan',
    '🕔' => 'phisqa',
    '🕠' => 'phisqa chaymanta kimsa chunkawan',
    '🕕' => 'suqta',
    '🕡' => 'suqta chaymanta kimsa chunkawan',
    '🕖' => 'qanchis',
    '🕢' => 'qanchis chaymanta kimsa chunkawan',
    '🕗' => 'pusaq',
    '🕣' => 'pusaq chaymanta kimsa chunkawan',
    '🕘' => 'jisqʼun',
    '🕤' => 'jisqʼun chaymanta kimsa chunkawan',
    '🕙' => 'chunka',
    '🕥' => 'chunka chaymanta kimsa chunkawan',
    '🕚' => 'chunka hukniyuq',
    '🕦' => 'chunka hukniyuq-kimsa chunkawan',
    '🌑' => 'unu Killa',
    '🌒' => 'tukuspa chawpi killa',
    '🌓' => 'hukñiqi wañu killa',
    '🌔' => 'chawpi gibosa killa',
    '🌕' => 'pura killa',
    '🌖' => 'wañu gibosa killa',
    '🌗' => 'qhipa wañu killa',
    '🌘' => 'wañu killa',
    '🌙' => 'chawpi killa',
    '🌚' => 'unu killa uya',
    '🌛' => 'chawpi killa uya',
    '🌜' => 'qipa chawpi killa uya',
    '🌡' => 'termometro',
    '☀' => 'inti',
    '🌝' => 'hunta killa uya',
    '🌞' => 'inti uyawan',
    '🪐' => 'anillukunawan planeta',
    '⭐' => 'quyllur',
    '🌟' => 'lliphisqa quyllur',
    '🌠' => 'utqhay quyllur',
    '🌌' => 'via lactea',
    '☁' => 'puyu',
    '⛅' => 'inti qhipa puyuman',
    '⛈' => 'puyu k’anchasqa parawan',
    '🌤' => 'inti qhipa huchuy puyu',
    '🌥' => 'inti qhipa hatun puyu',
    '🌦' => 'inti qhipa para puyupi',
    '🌧' => 'puyu parawan',
    '🌨' => 'puyu rit’iwan',
    '🌩' => 'puyu lliphiwan',
    '🌪' => 'wayrakuna',
    '🌫' => 'pukutay',
    '🌬' => 'wayra uya',
    '🌀' => 'ciclón',
    '🌈' => 'kʼuychi',
    '🌂' => 'wichqasqa para achiwa',
    '☂' => 'para achiwa',
    '☔' => 'para achiwa para sutʼukunawan',
    '⛱' => 'para achiwa jallp’api',
    '⚡' => 'kuraq voltaje',
    '❄' => 'rit’i urpu',
    '☃' => 'runa rit’imanta',
    '⛄' => 'ritʼi urpu mana ritʼiwan',
    '☄' => 'cometa',
    '🔥' => 'nina',
    '💧' => 'sutʼu',
    '🌊' => 'yaku wallcha',
    '🎃' => 'mathi',
    '🎄' => 'Navidad sacha',
    '🎆' => 'fuegos artificiales',
    '🎇' => 'pinchi',
    '🧨' => 'petardo',
    '✨' => 'pinchikuna',
    '🎈' => 'glubu',
    '🎉' => 'confeti chamqaq',
    '🎊' => 'muyu confetiwan',
    '🎋' => 'tanabata sachʼa',
    '🎍' => 'pino achhachala',
    '🎎' => 'Japonesa urpukuna',
    '🎏' => 'wipala carpaswan',
    '🎐' => 'chhullupi wayrapaq',
    '🎑' => 'killa itu qawaypaq',
    '🧧' => 'puka carta',
    '🎀' => 'cinta',
    '🎁' => 'pʼintusqa suña',
    '🎗' => 'yuyarinapaq cinta',
    '🎟' => 'uyakuynin boletokunapaq',
    '🎫' => 'boleto',
    '🎖' => 'militar medalla',
    '🏆' => 'trofeo',
    '🏅' => 'pukllaypaq medalla',
    '🥇' => 'medalla 1qi kitipaq',
    '🥈' => 'medalla 2qi kitipaq',
    '🥉' => 'medalla 3qi kitipaq',
    '⚽' => 'futbol pʼulu',
    '⚾' => 'beisbol',
    '🥎' => 'softball nisqa',
    '🏀' => 'basket',
    '🏐' => 'voleibol',
    '🏈' => 'futbol americano',
    '🏉' => 'rugby pʼulu',
    '🎾' => 'tenis',
    '🥏' => 'pawasqa disku',
    '🎳' => 'bolos',
    '🏏' => 'cricket pukllay',
    '🏑' => 'hockey chʼampapi',
    '🏒' => 'hockey ritʼipi',
    '🥍' => 'lacrosse nisqa',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'guante boxeopaq',
    '🥋' => 'artes marciales pʼacha',
    '🥅' => 'arco',
    '⛳' => 'wiphala tʼuqupi',
    '⛸' => 'chhullunka patinar',
    '🎣' => 'caña challawaypaq challwawan',
    '🤿' => 'buceo lentekuna',
    '🎽' => 'camiseta phawaypaq',
    '🎿' => 'esquis',
    '🛷' => 'trineo',
    '🥌' => 'muyusqa rumi',
    '🎯' => 'diana',
    '🪀' => 'yoyo',
    '🪁' => 'cometa nisqa',
    '🔫' => 'yaku pistola',
    '🎱' => 'billar',
    '🔮' => 'muyu qhispillu',
    '🪄' => 'magica warra',
    '🎮' => 'video pukllay',
    '🕹' => 'palanca patachaqpaq',
    '🎰' => 'casinopaq maquina',
    '🎲' => 'dado',
    '🧩' => 'rompecabeza parti',
    '🧸' => 'peluche',
    '🪅' => 'piñata',
    '🪩' => 'muyusqa espejokuna',
    '🪆' => 'qisa urpukuna',
    '♠' => 'espada tarhita',
    '♥' => 'sunqu tarhita',
    '♦' => 'diamante tarhita',
    '♣' => 'trebol tarhita',
    '♟' => 'peon',
    '🃏' => 'joker',
    '🀄' => 'mahjong puka dragon',
    '🎴' => 'tʼika naipes',
    '🎭' => 'artes escenicas',
    '🖼' => 'kanchapi rikchay',
    '🎨' => 'paleta llimpiq',
    '🧵' => 'hilo',
    '🪡' => 'uku hilopaq',
    '🧶' => 'watu',
    '🪢' => 'nudo',
    '👓' => 'lentes',
    '🕶' => 'lentes intipaq',
    '🥽' => 'goggles nisqa',
    '🥼' => 'laboratoriomanta pacha',
    '🦺' => 'chaleku harkaypaq',
    '👔' => 'corbata',
    '👕' => 'camisa',
    '👖' => 'jeans',
    '🧣' => 'chalina',
    '🧤' => 'guantes',
    '🧥' => 'abrigo',
    '🧦' => 'medias',
    '👗' => 'aqsu',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'naryaypaq pacha',
    '🩲' => 'yakupaq pacha',
    '🩳' => 'uchuy pantalon',
    '👙' => 'bikini',
    '👚' => 'warmipa pachan',
    '🪭' => 'abanico',
    '👛' => 'pulcera',
    '👜' => 'bolso',
    '👝' => 'cartera',
    '🛍' => 'ratina qamaña',
    '🎒' => 'qipi',
    '🩴' => 'sandalia',
    '👞' => 'runapa papatun',
    '👟' => 'pawasqa papatu',
    '🥾' => 'bota',
    '🥿' => 'planu papatu',
    '👠' => 'tacones phapatu',
    '👡' => 'warmip sandalian',
    '👢' => 'warmip botan',
    '🪮' => 'chukchapaq peine',
    '👑' => 'pillu',
    '👒' => 'warmip chikun',
    '🎩' => 'hanaq chiku',
    '🎓' => 'graduacion chiku',
    '🧢' => 'gorra',
    '🪖' => 'militar casco nisqa',
    '⛑' => 'yanapaq llamkaqmanta casco',
    '📿' => 'rosario',
    '💄' => 'llimpʼi simipaq',
    '💍' => 'siwi',
    '💎' => 'gema',
    '🔇' => 'chʼin altavoz',
    '🔈' => 'altavoz pisi chanrawan',
    '🔉' => 'altavoz chawpi chanrawan',
    '🔊' => 'altavoz hatun chanrawan',
    '📢' => 'altoparlante',
    '📣' => 'megáfono',
    '📯' => 'chakipaq waqra',
    '🔔' => 'kampana',
    '🔕' => 'chʼin chhullupi',
    '🎼' => 'partitura',
    '🎵' => 'notas musical',
    '🎶' => 'notas musicales',
    '🎙' => 'microfono estudiomanta',
    '🎚' => 'kuyuq ñiqi',
    '🎛' => 'perillas patachaqpaq',
    '🎤' => 'micrófono',
    '🎧' => 'audifono',
    '📻' => 'radio',
    '🎷' => 'saxofon',
    '🎺' => 'trompeta',
    '🪊' => 'trombón nisqa',
    '🪗' => 'acordion',
    '🎸' => 'guitarra',
    '🎹' => 'teclas musicales',
    '🎻' => 'violin',
    '🪕' => 'banjo',
    '🥁' => 'tambor',
    '🪘' => 'tambor kullumanta',
    '🪇' => 'maracas',
    '🪈' => 'flauta',
    '🪉' => 'arpa',
    '📱' => 'apaykachana telefono',
    '📲' => 'apaykachana telefono wachʼiwan',
    '☎' => 'fono',
    '📞' => 'auricular telefonomanta',
    '📟' => 'tariq',
    '📠' => 'maquina faxpaq',
    '🔋' => 'kallpa waqaychaq',
    '🪫' => 'pisi kallpa waqaychaq',
    '🔌' => 'enchufe',
    '💻' => 'computadora',
    '🖥' => 'hanpara computadora',
    '🖨' => 'impresora',
    '⌨' => 'ñitina',
    '🖱' => 'mouse computadorapaq',
    '🖲' => 'muyu mousepi',
    '💽' => 'computadora ruyru',
    '💾' => 'disquete',
    '💿' => 'disku',
    '📀' => 'dvd',
    '🧮' => 'abaco',
    '🎥' => 'camara cinepaq',
    '🎞' => 'kanchakuna peliculamanta',
    '📽' => 'proyector cinepaq',
    '🎬' => 'claqueta',
    '📺' => 'television',
    '📷' => 'camara',
    '📸' => 'camara flash kaqwan',
    '📹' => 'videocamara',
    '📼' => 'videocaset',
    '🔍' => 'lupa lluqiman',
    '🔎' => 'lupa pañaman',
    '🕯' => 'vela',
    '💡' => 'kʼancha',
    '🔦' => 'flash',
    '🏮' => 'izakaya linterna',
    '🪔' => 'diya lampara',
    '📔' => 'yachaykunapaq pʼanqa kʼacha rapiwan',
    '📕' => 'wichqasqa pʼanqa',
    '📖' => 'kichasqa pʼanqa',
    '📗' => 'qʼumir pʼanqa',
    '📘' => 'anqas p’anqa',
    '📙' => 'willapi pʼanqa',
    '📚' => 'pʼanqakuna',
    '📓' => 'huchuy qillqanacha',
    '📒' => 'pʼanqa siwukunawan',
    '📃' => 'llinkʼu rapi',
    '📜' => 'suchuririy',
    '📄' => 'hanaqman rapi',
    '📰' => 'periodico',
    '🗞' => 'periodico ch’umisqa',
    '📑' => 'rapi chinpuqkunawan',
    '🔖' => 'chinpuq',
    '🏷' => 'sutichaq',
    '🪙' => 'moneda',
    '💰' => 'qulli qipi',
    '🪎' => 'qulliwan kufri',
    '💴' => 'yen billete',
    '💵' => 'dolar billete',
    '💶' => 'euro billete',
    '💷' => 'libras esterlinas billete',
    '💸' => 'qullqi raprakunawan',
    '💳' => 'qullqi mañaypa tarjetan',
    '🧾' => 'recibo',
    '💹' => 'tawa kuchu yaparispa yenwan',
    '✉' => 'karta',
    '📧' => 'correo electronico',
    '📨' => 'yaykumuq carta',
    '📩' => 'carta wachiwan',
    '📤' => 'lluqsina wandiha',
    '📥' => 'bandeja de entrada',
    '📫' => 'wisq’asqa correo caja hoqarisqa banderayuq',
    '📪' => 'wisq’asqa correo caja uraykachisqa banderayuq',
    '📬' => 'open mailbox with raised flag',
    '📭' => 'uraykachisqa banderayuq correo cajata kichay',
    '📮' => 'chaski churana',
    '🗳' => 'urna caja de voto nisqawan',
    '✏' => 'qillqana',
    '✒' => 'yana lapisiru',
    '🖋' => 'fuente qillqana',
    '🖊' => 'tintawan qillqana',
    '🖌' => 'pincel',
    '🖍' => 'crayon',
    '📝' => 'qillqa',
    '💼' => 'maletín',
    '📁' => 'willañiqi qillqana maytʼu',
    '📂' => 'willañiqi qillqana maytʼuta kichay',
    '🗂' => 'tarjeta indis rakiqkuna',
    '📅' => 'calendario nisqa',
    '📆' => 'llikisqa calendario nisqa',
    '🗒' => 'bloc de notas espiral nisqa',
    '🗓' => 'calendario espiral nisqa',
    '📇' => 'tarjetapa indisnin',
    '📈' => 'tabla yapakuq',
    '📉' => 'tabla pisiyachiq',
    '📊' => 'tabla de barras nisqa',
    '📋' => 'portapapeles nisqa',
    '📌' => 't’ikakuna',
    '📍' => 'round pushpin',
    '📎' => 'clip rapipaq',
    '🖇' => 'tinkisqa clipkuna rapipaq',
    '📏' => 'chiqan kamachiq',
    '📐' => 'kimsa kuchuyuq kamachiq',
    '✂' => 'kuchuna',
    '🗃' => 'tarjeta archivo caja',
    '🗄' => 'file cabinet',
    '🗑' => 'basura',
    '🔒' => 'harkana',
    '🔓' => 'mana wichqasqa',
    '🔏' => 'plumawan wichqasqa',
    '🔐' => 'llavewan wichqasqa',
    '🔑' => 'kichana',
    '🗝' => 'ñawpa kichana',
    '🔨' => 'martillo',
    '⛏' => 'akllay',
    '⚒' => 'martillowan pilluy',
    '🛠' => 'martillowan llavewan',
    '🗡' => 'puñal',
    '⚔' => 'chakasqa espadakuna',
    '💣' => 'bomba',
    '🪃' => 'boomerang nisqa',
    '🏹' => 'bow and arrow',
    '🛡' => 'harkay',
    '🪚' => 'carpintería saw',
    '🔧' => 'llave',
    '🪛' => 'screwdriver',
    '🔩' => 'tuerca y perno',
    '⚙' => 'engranaje',
    '🗜' => 'abrazadera',
    '⚖' => 'balanza nisqa escala',
    '🦯' => 'yuraq kaspi',
    '🔗' => 'tinkina',
    '⛓' => 'cadenakuna',
    '🪝' => 'gancho',
    '🧰' => 'llamkanakuna huñusqa',
    '🧲' => 'magnetu',
    '🪜' => 'escalera nisqa',
    '🪏' => 'pala',
    '⚗' => 'hinallataq',
    '🧪' => 'tubo de prueba nisqa',
    '🧫' => 'petri plato',
    '🧬' => 'dna',
    '🔬' => 'microscopio',
    '🔭' => 'telescopio',
    '📡' => 'satélite nisqamanta antena nisqa',
    '💉' => 'jeringa nisqa',
    '🩸' => 'yawar gota',
    '💊' => 'pastilla',
    '🩹' => 'vendaje adhesivo nisqa',
    '🩼' => 'crutch',
    '🩺' => 'estetoscopio nisqawan',
    '🩻' => 'x-ray',
    '🚪' => 'punku',
    '🛗' => 'elevador',
    '🪞' => 'espejo',
    '🪟' => 'wasi tuqu',
    '🛏' => 'puñuna',
    '🛋' => 'sofá y lampa',
    '🪑' => 'tiyana',
    '🚽' => 'mayllakuna',
    '🪠' => 'émbolo',
    '🚿' => 'ducha',
    '🛁' => 'bañera',
    '🪤' => 'siwi trampa',
    '🪒' => 'navajas',
    '🧴' => 'loción botella',
    '🧷' => 'seguridad pin',
    '🧹' => 'pichana',
    '🧺' => 'canasta',
    '🧻' => 'rollo de papel',
    '🪣' => 'cubo',
    '🧼' => 'jabon',
    '🫧' => 'bubbles',
    '🪥' => 'toothbrush',
    '🧽' => 'sponge',
    '🧯' => 'fire extinguisher',
    '🛒' => 'shopping cart',
    '🚬' => 'cigarru',
    '⚰' => 'tawakuchu wañuypaq',
    '🪦' => 'rumi wañusqakunapaq',
    '⚱' => 'urna funeraria',
    '🧿' => 'nazar amuleto',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'pankarta',
    '🪪' => 'riqsichiq tarhita',
    '🏧' => 'ATM unancha',
    '🚮' => 'chuqasqa qupapi unancha',
    '🚰' => 'potable yaku unancha',
    '♿' => 'tiyana ruedaspi unancha',
    '🚹' => 'runapaq unancha',
    '🚺' => 'warmipaq unancha',
    '🚻' => 'baños',
    '🚼' => 'wawapaq unancha',
    '🚾' => 'inodoro',
    '🛂' => 'pasaporte chiqaqchaynin',
    '🛃' => 'aduanas',
    '🛄' => 'chaskimuy qipikuna',
    '🛅' => 'lluqsina qipikuna',
    '⚠' => 'yuyachikuy',
    '🚸' => 'wawakuna purichkanku',
    '⛔' => 'ama yaykuna',
    '🚫' => 'amatasqa',
    '🚳' => 'ama bicicletakuna',
    '🚭' => 'ama fumar',
    '🚯' => 'ama qupa chuqaychu',
    '🚱' => 'ama yaku upyaypaq',
    '🚷' => 'ama transeuntes',
    '📵' => 'ama apaykachana telefonokuna',
    '🔞' => 'ama sullka chunka pusaqniyuqwan',
    '☢' => 'radiactivo',
    '☣' => 'biologico qupa',
    '⬆' => 'hanaq wachi',
    '↗' => 'hanaq paña wachi',
    '➡' => 'paña wachi',
    '↘' => 'uran paña wachi',
    '⬇' => 'uran wachi',
    '↙' => 'uran lluqi wachi',
    '⬅' => 'lluqi wachi',
    '↖' => 'hanaq lluqi wachi',
    '↕' => 'hanaq uran wachi',
    '↔' => 'lluqi paña wachi',
    '↩' => 'paña wachi llinkuwan lluqiman',
    '↪' => 'lluqi wachi llinkuwan pañaman',
    '⤴' => 'paña wachi llinkuwan hanaqman',
    '⤵' => 'paña wachi llinkuwan uranman',
    '🔃' => 'sayanpa wachikuna ura qatichkanku',
    '🔄' => 'laduman ura qatispa wachikunata ñitina',
    '🔙' => 'QIPA wachi',
    '🔚' => 'TUKUY wachi',
    '🔛' => 'KAWSARICHIY! wachi',
    '🔜' => 'QATIQ wachi',
    '🔝' => 'HANAN wachi',
    '🛐' => 'muchay kiti',
    '⚛' => 'atomo unancha',
    '🕉' => 'om',
    '✡' => 'quyllur Davidmanta',
    '☸' => 'muyu dharmanimanta',
    '☯' => 'yin yang',
    '✝' => 'latina chakana',
    '☦' => 'ortodoxa chakana',
    '☪' => 'quyllur chaymanta chawpi killa',
    '☮' => 'qhasi kay unancha',
    '🕎' => 'menorah',
    '🔯' => 'suqta ñawpinkunawan quyllur',
    '🪯' => 'khanda',
    '♈' => 'Aries',
    '♉' => 'Tauro',
    '♊' => 'Geminis',
    '♋' => 'Cancer',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Escorpion',
    '♐' => 'Sagitario',
    '♑' => 'Capricornio',
    '♒' => 'Acuario',
    '♓' => 'Piscis',
    '⛎' => 'Ofiuco',
    '🔀' => 'chakatasqa wachʼikuna ñitina',
    '🔁' => 'kutipay ñitina',
    '🔂' => 'huklla kutipay ñitina',
    '▶' => 'purichiy ñitina',
    '⏩' => 'utqhay qatiq ñitina',
    '⏭' => 'qatiq ñan ñitina',
    '⏯' => 'purichiy utaq samay ñitina',
    '◀' => 'qhipanman ñitina',
    '⏪' => 'utqhay tikrana ñitina',
    '⏮' => 'qhipa ñan ñitina',
    '🔼' => 'hanaqman ñitina',
    '⏫' => 'utqhay hanaq ñitina',
    '🔽' => 'uranman ñitina',
    '⏬' => 'utqhay uran ñitina',
    '⏸' => 'samay ñitina',
    '⏹' => 'tatichiy ñitina',
    '⏺' => 'graway ñitina',
    '⏏' => 'qarpuy ñitina',
    '🎦' => 'cine',
    '🔅' => 'lliphiy ñitina',
    '🔆' => 'kʼanchay ñitina',
    '📶' => 'antena siqikunawan',
    '🛜' => 'internetniyuqwan',
    '📳' => 'vibracion mudu',
    '📴' => 'apaykachana telefono wañuchiy',
    '♀' => 'warmi unancha',
    '♂' => 'tata unancha',
    '⚧' => 'transgenero unancha',
    '✖' => 'mirachiy',
    '➕' => 'yapana',
    '➖' => 'qhichuna',
    '➗' => 'rakiy',
    '🟰' => 'tinki unancha',
    '♾' => 'wiñaypaq wiñaynin',
    '‼' => 'iskay qapariq yupiy',
    '⁉' => 'qapariq tapuna chinpuy',
    '❓' => 'puka tapuna chimpu',
    '❔' => 'yuraq tapukuna yupiy',
    '❕' => 'yuraq qapariq yupiy',
    '❗' => 'puka qapariq yupiy',
    '〰' => 'muyuq rakiqch’iku',
    '💱' => 'tikrasqa qullqi',
    '💲' => 'dolar unancha',
    '⚕' => 'hampiq unancha',
    '♻' => 'allinyachiy unancha',
    '⚜' => 'flor de lis',
    '🔱' => 'tridente unancha',
    '📛' => 'nina rawra',
    '🔰' => 'japones unancha qallariqkunapaq',
    '⭕' => 'ukun puka muyu',
    '✅' => 'chimputa chiqaqchay ñitina',
    '☑' => 'chiqaqchay tawakuchu chimpuwan',
    '✔' => 'chiqaqchay chimpu',
    '❌' => 'chakana chinpu',
    '❎' => 'chakana chinpu ñitina',
    '➰' => 'bucle',
    '➿' => 'iskay bucle',
    '〽' => 'alternancia patma unancha',
    '✳' => 'pusaq siqiwan asterisco',
    '✴' => 'pusaq ñawpikunawan quyllur',
    '❇' => 'k’anchay',
    '™' => 'waqaychasqa chinpuy',
    '🫟' => 'salpicay',
    '🔠' => 'latina hatun sananpakuna yaykuy',
    '🔡' => 'latina uchuy sananpakuna yaykuy',
    '🔢' => 'yupaykuna yaykuy',
    '🔣' => 'unanchakuna yaykuy',
    '🔤' => 'latina sananpakuna yaykuy',
    '🅰' => 'A ñitina (imayna yawar)',
    '🆎' => 'AB ñitina (imayna yawar)',
    '🅱' => 'B ñitina (imayna yawar)',
    '🆑' => 'CL ñitina',
    '🆒' => 'COOL ñitina',
    '🆓' => 'FREE ñitina',
    'ℹ' => 'willakuy',
    '🆔' => 'ID ñitina',
    'Ⓜ' => 'muyusqa M',
    '🆕' => 'NEW ñitina',
    '🆖' => 'NG ñitina',
    '🅾' => 'O ñitina (imayna yawar)',
    '🆗' => 'OK ñitina',
    '🅿' => 'P ñitina',
    '🆘' => 'SOS ñitina',
    '🆙' => 'UP! ñitina',
    '🆚' => 'VS ñitina',
    '🈁' => 'Japones "kaypi" ñitina',
    '🈂' => 'Japones "yanapakuy chanin" ñitina',
    '🈷' => 'Japones "sapa killa chanin" ñitina',
    '🈶' => 'Japones "mana qullqiyuq chaninpaq" ñitina',
    '🈯' => 'Japones "waqaychasqa" ñitina',
    '🉐' => 'Japones "makipuray" ñitina',
    '🈹' => 'Japones "ribajay" ñitina',
    '🈚' => 'Japones "mana tarifawan" ñitina',
    '🈲' => 'Japones "amatasqa" ñitina',
    '🉑' => 'Japones "uyakusqa" ñitina',
    '🈸' => 'Japones “llamkana” ñitina',
    '🈴' => 'Japones "ñiqi wichay" ñitina',
    '🈳' => 'Japones "vacante" ñitina',
    '㊗' => 'Japones “kusirikuykuna” ñitina',
    '㊙' => 'Japones "pakasqa" ñitina',
    '🈺' => 'Japones "qatunapaq kichay" ñitina',
    '🈵' => 'Japones "mana vacanteyuq" ñitina',
    '🔴' => 'puka muyu',
    '🟠' => 'qillmu muyu',
    '🟡' => 'qillu muyu',
    '🟢' => 'qumir muyu',
    '🔵' => 'anqas muyu',
    '🟣' => 'kulli muyu',
    '🟤' => 'paru muyu',
    '⚫' => 'yana muyu',
    '⚪' => 'yuraq muyu',
    '🟥' => 'puka tawakuchu',
    '🟧' => 'qillmu tawakuchu',
    '🟨' => 'qillu tawakuchu',
    '🟩' => 'qumir tawakuchu',
    '🟦' => 'anqas tawakuchu',
    '🟪' => 'kulli tawakuchu',
    '🟫' => 'paru tawakuchu',
    '⬛' => 'yana hatun tawakuchu',
    '⬜' => 'yuraq hatun tawakuchu',
    '◼' => 'yana kuska tawakuchu',
    '◻' => 'yuraq kuska tawakuchu',
    '◾' => 'yana kuska uchuy tawakuchu',
    '◽' => 'yuraq kuska uchuy tawakuchu',
    '▪' => 'yana uchuy tawakuchu',
    '▫' => 'yuraq uchuy tawakuchu',
    '🔶' => 'hatun qillmu puytu',
    '🔷' => 'hatun anqas puytu',
    '🔸' => 'uchuy qillmu puytu',
    '🔹' => 'uchuy anqas puytu',
    '🔺' => 'puka kimsakuchu ñawpiwan hanaqman',
    '🔻' => 'puka kimsakuchu ñawpiwan uranman',
    '💠' => 'puytu chusuwan',
    '🔘' => 'radio ñitina',
    '🔳' => 'yuraq tawakuchu ñitina',
    '🔲' => 'yana tawakuchu ñitina',
    '🏁' => 'metapaq whipala',
    '🚩' => 'kimsa kʼuchuwan wiphala',
    '🎌' => 'chakatasqa wiphalakuna',
    '🏴' => 'yana whipala',
    '🏳' => 'yuraq whipala',
];
